.lightdm.menu {
    background-image: none;
    background-color: alpha(black, 0.6);
    border-color: alpha(white, 0.2);
    border-radius: 3px;
    padding: 1px;
    color: white;
}

.lightdm-combo .menu {
    background-color: alpha(black, 0.6);
    border-radius: 0;
    padding: 0;
    color: white;
}

.lightdm.menu .menuitem *,
.lightdm.menu .menuitem.check:active,
.lightdm.menu .menuitem.radio:active {
    color: white;
}

.lightdm.menubar {
    background-image: none;
    background-color: alpha(black, 0.5);
}

.lightdm-combo.combobox-entry .button,
.lightdm-combo .cell,
.lightdm-combo .button,
.lightdm-combo .entry,
.lightdm.button,
.lightdm.entry {
    background-image: none;
    background-color: alpha(black, 0.3);
    border-color: alpha(white, 0.6);
    border-radius: 3px;
    padding: 7px;
    color: white;
    text-shadow: none;
}

.lightdm.button,
.lightdm.button:hover,
.lightdm.button:active,
.lightdm.button:active:focus,
.lightdm.entry,
.lightdm.entry:hover,
.lightdm.entry:active,
.lightdm.entry:active:focus {
    background-image: none;
}

.lightdm.button:focus,
.lightdm.entry:focus {
    border-color: alpha(white, 0.9);
    color: white;
}

@keyframes dashentry_spinner {
    to { -gtk-icon-transform: rotate(1turn); }
}

.lightdm.entry:active {
    -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
    animation: dashentry_spinner 1s infinite linear;
}
