# Google Chrome/Chromium theming (requires 9.0.597 or newer)
style "chrome-gtk-frame"
{
    ChromeGtkFrame::frame-color = shade (1.0, @bg_color)
    ChromeGtkFrame::inactive-frame-color = shade (1.0, @bg_color)
    ChromeGtkFrame::incognito-frame-color = shade (0.5, @bg_color)
    ChromeGtkFrame::incognito-inactive-frame-color = shade (0.5, @bg_color)

    ChromeGtkFrame::frame-gradient-size = 100
    ChromeGtkFrame::frame-gradient-color = shade (1.08,@bg_color)
    ChromeGtkFrame::inactive-frame-gradient-color = shade (1.08,@bg_color)
    ChromeGtkFrame::incognito-frame-gradient-color = shade (1.08,@bg_color)
    ChromeGtkFrame::incognito-inactive-frame-gradient-color = shade (1.08,@bg_color)

    ChromeGtkFrame::scrollbar-trough-color = @base_color
    ChromeGtkFrame::scrollbar-slider-prelight-color = shade(0.92, @bg_color)
    ChromeGtkFrame::scrollbar-slider-normal-color = @bg_color
}
class "ChromeGtkFrame"		style "chrome-gtk-frame"
