*, .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link { padding: 0; -GtkToolButton-icon-spacing: 4; -GtkTextView-error-underline-color: #cc0000; -GtkScrolledWindow-scrollbar-spacing: 0; -GtkToolItemGroup-expander-size: 11; -GtkWidget-text-handle-width: 20; -GtkWidget-text-handle-height: 24; -GtkDialog-button-spacing: 4; -GtkDialog-action-area-border: 0; outline-color: alpha(currentColor,0.3); outline-style: dashed; outline-offset: -3px; outline-width: 1px; -gtk-outline-radius: 2px; -gtk-secondary-caret-color: #145ba6; }

/*************** Base States * */
.background { color: #eeeeec; background-color: #3b3e3f; }

.background:backdrop { color: #959696; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; }

/* These wildcard seems unavoidable, need to investigate. Wildcards are bad and troublesome, use them with care, or better, just don't. Everytime a wildcard is used a kitten dies, painfully. */
spinner:disabled, arrow:disabled, scrollbar:disabled, check:disabled, radio:disabled, treeview.expander:disabled, label:disabled selection.expander { -gtk-icon-effect: dim; }

.gtkstyle-fallback { color: #eeeeec; background-color: #3b3e3f; text-shadow: none; }

.gtkstyle-fallback:hover { color: #eeeeec; background-color: #545859; }

.gtkstyle-fallback:active { color: #eeeeec; background-color: #222425; }

.gtkstyle-fallback:disabled, label:disabled selection.gtkstyle-fallback { color: #959696; background-color: #353839; }

.gtkstyle-fallback:selected, .selection-mode.titlebar:not(headerbar) .gtkstyle-fallback.subtitle:link, headerbar.selection-mode .gtkstyle-fallback.subtitle:link { color: #ffffff; background-color: #145ba6; }

.view, iconview, .view text, iconview text, textview text { color: white; background-color: #2d2e30; }

.view:backdrop, iconview:backdrop, .view text:backdrop, iconview text:backdrop, textview text:backdrop { color: #d5d6d6; background-color: #2f3133; }

.view:backdrop:disabled, label:disabled selection:backdrop, iconview:backdrop:disabled, .view text:backdrop:disabled, iconview text:backdrop:disabled, textview text:backdrop:disabled { color: #606567; }

.view:disabled, label:disabled selection.view, iconview:disabled, .view text:disabled, iconview text:disabled, textview text:disabled { color: #959696; background-color: #353839; }

.view:selected:focus, iconview:selected:focus, headerbar.selection-mode iconview.subtitle:focus:link, .view:selected, .selection-mode.titlebar:not(headerbar) .view.subtitle:link, headerbar.selection-mode .view.subtitle:link, iconview:selected, .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, headerbar.selection-mode iconview.subtitle:link, textview text:selected:focus, textview headerbar.selection-mode text.subtitle:focus:link, headerbar.selection-mode textview text.subtitle:focus:link, .view text:selected, .view .selection-mode.titlebar:not(headerbar) text.subtitle:link, .selection-mode.titlebar:not(headerbar) .view text.subtitle:link, .view headerbar.selection-mode text.subtitle:link, headerbar.selection-mode .view text.subtitle:link, iconview text:selected, iconview .selection-mode.titlebar:not(headerbar) text.subtitle:link, .selection-mode.titlebar:not(headerbar) iconview text.subtitle:link, iconview headerbar.selection-mode text.subtitle:link, headerbar.selection-mode iconview text.subtitle:link, textview text:selected, textview .selection-mode.titlebar:not(headerbar) text.subtitle:link, .selection-mode.titlebar:not(headerbar) textview text.subtitle:link, textview headerbar.selection-mode text.subtitle:link, headerbar.selection-mode textview text.subtitle:link { border-radius: 3px; }

textview border { background-color: #343638; }

.rubberband, rubberband, XfdesktopIconView.view .rubberband, .content-view rubberband, .content-view .rubberband, treeview.view rubberband, flowbox rubberband { border: 1px solid #0f4278; background-color: rgba(15, 66, 120, 0.2); }

flowbox flowboxchild { padding: 3px; border-radius: 3px; }

flowbox flowboxchild:selected, flowbox .selection-mode.titlebar:not(headerbar) flowboxchild.subtitle:link, .selection-mode.titlebar:not(headerbar) flowbox flowboxchild.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link { outline-offset: -2px; }

.content-view .tile { margin: 2px; background-color: black; border-radius: 0; padding: 0; }

.content-view .tile:backdrop { background-color: #232425; }

.content-view .tile:active, .content-view .tile:selected, .content-view .selection-mode.titlebar:not(headerbar) .tile.subtitle:link, .selection-mode.titlebar:not(headerbar) .content-view .tile.subtitle:link, .content-view headerbar.selection-mode .tile.subtitle:link, headerbar.selection-mode .content-view .tile.subtitle:link { background-color: #145ba6; }

.content-view .tile:disabled, .content-view label:disabled selection.tile, label:disabled .content-view selection.tile { background-color: #353839; }

label { caret-color: currentColor; }

label.separator { color: #eeeeec; }

label.separator:backdrop { color: #959696; }

label:disabled { color: #959696; }

button label:disabled { color: inherit; }

label:disabled:backdrop { color: #606567; }

button label:disabled:backdrop { color: inherit; }

label:backdrop selection { color: #d5d6d6; background-color: #656a6c; }

.dim-label, .titlebar:not(headerbar) .subtitle, headerbar .subtitle, label.separator { opacity: 0.55; text-shadow: none; }

assistant .sidebar { background-color: #2d2e30; border-top: 1px solid #1d1f1f; }

assistant .sidebar:backdrop { background-color: #2f3133; border-color: #202223; }

assistant.csd .sidebar { border-top-style: none; }

assistant .sidebar label { padding: 6px 12px; }

assistant .sidebar label.highlight { background-color: #5f6162; }

.osd .scale-popup, .app-notification, .app-notification.frame, .csd popover.background.osd, popover.background.osd, .csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier, .osd { color: #eeeeee; border: none; background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; outline-color: rgba(238, 238, 238, 0.3); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd .scale-popup:backdrop, .app-notification:backdrop, popover.background.osd:backdrop, popover.background.touch-selection:backdrop, popover.background.magnifier:backdrop, .osd:backdrop { color: shade(#eeeeee, 1.2); background-color: shade(rgba(34, 34, 34, 0.8), 1.6); text-shadow: none; -gtk-icon-shadow: none; }

/********************* Spinner Animation * */
@keyframes spin { to { -gtk-icon-transform: rotate(1turn); } }

spinner { background: none; opacity: 0; -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }

spinner:backdrop { color: #959696; }

spinner:checked { opacity: 1; animation: spin 1s linear infinite; }

spinner:checked:disabled, label:disabled selection:checked { opacity: 0.5; }

/**************** Text Entries * */
spinbutton:not(.vertical), entry { min-height: 28px; padding-left: 4px; padding-right: 4px; border: 1px solid; border-radius: 3px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: white; border-color: #1d1f1f; background-color: #2d2e30; box-shadow: inset 0 0 0 1px rgba(20, 91, 166, 0); }

spinbutton:not(.vertical) image.left, entry image.left { margin-right: 6px; }

spinbutton:not(.vertical) image.right, entry image.right { margin-left: 6px; }

spinbutton:not(.vertical) undershoot.left, entry undershoot.left { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-left: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: left center; border: none; box-shadow: none; }

spinbutton:not(.vertical) undershoot.right, entry undershoot.right { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-right: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: right center; border: none; box-shadow: none; }

label:disabled selection.flat, label:disabled selection:backdrop, spinbutton.flat:not(.vertical), entry.flat { min-height: 0; padding: 2px; background-color: transparent; border-color: transparent; border-radius: 0; }

spinbutton:focus:not(.vertical), entry:focus { border-color: #145ba6; }

spinbutton:disabled:not(.vertical), entry:disabled { color: #959696; border-color: #1d1f1f; background-color: #353839; box-shadow: none; }

spinbutton:backdrop:not(.vertical), entry:backdrop { color: #d5d6d6; border-color: #202223; background-color: #2f3133; box-shadow: none; transition: 200ms ease-out; }

spinbutton:backdrop:disabled:not(.vertical), label:disabled selection:backdrop, entry:backdrop:disabled { color: #606567; border-color: #202223; background-color: #353839; box-shadow: none; }

spinbutton.error:not(.vertical), entry.error { background-color: rgba(204, 0, 0, 0.1); color: #cc0000; text-shadow: none; border-color: #cc0000; }

spinbutton.error:focus:not(.vertical), entry.error:focus { border-color: #cc0000; }

spinbutton.error:not(.vertical) selection, entry.error selection { background-color: #cc0000; }

spinbutton.warning:not(.vertical), entry.warning { background-color: rgba(245, 121, 0, 0.1); color: #f57900; text-shadow: none; border-color: #f57900; }

spinbutton.warning:focus:not(.vertical), entry.warning:focus { border-color: #f57900; }

spinbutton.warning:not(.vertical) selection, entry.warning selection { background-color: #f57900; }

spinbutton:not(.vertical) image, entry image { color: #c7c8c6; }

spinbutton:not(.vertical) image:hover, entry image:hover { color: #eeeeec; }

spinbutton:not(.vertical) image:active, entry image:active { color: #145ba6; }

spinbutton:not(.vertical) image:backdrop, entry image:backdrop { color: #818282; }

spinbutton:drop(active):not(.vertical), entry:drop(active):focus, entry:drop(active) { border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; }

.osd spinbutton:not(.vertical), .osd entry { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:focus:not(.vertical), .osd entry:focus { color: white; border-color: #145ba6; background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: inset 0 0 0 1px #145ba6; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:backdrop:not(.vertical), .osd entry:backdrop { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd spinbutton:disabled:not(.vertical), .osd entry:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

spinbutton:not(.vertical) progress, entry progress { margin: 2px -6px; background-color: transparent; background-image: none; border-radius: 0; border-width: 0 0 2px; border-color: #145ba6; border-style: solid; box-shadow: none; }

spinbutton:not(.vertical) progress:backdrop, entry progress:backdrop { background-color: transparent; }

.linked:not(.vertical) > spinbutton:focus:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus:not(.vertical) + entry, .linked:not(.vertical) > entry:focus + button, .linked:not(.vertical) > entry:focus + combobox > box > button.combo, .linked:not(.vertical) > entry:focus + spinbutton:not(.vertical), .linked:not(.vertical) > entry:focus + entry { border-left-color: #145ba6; }

.linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus.error:not(.vertical) + entry, .linked:not(.vertical) > entry:focus.error + button, .linked:not(.vertical) > entry:focus.error + combobox > box > button.combo, .linked:not(.vertical) > entry:focus.error + spinbutton:not(.vertical), .linked:not(.vertical) > entry:focus.error + entry { border-left-color: #cc0000; }

.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + entry, .linked:not(.vertical) > entry:drop(active) + button, .linked:not(.vertical) > entry:drop(active) + combobox > box > button.combo, .linked:not(.vertical) > entry:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > entry:drop(active) + entry { border-left-color: #4e9a06; }

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled), .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) { border-top-color: #28292b; background-color: #2d2e30; }

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled):backdrop, .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):backdrop:not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled):backdrop, .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):backdrop:not(.vertical) { border-top-color: #2b2c2e; background-color: #2f3133; }

.linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical), .linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, .linked.vertical > entry:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > entry:disabled + entry:disabled { border-top-color: #28292b; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus:not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:focus:not(:only-child), .linked.vertical > entry + spinbutton:focus:not(:only-child):not(.vertical), .linked.vertical > entry + entry:focus:not(:only-child) { border-top-color: #145ba6; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus.error:not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:focus.error:not(:only-child), .linked.vertical > entry + spinbutton:focus.error:not(:only-child):not(.vertical), .linked.vertical > entry + entry:focus.error:not(:only-child) { border-top-color: #cc0000; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), .linked.vertical > entry + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > entry + entry:drop(active):not(:only-child) { border-top-color: #4e9a06; }

.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:focus:not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:focus:not(:only-child) + entry, .linked.vertical > entry:focus:not(:only-child) + button, .linked.vertical > entry:focus:not(:only-child) + combobox > box > button.combo { border-top-color: #145ba6; }

.linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:focus.error:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:focus.error:not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:focus.error:not(:only-child) + entry, .linked.vertical > entry:focus.error:not(:only-child) + button, .linked.vertical > entry:focus.error:not(:only-child) + combobox > box > button.combo { border-top-color: #cc0000; }

.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:drop(active):not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:drop(active):not(:only-child) + entry, .linked.vertical > entry:drop(active):not(:only-child) + button, .linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo { border-top-color: #4e9a06; }

treeview entry:focus:dir(rtl), treeview entry:focus:dir(ltr) { background-color: #2d2e30; transition-property: color, background; }

treeview entry.flat, treeview entry { border-radius: 0; background-image: none; background-color: #2d2e30; }

treeview entry.flat:focus, treeview entry:focus { border-color: #145ba6; }

/*********** Buttons * */
@keyframes needs_attention { from { background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#2281e4), to(transparent)); }
  to { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#145ba6), to(transparent)); } }

button.titlebutton, button.sidebar-button, notebook > header > tabs > arrow, combobox:drop(active) button.combo, .selection-mode button.titlebutton, button { min-height: 24px; min-width: 22px; padding: 1px 2px; border: 1px solid; border-radius: 3px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #36393a, #313434 60%, #2c2e2f); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

notebook > header > tabs > arrow.flat, notebook > header > tabs > arrow, combobox:drop(active) button.flat.combo, combobox:drop(active) button.combo.titlebutton, combobox:drop(active) button.combo.sidebar-button, .selection-mode button.titlebutton, button.flat, button.titlebutton, button.sidebar-button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; transition: none; }

notebook > header > tabs > arrow:hover, combobox:drop(active) button.flat.combo:hover, combobox:drop(active) button.combo.titlebutton:hover, combobox:drop(active) button.combo.sidebar-button:hover, button.flat:hover, button.titlebutton:hover, button.sidebar-button:hover { transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-duration: 500ms; }

notebook > header > tabs > arrow:hover:active, combobox:drop(active) button.flat.combo:hover:active, combobox:drop(active) button.combo.titlebutton:hover:active, combobox:drop(active) button.combo.sidebar-button:hover:active, button.flat:hover:active, button.titlebutton:hover:active, button.sidebar-button:hover:active { transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

notebook > header > tabs > arrow:hover, combobox:drop(active) button.combo:hover, .selection-mode button.titlebutton:hover, button:hover { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3d4142, #36393a 60%, #313434); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); -gtk-icon-effect: highlight; }

notebook > header > tabs > arrow:active, combobox:drop(active) button.combo:active, notebook > header > tabs > arrow:checked, combobox:drop(active) button.combo:checked, .selection-mode button.titlebutton:active, .selection-mode button.titlebutton:checked, button:active, button:checked { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #252727, #2f3132); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); transition-duration: 50ms; }

popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, notebook > header > tabs > arrow:backdrop, combobox:drop(active) button.combo:backdrop, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, .selection-mode button.titlebutton:backdrop, button:backdrop.flat, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, button:backdrop { border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); transition: 200ms ease-out; -gtk-icon-effect: none; }

popover.background checkbutton:backdrop label, popover.background radiobutton:backdrop label, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, notebook > header > tabs > arrow:backdrop label, combobox:drop(active) button.combo:backdrop label, notebook > header > tabs > arrow:backdrop, combobox:drop(active) button.combo:backdrop, popover.background checkbutton:backdrop label, popover.background radiobutton:backdrop label, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, .selection-mode button.titlebutton:backdrop label, .selection-mode button.titlebutton:backdrop, button:backdrop.flat label, popover.background checkbutton:backdrop label, popover.background radiobutton:backdrop label, button:backdrop.flat, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, button:backdrop label, button:backdrop { color: #959696; }

popover.background checkbutton:backdrop:active, popover.background radiobutton:backdrop:active, popover.background checkbutton:backdrop:checked, popover.background radiobutton:backdrop:checked, notebook > header > tabs > arrow:backdrop:active, combobox:drop(active) button.combo:backdrop:active, notebook > header > tabs > arrow:backdrop:checked, combobox:drop(active) button.combo:backdrop:checked, button:backdrop.flat:active, button:backdrop.flat:checked, button:backdrop:active, button:backdrop:checked { border-color: #202223; background-color: #323435; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton:backdrop:active label, popover.background radiobutton:backdrop:active label, popover.background checkbutton:backdrop:active, popover.background radiobutton:backdrop:active, popover.background checkbutton:backdrop:checked label, popover.background radiobutton:backdrop:checked label, popover.background checkbutton:backdrop:checked, popover.background radiobutton:backdrop:checked, notebook > header > tabs > arrow:backdrop:active label, combobox:drop(active) button.combo:backdrop:active label, notebook > header > tabs > arrow:backdrop:active, combobox:drop(active) button.combo:backdrop:active, notebook > header > tabs > arrow:backdrop:checked label, combobox:drop(active) button.combo:backdrop:checked label, notebook > header > tabs > arrow:backdrop:checked, combobox:drop(active) button.combo:backdrop:checked, button:backdrop.flat:active label, button:backdrop.flat:active, button:backdrop.flat:checked label, button:backdrop.flat:checked, button:backdrop:active label, button:backdrop:active, button:backdrop:checked label, button:backdrop:checked { color: #959696; }

popover.background checkbutton:backdrop:disabled, popover.background radiobutton:backdrop:disabled, label:disabled selection.flat, notebook > header > tabs > arrow:backdrop:disabled, combobox:drop(active) button.combo:backdrop:disabled, label:disabled selection:backdrop, button:backdrop.flat:disabled, button:backdrop:disabled { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton:backdrop:disabled label, popover.background radiobutton:backdrop:disabled label, label:disabled selection.flat label, popover.background checkbutton:backdrop:disabled, popover.background radiobutton:backdrop:disabled, label:disabled selection.flat, notebook > header > tabs > arrow:backdrop:disabled label, combobox:drop(active) button.combo:backdrop:disabled label, label:disabled selection:backdrop label, notebook > header > tabs > arrow:backdrop:disabled, combobox:drop(active) button.combo:backdrop:disabled, label:disabled selection:backdrop, button:backdrop.flat:disabled label, button:backdrop.flat:disabled, button:backdrop:disabled label, button:backdrop:disabled { color: #606567; }

popover.background checkbutton:backdrop:disabled:active, popover.background radiobutton:backdrop:disabled:active, label:disabled selection.flat:active, popover.background checkbutton:backdrop:disabled:checked, popover.background radiobutton:backdrop:disabled:checked, label:disabled selection.flat:checked, notebook > header > tabs > arrow:backdrop:disabled:active, combobox:drop(active) button.combo:backdrop:disabled:active, label:disabled selection:backdrop:active, notebook > header > tabs > arrow:backdrop:disabled:checked, combobox:drop(active) button.combo:backdrop:disabled:checked, label:disabled selection:backdrop:checked, button:backdrop.flat:disabled:active, button:backdrop.flat:disabled:checked, button:backdrop:disabled:active, button:backdrop:disabled:checked { border-color: #202223; background-color: #292b2c; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton:backdrop:disabled:active label, popover.background radiobutton:backdrop:disabled:active label, label:disabled selection.flat:active label, popover.background checkbutton:backdrop:disabled:checked label, popover.background radiobutton:backdrop:disabled:checked label, label:disabled selection.flat:checked label, notebook > header > tabs > arrow:backdrop:disabled:active label, label:disabled selection:backdrop:active label, notebook > header > tabs > arrow:backdrop:disabled:checked label, label:disabled selection:backdrop:checked label, button:backdrop.flat:disabled:active label, button:backdrop.flat:disabled:checked label, button:backdrop:disabled:active label, button:backdrop:disabled:checked label { color: #606567; }

notebook > header > tabs > arrow:backdrop, combobox:drop(active) button.flat.combo:backdrop, combobox:drop(active) button.combo.titlebutton:backdrop, combobox:drop(active) button.combo.sidebar-button:backdrop, notebook > header > tabs > arrow:disabled, combobox:drop(active) button.flat.combo:disabled, combobox:drop(active) button.combo.titlebutton:disabled, combobox:drop(active) button.combo.sidebar-button:disabled, label:disabled selection.flat, label:disabled selection:backdrop, button.flat:backdrop, button.titlebutton:backdrop, button.sidebar-button:backdrop, button.flat:disabled, button.titlebutton:disabled, button.sidebar-button:disabled, button.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

notebook > header > tabs > arrow:disabled, combobox:drop(active) button.combo:disabled, .selection-mode button.titlebutton:disabled, button:disabled { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:disabled label, combobox:drop(active) button.combo:disabled label, notebook > header > tabs > arrow:disabled, combobox:drop(active) button.combo:disabled, .selection-mode button.titlebutton:disabled label, .selection-mode button.titlebutton:disabled, button:disabled label, button:disabled { color: #959696; }

notebook > header > tabs > arrow:disabled:active, combobox:drop(active) button.combo:disabled:active, notebook > header > tabs > arrow:disabled:checked, combobox:drop(active) button.combo:disabled:checked, button:disabled:active, button:disabled:checked { border-color: #1d1f1f; background-image: linear-gradient(to bottom, #333536, #353839); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:disabled:active label, combobox:drop(active) button.combo:disabled:active label, notebook > header > tabs > arrow:disabled:active, combobox:drop(active) button.combo:disabled:active, notebook > header > tabs > arrow:disabled:checked label, combobox:drop(active) button.combo:disabled:checked label, notebook > header > tabs > arrow:disabled:checked, combobox:drop(active) button.combo:disabled:checked, button:disabled:active label, button:disabled:active, button:disabled:checked label, button:disabled:checked { color: #959696; }

notebook > header > tabs > arrow.image-button, combobox:drop(active) button.image-button.combo, .selection-mode button.image-button.titlebutton, button.image-button { min-height: 20px; min-width: 20px; padding: 2px; }

notebook > header > tabs > arrow.text-button, combobox:drop(active) button.text-button.combo, .selection-mode button.text-button.titlebutton, button.text-button { padding-left: 8px; padding-right: 8px; }

notebook > header > tabs > arrow.text-button.image-button, combobox:drop(active) button.text-button.image-button.combo, button.text-button.image-button { padding-left: 4px; padding-right: 4px; }

notebook > header > tabs > arrow.text-button.image-button label, combobox:drop(active) button.text-button.image-button.combo label, button.text-button.image-button label { padding-left: 4px; padding-right: 4px; }

notebook > header > tabs > arrow:drop(active), combobox:drop(active) button.combo.titlebutton, combobox:drop(active) button.combo.sidebar-button, combobox:drop(active) button.combo:drop(active), combobox:drop(active) button.combo, .selection-mode button.titlebutton:drop(active), button:drop(active), combobox:drop(active) button.combo { color: #4e9a06; border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; }

row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled), row:selected button.titlebutton:not(:active):not(:checked):not(:hover):not(disabled), row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), .selection-mode.titlebar:not(headerbar) row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled), .selection-mode.titlebar:not(headerbar) row.subtitle:link button.titlebutton:not(:active):not(:checked):not(:hover):not(disabled), .selection-mode.titlebar:not(headerbar) row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), headerbar.selection-mode row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled), headerbar.selection-mode row.subtitle:link button.titlebutton:not(:active):not(:checked):not(:hover):not(disabled), headerbar.selection-mode row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled) { color: #ffffff; border-color: transparent; }

row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected button.titlebutton:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop, .selection-mode.titlebar:not(headerbar) row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, .selection-mode.titlebar:not(headerbar) row.subtitle:link button.titlebutton:not(:active):not(:checked):not(:hover):not(disabled):backdrop, .selection-mode.titlebar:not(headerbar) row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop, headerbar.selection-mode row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, headerbar.selection-mode row.subtitle:link button.titlebutton:not(:active):not(:checked):not(:hover):not(disabled):backdrop, headerbar.selection-mode row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop { color: #959696; }

.selection-mode button.osd.titlebutton, button.osd { min-width: 24px; min-height: 32px; color: #eeeeee; border-radius: 5px; outline-color: rgba(238, 238, 238, 0.3); color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); border: none; box-shadow: none; }

button.osd.image-button { min-width: 32px; }

button.osd:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); border: none; box-shadow: none; }

button.osd:active, button.osd:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); border: none; box-shadow: none; }

label:disabled selection.osd, button.osd:disabled:backdrop, button.osd:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; border: none; }

button.osd:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; border: none; }

.app-notification button, .app-notification.frame button, .csd popover.background.touch-selection button, .csd popover.background.magnifier button, popover.background.touch-selection button, popover.background.magnifier button, .osd .selection-mode button.titlebutton, .selection-mode .osd button.titlebutton, .osd button { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .osd button:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button:active, popover.background.touch-selection button:active, popover.background.magnifier button:active, .app-notification button:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .osd button:active:backdrop, .osd button:active, .osd button:checked:backdrop, .osd button:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .osd button:disabled:backdrop, .osd button:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button:backdrop, popover.background.touch-selection button:backdrop, popover.background.magnifier button:backdrop, .osd button:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.flat, .app-notification button.titlebutton, .app-notification button.sidebar-button, popover.background.touch-selection button.flat, popover.background.touch-selection button.titlebutton, popover.background.touch-selection button.sidebar-button, popover.background.magnifier button.flat, popover.background.magnifier button.titlebutton, popover.background.magnifier button.sidebar-button, .osd button.flat, .osd button.titlebutton, .osd button.sidebar-button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; box-shadow: none; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.app-notification button.flat:hover, .app-notification button.titlebutton:hover, .app-notification button.sidebar-button:hover, popover.background.touch-selection button.flat:hover, popover.background.touch-selection button.titlebutton:hover, popover.background.touch-selection button.sidebar-button:hover, popover.background.magnifier button.flat:hover, popover.background.magnifier button.titlebutton:hover, popover.background.magnifier button.sidebar-button:hover, .osd button.flat:hover, .osd button.titlebutton:hover, .osd button.sidebar-button:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button.flat:disabled, .app-notification button.titlebutton:disabled, .app-notification button.sidebar-button:disabled, popover.background.touch-selection button.flat:disabled, popover.background.touch-selection button.titlebutton:disabled, popover.background.touch-selection button.sidebar-button:disabled, popover.background.magnifier button.flat:disabled, popover.background.magnifier button.titlebutton:disabled, popover.background.magnifier button.sidebar-button:disabled, label:disabled selection.flat, .osd button.flat:disabled, .osd button.titlebutton:disabled, .osd button.sidebar-button:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; background-image: none; border-color: transparent; box-shadow: none; }

.app-notification button.flat:backdrop, .app-notification button.titlebutton:backdrop, .app-notification button.sidebar-button:backdrop, popover.background.touch-selection button.flat:backdrop, popover.background.touch-selection button.titlebutton:backdrop, popover.background.touch-selection button.sidebar-button:backdrop, popover.background.magnifier button.flat:backdrop, popover.background.magnifier button.titlebutton:backdrop, popover.background.magnifier button.sidebar-button:backdrop, .osd button.flat:backdrop, .osd button.titlebutton:backdrop, .osd button.sidebar-button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.flat:active, .app-notification button.titlebutton:active, .app-notification button.sidebar-button:active, popover.background.touch-selection button.flat:active, popover.background.touch-selection button.titlebutton:active, popover.background.touch-selection button.sidebar-button:active, popover.background.magnifier button.flat:active, popover.background.magnifier button.titlebutton:active, popover.background.magnifier button.sidebar-button:active, .app-notification button.flat:checked, .app-notification button.titlebutton:checked, .app-notification button.sidebar-button:checked, popover.background.touch-selection button.flat:checked, popover.background.touch-selection button.titlebutton:checked, popover.background.touch-selection button.sidebar-button:checked, popover.background.magnifier button.flat:checked, popover.background.magnifier button.titlebutton:checked, popover.background.magnifier button.sidebar-button:checked, .osd button.flat:active, .osd button.titlebutton:active, .osd button.sidebar-button:active, .osd button.flat:checked, .osd button.titlebutton:checked, .osd button.sidebar-button:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.selection-mode button.titlebutton, button.suggested-action { color: white; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #13569d, #125194 60%, #114c8b); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

button.suggested-action.titlebutton, .selection-mode button.titlebutton, button.suggested-action.sidebar-button, notebook > header > tabs > arrow.suggested-action, popover.background checkbutton.suggested-action, popover.background radiobutton.suggested-action, button.suggested-action.flat, popover.background checkbutton.suggested-action, popover.background radiobutton.suggested-action { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #145ba6; }

button.suggested-action:hover, .selection-mode button.titlebutton:hover { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #061d34; background-image: linear-gradient(to bottom, #155eaa, #13569d 60%, #125194); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

button.suggested-action:active, .selection-mode button.titlebutton:active, button.suggested-action:checked, .selection-mode button.titlebutton:checked { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #061d34; background-image: linear-gradient(to bottom, #0f457d, #114f8f); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

notebook > header > tabs > arrow.suggested-action:backdrop, popover.background checkbutton.suggested-action:backdrop, popover.background radiobutton.suggested-action:backdrop, button.suggested-action:backdrop, .selection-mode button.titlebutton:backdrop, button.suggested-action.flat:backdrop { border-color: #061d34; background-color: #145ba6; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow.suggested-action:backdrop label, popover.background checkbutton.suggested-action:backdrop label, popover.background radiobutton.suggested-action:backdrop label, notebook > header > tabs > arrow.suggested-action:backdrop, popover.background checkbutton.suggested-action:backdrop, popover.background radiobutton.suggested-action:backdrop, button.suggested-action:backdrop label, .selection-mode button.titlebutton:backdrop label, button.suggested-action:backdrop, .selection-mode button.titlebutton:backdrop, button.suggested-action.flat:backdrop label, button.suggested-action.flat:backdrop { color: #d0deed; }

notebook > header > tabs > arrow.suggested-action:backdrop:active, popover.background checkbutton.suggested-action:backdrop:active, popover.background radiobutton.suggested-action:backdrop:active, notebook > header > tabs > arrow.suggested-action:backdrop:checked, popover.background checkbutton.suggested-action:backdrop:checked, popover.background radiobutton.suggested-action:backdrop:checked, button.suggested-action:backdrop:active, .selection-mode button.titlebutton:backdrop:active, button.suggested-action:backdrop:checked, .selection-mode button.titlebutton:backdrop:checked, button.suggested-action.flat:backdrop:active, button.suggested-action.flat:backdrop:checked { border-color: #061d34; background-color: #0f4278; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow.suggested-action:backdrop:active label, popover.background checkbutton.suggested-action:backdrop:active label, popover.background radiobutton.suggested-action:backdrop:active label, notebook > header > tabs > arrow.suggested-action:backdrop:active, popover.background checkbutton.suggested-action:backdrop:active, popover.background radiobutton.suggested-action:backdrop:active, notebook > header > tabs > arrow.suggested-action:backdrop:checked label, popover.background checkbutton.suggested-action:backdrop:checked label, popover.background radiobutton.suggested-action:backdrop:checked label, notebook > header > tabs > arrow.suggested-action:backdrop:checked, popover.background checkbutton.suggested-action:backdrop:checked, popover.background radiobutton.suggested-action:backdrop:checked, button.suggested-action:backdrop:active label, .selection-mode button.titlebutton:backdrop:active label, button.suggested-action:backdrop:active, .selection-mode button.titlebutton:backdrop:active, button.suggested-action:backdrop:checked label, .selection-mode button.titlebutton:backdrop:checked label, button.suggested-action:backdrop:checked, .selection-mode button.titlebutton:backdrop:checked, button.suggested-action.flat:backdrop:active label, button.suggested-action.flat:backdrop:active, button.suggested-action.flat:backdrop:checked label, button.suggested-action.flat:backdrop:checked { color: #cfd9e4; }

label:disabled selection:backdrop, notebook > header > tabs > arrow.suggested-action:backdrop:disabled, popover.background checkbutton.suggested-action:backdrop:disabled, popover.background radiobutton.suggested-action:backdrop:disabled, button.suggested-action:backdrop:disabled, .selection-mode button.titlebutton:backdrop:disabled, button.suggested-action.flat:backdrop:disabled { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop label, label:disabled selection:backdrop, notebook > header > tabs > arrow.suggested-action:backdrop:disabled label, popover.background checkbutton.suggested-action:backdrop:disabled label, popover.background radiobutton.suggested-action:backdrop:disabled label, notebook > header > tabs > arrow.suggested-action:backdrop:disabled, popover.background checkbutton.suggested-action:backdrop:disabled, popover.background radiobutton.suggested-action:backdrop:disabled, button.suggested-action:backdrop:disabled label, .selection-mode button.titlebutton:backdrop:disabled label, button.suggested-action:backdrop:disabled, .selection-mode button.titlebutton:backdrop:disabled, button.suggested-action.flat:backdrop:disabled label, button.suggested-action.flat:backdrop:disabled { color: #606567; }

label:disabled selection:backdrop:active, label:disabled selection:backdrop:checked, notebook > header > tabs > arrow.suggested-action:backdrop:disabled:active, popover.background checkbutton.suggested-action:backdrop:disabled:active, popover.background radiobutton.suggested-action:backdrop:disabled:active, notebook > header > tabs > arrow.suggested-action:backdrop:disabled:checked, popover.background checkbutton.suggested-action:backdrop:disabled:checked, popover.background radiobutton.suggested-action:backdrop:disabled:checked, button.suggested-action:backdrop:disabled:active, .selection-mode button.titlebutton:backdrop:disabled:active, button.suggested-action:backdrop:disabled:checked, .selection-mode button.titlebutton:backdrop:disabled:checked, button.suggested-action.flat:backdrop:disabled:active, button.suggested-action.flat:backdrop:disabled:checked { border-color: #061d34; background-color: #14487e; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop:active label, label:disabled selection:backdrop:checked label, notebook > header > tabs > arrow.suggested-action:backdrop:disabled:active label, popover.background checkbutton.suggested-action:backdrop:disabled:active label, popover.background radiobutton.suggested-action:backdrop:disabled:active label, notebook > header > tabs > arrow.suggested-action:backdrop:disabled:checked label, popover.background checkbutton.suggested-action:backdrop:disabled:checked label, popover.background radiobutton.suggested-action:backdrop:disabled:checked label, button.suggested-action:backdrop:disabled:active label, .selection-mode button.titlebutton:backdrop:disabled:active label, button.suggested-action:backdrop:disabled:checked label, .selection-mode button.titlebutton:backdrop:disabled:checked label, button.suggested-action.flat:backdrop:disabled:active label, button.suggested-action.flat:backdrop:disabled:checked label { color: #6788ab; }

button.suggested-action.titlebutton:backdrop, .selection-mode button.titlebutton:backdrop, button.suggested-action.sidebar-button:backdrop, notebook > header > tabs > arrow.suggested-action:backdrop, popover.background checkbutton.suggested-action:backdrop, popover.background radiobutton.suggested-action:backdrop, button.suggested-action.titlebutton:disabled, .selection-mode button.titlebutton:disabled, button.suggested-action.sidebar-button:disabled, notebook > header > tabs > arrow.suggested-action:disabled, popover.background checkbutton.suggested-action:disabled, popover.background radiobutton.suggested-action:disabled, label:disabled selection.flat, label:disabled selection:backdrop, button.suggested-action.flat:backdrop, button.suggested-action.flat:disabled, button.suggested-action.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(20, 91, 166, 0.8); }

label:disabled selection.suggested-action, button.suggested-action:disabled, .selection-mode button.titlebutton:disabled { border-color: #061d34; background-color: #185594; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.suggested-action label, label:disabled selection.suggested-action, button.suggested-action:disabled label, .selection-mode button.titlebutton:disabled label, button.suggested-action:disabled, .selection-mode button.titlebutton:disabled { color: #8caaca; }

label:disabled selection.suggested-action:active, label:disabled selection.suggested-action:checked, button.suggested-action:disabled:active, .selection-mode button.titlebutton:disabled:active, button.suggested-action:disabled:checked, .selection-mode button.titlebutton:disabled:checked { border-color: #061d34; background-image: linear-gradient(to bottom, #134477, #14487e); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.suggested-action:active label, label:disabled selection.suggested-action:active, label:disabled selection.suggested-action:checked label, label:disabled selection.suggested-action:checked, button.suggested-action:disabled:active label, .selection-mode button.titlebutton:disabled:active label, button.suggested-action:disabled:active, .selection-mode button.titlebutton:disabled:active, button.suggested-action:disabled:checked label, .selection-mode button.titlebutton:disabled:checked label, button.suggested-action:disabled:checked, .selection-mode button.titlebutton:disabled:checked { color: #a1b6cb; }

.osd button.suggested-action, .osd .selection-mode button.titlebutton, .selection-mode .osd button.titlebutton { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(20, 91, 166, 0.5); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.suggested-action:hover, .osd .selection-mode button.titlebutton:hover, .selection-mode .osd button.titlebutton:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(20, 91, 166, 0.7); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.suggested-action:active:backdrop, .osd button.suggested-action:active, .osd .selection-mode button.titlebutton:active, .selection-mode .osd button.titlebutton:active, .osd button.suggested-action:checked:backdrop, .osd button.suggested-action:checked, .osd .selection-mode button.titlebutton:checked, .selection-mode .osd button.titlebutton:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: #145ba6; background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd label:disabled selection.suggested-action, label:disabled .osd selection.suggested-action, .osd button.suggested-action:disabled:backdrop, .osd button.suggested-action:disabled, .osd .selection-mode button.titlebutton:disabled, .selection-mode .osd button.titlebutton:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd button.suggested-action:backdrop, .osd .selection-mode button.titlebutton:backdrop, .selection-mode .osd button.titlebutton:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(20, 91, 166, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode button.destructive-action.titlebutton, button.destructive-action { color: white; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #cc0f0f, #c20f0f 60%, #b90e0e); box-shadow: inset 0 1px rgba(255, 255, 255, 0.2); }

button.destructive-action.titlebutton, button.destructive-action.sidebar-button, notebook > header > tabs > arrow.destructive-action, popover.background checkbutton.destructive-action, popover.background radiobutton.destructive-action, button.destructive-action.flat, popover.background checkbutton.destructive-action, popover.background radiobutton.destructive-action { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #d51010; }

button.destructive-action:hover { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #5e0707; background-image: linear-gradient(to bottom, #da1010, #cc0f0f 60%, #c20f0f); box-shadow: inset 0 1px rgba(255, 255, 255, 0.2); }

button.destructive-action:active, button.destructive-action:checked { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #5e0707; background-image: linear-gradient(to bottom, #aa0d0d, #bd0e0e); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

notebook > header > tabs > arrow.destructive-action:backdrop, popover.background checkbutton.destructive-action:backdrop, popover.background radiobutton.destructive-action:backdrop, button.destructive-action:backdrop, button.destructive-action.flat:backdrop { border-color: #5e0707; background-color: #d51010; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow.destructive-action:backdrop label, popover.background checkbutton.destructive-action:backdrop label, popover.background radiobutton.destructive-action:backdrop label, notebook > header > tabs > arrow.destructive-action:backdrop, popover.background checkbutton.destructive-action:backdrop, popover.background radiobutton.destructive-action:backdrop, button.destructive-action:backdrop label, button.destructive-action:backdrop, button.destructive-action.flat:backdrop label, button.destructive-action.flat:backdrop { color: #f7cfcf; }

notebook > header > tabs > arrow.destructive-action:backdrop:active, popover.background checkbutton.destructive-action:backdrop:active, popover.background radiobutton.destructive-action:backdrop:active, notebook > header > tabs > arrow.destructive-action:backdrop:checked, popover.background checkbutton.destructive-action:backdrop:checked, popover.background radiobutton.destructive-action:backdrop:checked, button.destructive-action:backdrop:active, button.destructive-action:backdrop:checked, button.destructive-action.flat:backdrop:active, button.destructive-action.flat:backdrop:checked { border-color: #5e0707; background-color: #a60c0c; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow.destructive-action:backdrop:active label, popover.background checkbutton.destructive-action:backdrop:active label, popover.background radiobutton.destructive-action:backdrop:active label, notebook > header > tabs > arrow.destructive-action:backdrop:active, popover.background checkbutton.destructive-action:backdrop:active, popover.background radiobutton.destructive-action:backdrop:active, notebook > header > tabs > arrow.destructive-action:backdrop:checked label, popover.background checkbutton.destructive-action:backdrop:checked label, popover.background radiobutton.destructive-action:backdrop:checked label, notebook > header > tabs > arrow.destructive-action:backdrop:checked, popover.background checkbutton.destructive-action:backdrop:checked, popover.background radiobutton.destructive-action:backdrop:checked, button.destructive-action:backdrop:active label, button.destructive-action:backdrop:active, button.destructive-action:backdrop:checked label, button.destructive-action:backdrop:checked, button.destructive-action.flat:backdrop:active label, button.destructive-action.flat:backdrop:active, button.destructive-action.flat:backdrop:checked label, button.destructive-action.flat:backdrop:checked { color: #edcece; }

label:disabled selection:backdrop, notebook > header > tabs > arrow.destructive-action:backdrop:disabled, popover.background checkbutton.destructive-action:backdrop:disabled, popover.background radiobutton.destructive-action:backdrop:disabled, button.destructive-action:backdrop:disabled, button.destructive-action.flat:backdrop:disabled { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop label, label:disabled selection:backdrop, notebook > header > tabs > arrow.destructive-action:backdrop:disabled label, popover.background checkbutton.destructive-action:backdrop:disabled label, popover.background radiobutton.destructive-action:backdrop:disabled label, notebook > header > tabs > arrow.destructive-action:backdrop:disabled, popover.background checkbutton.destructive-action:backdrop:disabled, popover.background radiobutton.destructive-action:backdrop:disabled, button.destructive-action:backdrop:disabled label, button.destructive-action:backdrop:disabled, button.destructive-action.flat:backdrop:disabled label, button.destructive-action.flat:backdrop:disabled { color: #606567; }

label:disabled selection:backdrop:active, label:disabled selection:backdrop:checked, notebook > header > tabs > arrow.destructive-action:backdrop:disabled:active, popover.background checkbutton.destructive-action:backdrop:disabled:active, popover.background radiobutton.destructive-action:backdrop:disabled:active, notebook > header > tabs > arrow.destructive-action:backdrop:disabled:checked, popover.background checkbutton.destructive-action:backdrop:disabled:checked, popover.background radiobutton.destructive-action:backdrop:disabled:checked, button.destructive-action:backdrop:disabled:active, button.destructive-action:backdrop:disabled:checked, button.destructive-action.flat:backdrop:disabled:active, button.destructive-action.flat:backdrop:disabled:checked { border-color: #5e0707; background-color: #a51212; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop:active label, label:disabled selection:backdrop:checked label, notebook > header > tabs > arrow.destructive-action:backdrop:disabled:active label, popover.background checkbutton.destructive-action:backdrop:disabled:active label, popover.background radiobutton.destructive-action:backdrop:disabled:active label, notebook > header > tabs > arrow.destructive-action:backdrop:disabled:checked label, popover.background checkbutton.destructive-action:backdrop:disabled:checked label, popover.background radiobutton.destructive-action:backdrop:disabled:checked label, button.destructive-action:backdrop:disabled:active label, button.destructive-action:backdrop:disabled:checked label, button.destructive-action.flat:backdrop:disabled:active label, button.destructive-action.flat:backdrop:disabled:checked label { color: #c46565; }

button.destructive-action.titlebutton:backdrop, button.destructive-action.sidebar-button:backdrop, notebook > header > tabs > arrow.destructive-action:backdrop, popover.background checkbutton.destructive-action:backdrop, popover.background radiobutton.destructive-action:backdrop, button.destructive-action.titlebutton:disabled, button.destructive-action.sidebar-button:disabled, notebook > header > tabs > arrow.destructive-action:disabled, popover.background checkbutton.destructive-action:disabled, popover.background radiobutton.destructive-action:disabled, label:disabled selection.flat, label:disabled selection:backdrop, button.destructive-action.flat:backdrop, button.destructive-action.flat:disabled, button.destructive-action.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(213, 16, 16, 0.8); }

label:disabled selection.destructive-action, button.destructive-action:disabled { border-color: #5e0707; background-color: #bc1415; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.destructive-action label, label:disabled selection.destructive-action, button.destructive-action:disabled label, button.destructive-action:disabled { color: #de8a8a; }

label:disabled selection.destructive-action:active, label:disabled selection.destructive-action:checked, button.destructive-action:disabled:active, button.destructive-action:disabled:checked { border-color: #5e0707; background-image: linear-gradient(to bottom, #9e1011, #a51212); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.destructive-action:active label, label:disabled selection.destructive-action:active, label:disabled selection.destructive-action:checked label, label:disabled selection.destructive-action:checked, button.destructive-action:disabled:active label, button.destructive-action:disabled:active, button.destructive-action:disabled:checked label, button.destructive-action:disabled:checked { color: #dba0a0; }

.osd button.destructive-action { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(213, 16, 16, 0.5); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.destructive-action:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(213, 16, 16, 0.7); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.destructive-action:active:backdrop, .osd button.destructive-action:active, .osd button.destructive-action:checked:backdrop, .osd button.destructive-action:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: #d51010; background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd label:disabled selection.destructive-action, label:disabled .osd selection.destructive-action, .osd button.destructive-action:disabled:backdrop, .osd button.destructive-action:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd button.destructive-action:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(213, 16, 16, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode .stack-switcher > button.titlebutton, .stack-switcher > button { outline-offset: -3px; }

.selection-mode .stack-switcher > button.titlebutton > label, .stack-switcher > button > label { padding-left: 6px; padding-right: 6px; }

.selection-mode .stack-switcher > button.titlebutton > image, .stack-switcher > button > image { padding-left: 6px; padding-right: 6px; padding-top: 3px; padding-bottom: 3px; }

.selection-mode .stack-switcher > button.text-button.titlebutton, .stack-switcher > button.text-button { padding-left: 10px; padding-right: 10px; }

.selection-mode .stack-switcher > button.image-button.titlebutton, .stack-switcher > button.image-button { padding-left: 2px; padding-right: 2px; }

.stack-switcher > button.needs-attention:active > label, .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label, .stack-switcher > button.needs-attention:checked > image { animation: none; background-image: none; }

.inline-toolbar .selection-mode button.titlebutton, .selection-mode .inline-toolbar button.titlebutton, .inline-toolbar button, .inline-toolbar button:backdrop { border-radius: 2px; border-width: 1px; }

.inline-toolbar .selection-mode button.titlebutton button, .selection-mode .inline-toolbar button.titlebutton button, .inline-toolbar button button, .inline-toolbar button:backdrop button { padding-left: 4px; padding-right: 4px; }

.primary-toolbar .selection-mode button.titlebutton, .selection-mode .primary-toolbar button.titlebutton, .primary-toolbar button { -gtk-icon-shadow: none; }

.selection-mode button.circular.titlebutton, button.circular { border-radius: 9999px; -gtk-outline-radius: 9999px; }

.selection-mode button.circular.titlebutton label, button.circular label { padding: 0; }

stacksidebar row.needs-attention > label, .selection-mode .stack-switcher > button.needs-attention.titlebutton > label, .selection-mode .stack-switcher > button.needs-attention.titlebutton > image, .stack-switcher > button.needs-attention > label, .stack-switcher > button.needs-attention > image { animation: needs_attention 150ms ease-in; background-image: radial-gradient(farthest-side, #2281e4 96%, rgba(34, 129, 228, 0)), radial-gradient(farthest-side, rgba(0, 0, 0, 0.808627) 95%, rgba(0, 0, 0, 0)); background-size: 6px 6px, 6px 6px; background-repeat: no-repeat; background-position: right 3px, right 2px; }

stacksidebar row.needs-attention > label:backdrop, .stack-switcher > button.needs-attention > label:backdrop, .stack-switcher > button.needs-attention > image:backdrop { background-size: 6px 6px, 0 0; }

stacksidebar row.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > image:dir(rtl) { background-position: left 3px, left 2px; }

.inline-toolbar toolbutton > button { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #36393a, #313434 60%, #2c2e2f); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

.inline-toolbar toolbutton > button:hover { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3d4142, #36393a 60%, #313434); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #252727, #2f3132); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

.inline-toolbar toolbutton > button:disabled { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:disabled label, .inline-toolbar toolbutton > button:disabled { color: #959696; }

.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked { border-color: #1d1f1f; background-image: linear-gradient(to bottom, #333536, #353839); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:disabled:active label, .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked label, .inline-toolbar toolbutton > button:disabled:checked { color: #959696; }

.inline-toolbar toolbutton > button:backdrop { border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop label, .inline-toolbar toolbutton > button:backdrop { color: #959696; }

.inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked { border-color: #202223; background-color: #323435; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:active label, .inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked label, .inline-toolbar toolbutton > button:backdrop:checked { color: #959696; }

.inline-toolbar toolbutton > button:backdrop:disabled, .inline-toolbar label:disabled toolbutton > selection:backdrop, label:disabled .inline-toolbar toolbutton > selection:backdrop { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:disabled label, .inline-toolbar label:disabled toolbutton > selection:backdrop label, label:disabled .inline-toolbar toolbutton > selection:backdrop label, .inline-toolbar toolbutton > button:backdrop:disabled, .inline-toolbar label:disabled toolbutton > selection:backdrop, label:disabled .inline-toolbar toolbutton > selection:backdrop { color: #606567; }

.inline-toolbar toolbutton > button:backdrop:disabled:active, .inline-toolbar label:disabled toolbutton > selection:backdrop:active, label:disabled .inline-toolbar toolbutton > selection:backdrop:active, .inline-toolbar toolbutton > button:backdrop:disabled:checked, .inline-toolbar label:disabled toolbutton > selection:backdrop:checked, label:disabled .inline-toolbar toolbutton > selection:backdrop:checked { border-color: #202223; background-color: #292b2c; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:disabled:active label, .inline-toolbar label:disabled toolbutton > selection:backdrop:active label, label:disabled .inline-toolbar toolbutton > selection:backdrop:active label, .inline-toolbar toolbutton > button:backdrop:disabled:checked label, .inline-toolbar label:disabled toolbutton > selection:backdrop:checked label, label:disabled .inline-toolbar toolbutton > selection:backdrop:checked label { color: #606567; }

.linked > combobox > box > button.combo:dir(ltr), .linked > combobox > box > button.combo:dir(rtl), .xfce4-panel.background menu .linked button, .linked:not(.vertical) > combobox:only-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo, combobox.linked button:nth-child(2):dir(rtl), combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry, .inline-toolbar .selection-mode button.titlebutton, .selection-mode .inline-toolbar button.titlebutton, .inline-toolbar button, .inline-toolbar button:backdrop, .selection-mode .linked:not(.vertical) > button.titlebutton, .linked:not(.vertical) > button, toolbar.inline-toolbar toolbutton > button.flat, toolbar.inline-toolbar toolbutton > button.titlebutton, toolbar.inline-toolbar toolbutton > button.sidebar-button { border-right-style: none; border-radius: 0; -gtk-outline-radius: 0; }

.linked.vertical > combobox:last-child > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox:last-child > box > button.combo:dir(rtl), .linked.vertical > combobox:first-child > box > button.combo:dir(ltr), .xfce4-panel.background menu .linked button:first-child, .xfce4-panel.background menu .linked.vertical > combobox:first-child > box > button.combo, .linked:not(.vertical) > combobox:only-child > box > button.combo:first-child, .linked:not(.vertical) > combobox:last-child > box > button.combo:first-child, .linked:not(.vertical) > combobox:first-child > box > button.combo, combobox.linked button:nth-child(2):dir(rtl), combobox.linked button:first-child:nth-child(2):dir(ltr), .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child, .inline-toolbar button:first-child, .inline-toolbar .linked.vertical > combobox:first-child > box > button.combo, .inline-toolbar button:first-child:backdrop, .selection-mode .linked:not(.vertical) > button.titlebutton:first-child, .linked:not(.vertical) > button:first-child, .linked.vertical > combobox:first-child > box.linked:not(.vertical) > button.combo, toolbar.inline-toolbar toolbutton:first-child > button.flat, toolbar.inline-toolbar .selection-mode toolbutton:first-child > button.titlebutton, toolbar.inline-toolbar toolbutton:first-child > button.titlebutton, toolbar.inline-toolbar toolbutton:first-child > button.sidebar-button { border-top-left-radius: 3px; border-bottom-left-radius: 3px; -gtk-outline-top-left-radius: 3px; -gtk-outline-bottom-left-radius: 3px; }

.linked.vertical > combobox:first-child > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo:dir(rtl), combobox.linked button:dir(rtl):nth-child(2), .linked.vertical > combobox:last-child > box > button.combo:dir(ltr), combobox.linked button:dir(ltr):nth-child(2), .xfce4-panel.background menu .linked button:last-child, .xfce4-panel.background menu .linked.vertical > combobox:last-child > box > button.combo, .linked:not(.vertical) > combobox:only-child > box > button.combo:last-child, .linked:not(.vertical) > combobox:last-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo:last-child, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child, .inline-toolbar button:last-child, .inline-toolbar .linked.vertical > combobox:last-child > box > button.combo, .inline-toolbar button:last-child:backdrop, .selection-mode .linked:not(.vertical) > button.titlebutton:last-child, .linked:not(.vertical) > button:last-child, .linked.vertical > combobox:last-child > box.linked:not(.vertical) > button.combo, toolbar.inline-toolbar toolbutton:last-child > button.flat, toolbar.inline-toolbar .selection-mode toolbutton:last-child > button.titlebutton, toolbar.inline-toolbar toolbutton:last-child > button.titlebutton, toolbar.inline-toolbar toolbutton:last-child > button.sidebar-button { border-right-style: solid; border-top-right-radius: 3px; border-bottom-right-radius: 3px; -gtk-outline-top-right-radius: 3px; -gtk-outline-bottom-right-radius: 3px; }

.xfce4-panel.background menu .linked button:only-child, .xfce4-panel.background menu .linked.vertical > combobox:only-child > box > button.combo, .linked:not(.vertical) > combobox:only-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo:only-child, .linked:not(.vertical) > combobox:first-child > box > button.combo:only-child, combobox.linked button:only-child:nth-child(2):dir(rtl), combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(rtl), combobox.linked button:only-child:nth-child(2):dir(ltr), combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(ltr), .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child, .inline-toolbar button:only-child, .inline-toolbar .linked.vertical > combobox:only-child > box > button.combo, .inline-toolbar button:only-child:backdrop, .selection-mode .linked:not(.vertical) > button.titlebutton:only-child, .linked:not(.vertical) > button:only-child, .linked.vertical > combobox:only-child > box.linked:not(.vertical) > button.combo, toolbar.inline-toolbar toolbutton:only-child > button.flat, toolbar.inline-toolbar .selection-mode toolbutton:only-child > button.titlebutton, toolbar.inline-toolbar toolbutton:only-child > button.titlebutton, toolbar.inline-toolbar toolbutton:only-child > button.sidebar-button { border-style: solid; border-radius: 3px; -gtk-outline-radius: 3px; }

.linked.vertical > combobox > box > button.combo, .linked.vertical > combobox:only-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo, .linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry, .selection-mode .linked.vertical > button.titlebutton, .linked.vertical > button { border-style: solid solid none solid; border-radius: 0; -gtk-outline-radius: 0; }

.linked.vertical > combobox:only-child > box > button.combo:first-child, .linked.vertical > combobox:last-child > box > button.combo:first-child, .linked.vertical > combobox:first-child > box > button.combo, combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(rtl), combobox.linked .linked.vertical > combobox:last-child > box > button.combo:nth-child(2):dir(rtl), .linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child, .selection-mode .linked.vertical > button.titlebutton:first-child, .linked.vertical > button:first-child, .linked:not(.vertical) > combobox:first-child > box.linked.vertical > button.combo, combobox.linked .linked.vertical > button:nth-child(2):dir(rtl) { border-top-left-radius: 3px; border-top-right-radius: 3px; -gtk-outline-top-left-radius: 3px; -gtk-outline-top-right-radius: 3px; }

.linked.vertical > combobox:only-child > box > button.combo:last-child, .linked.vertical > combobox:last-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo:last-child, combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(ltr), combobox.linked .linked.vertical > combobox:first-child > box > button.combo:nth-child(2):dir(ltr), .linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child, .selection-mode .linked.vertical > button.titlebutton:last-child, .linked.vertical > button:last-child, .linked:not(.vertical) > combobox:last-child > box.linked.vertical > button.combo, combobox.linked .linked.vertical > button:nth-child(2):dir(ltr) { border-bottom-style: solid; border-bottom-left-radius: 3px; border-bottom-right-radius: 3px; -gtk-outline-bottom-left-radius: 3px; -gtk-outline-bottom-right-radius: 3px; }

.linked.vertical > combobox:only-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo:only-child, .linked.vertical > combobox:first-child > box > button.combo:only-child, .linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child, .selection-mode .linked.vertical > button.titlebutton:only-child, .linked.vertical > button:only-child, .linked:not(.vertical) > combobox:only-child > box.linked.vertical > button.combo { border-style: solid; border-radius: 3px; -gtk-outline-radius: 3px; }

.scale-popup button:backdrop:hover, .scale-popup button:backdrop:disabled, .scale-popup label:disabled selection:backdrop, label:disabled .scale-popup selection:backdrop, .scale-popup button:backdrop, .scale-popup button:hover, calendar.button, button:link:hover, headerbar.selection-mode button.subtitle:hover:link, button:link:active, headerbar.selection-mode button.subtitle:active:link, button:link:checked, headerbar.selection-mode button.subtitle:checked:link, button:visited:hover, button:visited:active, button:visited:checked, button:link, .selection-mode.titlebar:not(headerbar) button.subtitle:link, headerbar.selection-mode button.subtitle:link, button:visited, modelbutton.flat:backdrop, popover.background checkbutton.flat:backdrop, popover.background radiobutton.flat:backdrop, modelbutton.flat:backdrop:hover, modelbutton.flat, popover.background checkbutton.flat, popover.background radiobutton.flat, .menuitem.button.flat, .selection-mode button.button.titlebutton, button.button.titlebutton, button.button.sidebar-button, notebook > header > tabs > arrow.button, popover.background checkbutton.button, popover.background radiobutton.button { background-color: transparent; background-image: none; border-color: transparent; box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

/* menu buttons */
modelbutton.flat, popover.background checkbutton.flat, popover.background radiobutton.flat, .menuitem.button.flat, .selection-mode button.button.titlebutton, button.button.titlebutton, button.button.sidebar-button, notebook > header > tabs > arrow.button, popover.background checkbutton.button, popover.background radiobutton.button { min-height: 26px; padding-left: 5px; padding-right: 5px; border-radius: 3px; outline-offset: -2px; }

modelbutton.flat:hover, popover.background checkbutton.flat:hover, popover.background radiobutton.flat:hover, .menuitem.button.flat:hover, button.button.titlebutton:hover, button.button.sidebar-button:hover, notebook > header > tabs > arrow.button:hover, popover.background checkbutton.button:hover, popover.background radiobutton.button:hover { background-color: #145ba6; }

modelbutton.flat:disabled, popover.background checkbutton.flat:disabled, popover.background radiobutton.flat:disabled, .menuitem.button.flat:disabled, button.button.titlebutton:disabled, button.button.sidebar-button:disabled, notebook > header > tabs > arrow.button:disabled, popover.background checkbutton.button:disabled, popover.background radiobutton.button:disabled, label:disabled selection.flat { color: #959696; }

modelbutton.flat:disabled:backdrop, popover.background checkbutton.flat:disabled:backdrop, popover.background radiobutton.flat:disabled:backdrop, label:disabled selection.flat:backdrop, .menuitem.button.flat:disabled:backdrop, button.button.titlebutton:disabled:backdrop, button.button.sidebar-button:disabled:backdrop, notebook > header > tabs > arrow.button:disabled:backdrop, popover.background checkbutton.button:disabled:backdrop, popover.background radiobutton.button:disabled:backdrop { color: #606567; }

modelbutton.flat arrow, popover.background checkbutton.flat arrow, popover.background radiobutton.flat arrow { background: none; }

modelbutton.flat arrow:hover, popover.background checkbutton.flat arrow:hover, popover.background radiobutton.flat arrow:hover { background: none; }

modelbutton.flat arrow.left, popover.background checkbutton.flat arrow.left, popover.background radiobutton.flat arrow.left { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

modelbutton.flat arrow.right, popover.background checkbutton.flat arrow.right, popover.background radiobutton.flat arrow.right { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

button.color { padding: 4px; }

button.color colorswatch:only-child, button.color colorswatch:only-child overlay { border-radius: 0; }

/********* Links * */
button:link > label, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, headerbar.selection-mode button.subtitle:link > label, button:visited > label, button:link, headerbar.selection-mode button.subtitle:link, button:visited, *:link, .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link { color: #6fa4dc; }

button:link > label:visited, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:visited, headerbar.selection-mode button.subtitle:link > label:visited, button:visited > label:visited, button:visited, *:link:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link:visited, headerbar.selection-mode .subtitle:link:visited { color: #1a74d3; }

*:selected button:link > label:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:visited, headerbar.selection-mode .subtitle:link button:link > label:visited, *:selected .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:visited, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:visited, .selection-mode.titlebar:not(headerbar) *:selected button.subtitle:link > label:visited, *:selected headerbar.selection-mode button.subtitle:link > label:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:visited, headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label:visited, headerbar.selection-mode *:selected button.subtitle:link > label:visited, *:selected button:visited > label:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:visited, headerbar.selection-mode .subtitle:link button:visited > label:visited, *:selected button:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, headerbar.selection-mode .subtitle:link button:visited, *:selected *:link:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:visited, headerbar.selection-mode .subtitle:link *:link:visited, *:selected .selection-mode.titlebar:not(headerbar) .subtitle:link:visited, .selection-mode.titlebar:not(headerbar) *:selected .subtitle:link:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link:visited, *:selected headerbar.selection-mode .subtitle:link:visited, headerbar.selection-mode *:selected .subtitle:link:visited, headerbar.selection-mode .subtitle:link .subtitle:link:visited { color: #a1bedb; }

button:link > label:hover, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, headerbar.selection-mode button.subtitle:link > label:hover, button:visited > label:hover, button:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, headerbar.selection-mode .subtitle:hover:link, button:hover:visited, *:link:hover { color: #98bee6; }

*:selected button:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:hover, headerbar.selection-mode .subtitle:link button:link > label:hover, *:selected .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) *:selected button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label:hover, *:selected headerbar.selection-mode button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:hover, headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label:hover, headerbar.selection-mode *:selected button.subtitle:link > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label:hover, headerbar.selection-mode .subtitle:link button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link headerbar.selection-mode button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:hover, headerbar.selection-mode .subtitle:selected:link button:link > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label:hover, headerbar.selection-mode .subtitle:link button:link > label:hover, headerbar.selection-mode .subtitle:selected:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:hover, *:selected button:visited > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:hover, headerbar.selection-mode .subtitle:link button:visited > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:hover, headerbar.selection-mode .subtitle:selected:link button:visited > label:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label:hover, headerbar.selection-mode .subtitle:link button:visited > label:hover, *:selected button:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:link, headerbar.selection-mode .subtitle:link button:hover:link, *:selected .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) *:selected .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:hover:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:hover:link, *:selected headerbar.selection-mode .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:hover:link, headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:hover:link, headerbar.selection-mode *:selected .subtitle:hover:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:hover:link, headerbar.selection-mode .subtitle:link .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:hover:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:hover:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:hover:link, headerbar.selection-mode .subtitle:selected:link button:hover:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:hover:link, headerbar.selection-mode .subtitle:link button:hover:link, headerbar.selection-mode .subtitle:selected:link .subtitle:hover:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:hover:link, headerbar.selection-mode .subtitle:link .subtitle:hover:link, *:selected button:hover:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:visited, headerbar.selection-mode .subtitle:link button:hover:visited, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:hover:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:hover:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:visited, headerbar.selection-mode .subtitle:selected:link button:hover:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:hover:visited, headerbar.selection-mode .subtitle:link button:hover:visited, *:selected *:link:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:hover, headerbar.selection-mode .subtitle:link *:link:hover, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link *:link:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:hover, headerbar.selection-mode .subtitle:selected:link *:link:hover, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:hover, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link:hover, headerbar.selection-mode .subtitle:link *:link:hover { color: #e8eff6; }

button:link > label:active, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, headerbar.selection-mode button.subtitle:link > label:active, button:visited > label:active, button:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:active:link, headerbar.selection-mode .subtitle:active:link, button:active:visited, *:link:active { color: #6fa4dc; }

*:selected button:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:active, headerbar.selection-mode .subtitle:link button:link > label:active, *:selected .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) *:selected button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label:active, *:selected headerbar.selection-mode button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:active, headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label:active, headerbar.selection-mode *:selected button.subtitle:link > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label:active, headerbar.selection-mode .subtitle:link button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link headerbar.selection-mode button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label:active, headerbar.selection-mode .subtitle:selected:link button:link > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label:active, headerbar.selection-mode .subtitle:link button:link > label:active, headerbar.selection-mode .subtitle:selected:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:active, *:selected button:visited > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:active, headerbar.selection-mode .subtitle:link button:visited > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:active, headerbar.selection-mode .subtitle:selected:link button:visited > label:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label:active, headerbar.selection-mode .subtitle:link button:visited > label:active, *:selected button:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:link, headerbar.selection-mode .subtitle:link button:active:link, *:selected .selection-mode.titlebar:not(headerbar) .subtitle:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:active:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:active:link, .selection-mode.titlebar:not(headerbar) *:selected .subtitle:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:active:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:active:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:active:link, *:selected headerbar.selection-mode .subtitle:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:active:link, headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:active:link, headerbar.selection-mode *:selected .subtitle:active:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:active:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:active:link, headerbar.selection-mode .subtitle:link .subtitle:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:active:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:active:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:active:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:active:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:active:link, headerbar.selection-mode .subtitle:selected:link button:active:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:active:link, headerbar.selection-mode .subtitle:link button:active:link, headerbar.selection-mode .subtitle:selected:link .subtitle:active:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:active:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:active:link, headerbar.selection-mode .subtitle:link .subtitle:active:link, *:selected button:active:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:visited, headerbar.selection-mode .subtitle:link button:active:visited, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:active:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:active:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:visited, headerbar.selection-mode .subtitle:selected:link button:active:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:active:visited, headerbar.selection-mode .subtitle:link button:active:visited, *:selected *:link:active, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:active, headerbar.selection-mode .subtitle:link *:link:active, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link *:link:active, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:active, headerbar.selection-mode .subtitle:selected:link *:link:active, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link:active, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link:active, headerbar.selection-mode .subtitle:link *:link:active { color: #d0deed; }

button:link > label:disabled, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:disabled, headerbar.selection-mode button.subtitle:link > label:disabled, button:visited > label:disabled, button:disabled:link, .selection-mode.titlebar:not(headerbar) .subtitle:disabled:link, headerbar.selection-mode .subtitle:disabled:link, button:disabled:visited, *:link:disabled, label:disabled selection:link, label:disabled .selection-mode.titlebar:not(headerbar) selection.subtitle:link, .selection-mode.titlebar:not(headerbar) label:disabled selection.subtitle:link, label:disabled headerbar.selection-mode selection.subtitle:link, headerbar.selection-mode label:disabled selection.subtitle:link, *:link:disabled:backdrop { color: rgba(166, 166, 166, 0.8); }

.selection-mode.titlebar:not(headerbar) .subtitle:hover:link, headerbar.selection-mode .subtitle:hover:link, button:link > label:backdrop, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:backdrop, headerbar.selection-mode button.subtitle:link > label:backdrop, button:visited > label:backdrop, button:backdrop:link, .selection-mode.titlebar:not(headerbar) .subtitle:backdrop:link, headerbar.selection-mode .subtitle:backdrop:link, button:backdrop:visited, *:link:backdrop:backdrop:hover, *:link:backdrop:backdrop:hover:selected, *:link:backdrop { color: #145ba6; }

.info *:link, .info headerbar.selection-mode .subtitle:link, headerbar.selection-mode .info .subtitle:link, .info .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .info .subtitle:link, .info .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .info .subtitle:link, .info headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .info .subtitle:link, .question *:link, .question headerbar.selection-mode .subtitle:link, headerbar.selection-mode .question .subtitle:link, .question .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .question .subtitle:link, .question .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .question .subtitle:link, .question headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .question .subtitle:link, .warning *:link, .warning headerbar.selection-mode .subtitle:link, headerbar.selection-mode .warning .subtitle:link, .warning .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .warning .subtitle:link, .warning .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .warning .subtitle:link, .warning headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .warning .subtitle:link, .error *:link, .error headerbar.selection-mode .subtitle:link, headerbar.selection-mode .error .subtitle:link, .error .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .error .subtitle:link, .error .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .error .subtitle:link, .error headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .error .subtitle:link, button:link > label:selected, .selection-mode.titlebar:not(headerbar) button:link > label.subtitle:link, headerbar.selection-mode button:link > label.subtitle:link, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label:selected, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode button.subtitle:link > label.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) button.subtitle:link > label.subtitle:link, headerbar.selection-mode button.subtitle:link > label:selected, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) button.subtitle:link > label.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode button.subtitle:link > label.subtitle:link, headerbar.selection-mode button.subtitle:link > label.subtitle:link, button:visited > label:selected, .selection-mode.titlebar:not(headerbar) button:visited > label.subtitle:link, headerbar.selection-mode button:visited > label.subtitle:link, button:selected:link, .selection-mode.titlebar:not(headerbar) button.subtitle:link, headerbar.selection-mode button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link, .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:selected:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link, button:selected:visited, .selection-mode.titlebar:not(headerbar) button.subtitle:visited:link, headerbar.selection-mode button.subtitle:visited:link, *:selected button:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label, headerbar.selection-mode .subtitle:link button:link > label, *:selected .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) *:selected button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, *:selected headerbar.selection-mode button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label, headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label, headerbar.selection-mode *:selected button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label, headerbar.selection-mode .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link headerbar.selection-mode button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link > label, headerbar.selection-mode .subtitle:selected:link button:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label, headerbar.selection-mode .subtitle:link button:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link > label, headerbar.selection-mode .subtitle:selected:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, headerbar.selection-mode .subtitle:selected:link button.subtitle:link > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link > label, headerbar.selection-mode .subtitle:link button.subtitle:link > label, *:selected button:visited > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, headerbar.selection-mode .subtitle:link button:visited > label, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:visited > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, headerbar.selection-mode .subtitle:selected:link button:visited > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label, headerbar.selection-mode .subtitle:link button:visited > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited > label, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:visited > label, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited > label, *:selected button:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link, headerbar.selection-mode .subtitle:link button:link, *:selected .selection-mode.titlebar:not(headerbar) button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link, .selection-mode.titlebar:not(headerbar) *:selected button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, *:selected headerbar.selection-mode button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link, headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link, headerbar.selection-mode *:selected button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link, headerbar.selection-mode .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link headerbar.selection-mode button.subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode button.subtitle:link, headerbar.selection-mode .subtitle:selected:link button:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link, headerbar.selection-mode .subtitle:link button:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:link, headerbar.selection-mode .subtitle:selected:link .selection-mode.titlebar:not(headerbar) button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, headerbar.selection-mode .subtitle:selected:link button.subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button.subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button.subtitle:link, headerbar.selection-mode .subtitle:link button.subtitle:link, *:selected button:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, headerbar.selection-mode .subtitle:link button:visited, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, headerbar.selection-mode .subtitle:selected:link button:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited, headerbar.selection-mode .subtitle:link button:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link button:visited, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link button:visited, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link button:visited, *:link:selected, .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) *.subtitle:selected:link, .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode *.subtitle:selected:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link:selected, .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link:selected, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, *:selected *:link, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link, headerbar.selection-mode .subtitle:link *:link, *:selected .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) *:selected .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, *:selected headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode *:selected .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link *:link, .selection-mode.titlebar:not(headerbar) .subtitle:link *:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link *:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link *:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:selected:link *:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link, headerbar.selection-mode .subtitle:link *:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link *:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link *:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link *:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link *:link, headerbar.selection-mode .subtitle:selected:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:selected:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:link .subtitle:link, *:selected .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, *:selected .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, headerbar.selection-mode *:selected .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) *:selected .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) *:selected headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) *:selected .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:selected:link headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, *:selected headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:link, *:selected headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) *:selected headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link headerbar.selection-mode .subtitle:link, headerbar.selection-mode *:selected .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode *:selected .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode *:selected .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:selected:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:selected:link .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:selected:link .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .subtitle:link, headerbar.selection-mode .subtitle:selected:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .subtitle:link .selection-mode.titlebar:not(headerbar) .subtitle:link { color: #d0deed; }

button:link, .selection-mode.titlebar:not(headerbar) button.subtitle:link, headerbar.selection-mode button.subtitle:link, button:visited { text-shadow: none; }

button:link:hover, .selection-mode.titlebar:not(headerbar) button.subtitle:hover:link, headerbar.selection-mode button.subtitle:hover:link, button:link:active, .selection-mode.titlebar:not(headerbar) button.subtitle:active:link, headerbar.selection-mode button.subtitle:active:link, button:link:checked, .selection-mode.titlebar:not(headerbar) button.subtitle:checked:link, headerbar.selection-mode button.subtitle:checked:link, button:visited:hover, button:visited:active, button:visited:checked { text-shadow: none; }

button:link > label, .selection-mode.titlebar:not(headerbar) button.subtitle:link > label, headerbar.selection-mode button.subtitle:link > label, button:visited > label { text-decoration-line: underline; }

/***************** GtkSpinButton * */
spinbutton:not(.vertical) { padding: 0; }

spinbutton:not(.vertical) entry { min-width: 28px; margin: 0; background: none; background-color: transparent; border: none; border-radius: 0; box-shadow: none; }

spinbutton:not(.vertical) button { min-height: 16px; margin: 0; padding-bottom: 0; padding-top: 0; color: #dbdbd9; background-image: none; border-style: none none none solid; border-color: rgba(29, 31, 31, 0.3); border-radius: 0; box-shadow: none; }

spinbutton:not(.vertical) button:dir(rtl) { border-style: none solid none none; }

spinbutton:not(.vertical) button:hover { color: #eeeeec; background-color: rgba(238, 238, 236, 0.05); }

spinbutton:not(.vertical) button:disabled { color: rgba(149, 150, 150, 0.3); background-color: transparent; }

spinbutton:not(.vertical) button:active { background-color: rgba(0, 0, 0, 0.1); box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.2); }

spinbutton:not(.vertical) button:backdrop { color: #8b8c8c; background-color: transparent; border-color: rgba(32, 34, 35, 0.3); transition: 200ms ease-out; }

spinbutton:not(.vertical) button:backdrop:disabled, spinbutton:not(.vertical) label:disabled selection:backdrop, label:disabled spinbutton:not(.vertical) selection:backdrop { color: rgba(96, 101, 103, 0.3); background-color: transparent; border-style: none none none solid; }

spinbutton:not(.vertical) button:backdrop:disabled:dir(rtl), spinbutton:not(.vertical) label:disabled selection:backdrop:dir(rtl), label:disabled spinbutton:not(.vertical) selection:backdrop:dir(rtl) { border-style: none solid none none; }

.osd spinbutton:not(.vertical) button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeee; border-style: none none none solid; border-color: rgba(0, 0, 0, 0.4); border-radius: 0; box-shadow: none; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:not(.vertical) button:dir(rtl) { border-style: none solid none none; }

.osd spinbutton:not(.vertical) button:hover { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeee; border-color: rgba(0, 0, 0, 0.5); background-color: rgba(238, 238, 238, 0.1); -gtk-icon-shadow: 0 1px black; box-shadow: none; }

.osd spinbutton:not(.vertical) button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeee; border-color: rgba(0, 0, 0, 0.5); -gtk-icon-shadow: none; box-shadow: none; }

.osd spinbutton:not(.vertical) button:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #888888; border-color: rgba(0, 0, 0, 0.5); -gtk-icon-shadow: none; box-shadow: none; }

.osd spinbutton:not(.vertical) button:dir(ltr):last-child, .osd spinbutton:not(.vertical) .linked.vertical > combobox:last-child > box > button.combo:dir(ltr), .osd spinbutton:not(.vertical) .linked:not(.vertical) > combobox:last-child > box > button.combo:dir(ltr), .osd spinbutton:not(.vertical) combobox.linked button:dir(ltr):nth-child(2), combobox.linked .osd spinbutton:not(.vertical) button:dir(ltr):nth-child(2) { border-radius: 0 3px 3px 0; }

.osd spinbutton:not(.vertical) button:dir(rtl):first-child, .osd spinbutton:not(.vertical) .linked.vertical > combobox:first-child > box > button.combo:dir(rtl), .osd spinbutton:not(.vertical) .linked:not(.vertical) > combobox:first-child > box > button.combo:dir(rtl), .osd spinbutton:not(.vertical) combobox.linked button:dir(rtl):nth-child(2), combobox.linked .osd spinbutton:not(.vertical) button:dir(rtl):nth-child(2) { border-radius: 3px 0 0 3px; }

spinbutton.vertical:disabled, label:disabled selection.vertical { color: #959696; }

spinbutton.vertical:backdrop:disabled, label:disabled selection:backdrop { color: #606567; }

spinbutton.vertical:drop(active), combobox:drop(active) button.vertical.combo { border-color: transparent; box-shadow: none; }

spinbutton.vertical entry { min-height: 32px; min-width: 32px; padding: 0; border-radius: 0; }

spinbutton.vertical button { min-height: 32px; min-width: 32px; padding: 0; }

spinbutton.vertical button.up { border-radius: 3px 3px 0 0; border-style: solid solid none solid; }

spinbutton.vertical button.down { border-radius: 0 0 3px 3px; border-style: none solid solid solid; }

.osd spinbutton.vertical button:first-child, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo, .osd spinbutton.vertical combobox.linked button:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:nth-child(2):dir(rtl) { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd spinbutton.vertical button:first-child:hover, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:hover, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:hover, .osd spinbutton.vertical combobox.linked button:hover:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:hover:nth-child(2):dir(rtl) { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd spinbutton.vertical button:first-child:active, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:active, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:active, .osd spinbutton.vertical combobox.linked button:active:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:active:nth-child(2):dir(rtl) { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd spinbutton.vertical button:first-child:disabled, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:disabled, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:disabled, .osd spinbutton.vertical combobox.linked button:disabled:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:disabled:nth-child(2):dir(rtl), .osd spinbutton.vertical label:disabled selection:first-child, label:disabled .osd spinbutton.vertical selection:first-child { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd spinbutton.vertical button:first-child:backdrop, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:backdrop, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, .osd spinbutton.vertical combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:backdrop:nth-child(2):dir(rtl) { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

treeview spinbutton:not(.vertical) { min-height: 0; border-style: none; border-radius: 0; }

treeview spinbutton:not(.vertical) entry { min-height: 0; padding: 1px 2px; }

/************** ComboBoxes * */
combobox arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); min-height: 16px; min-width: 16px; }

combobox:drop(active) { box-shadow: none; }

/************ Toolbars * */
searchbar, .location-bar, .inline-toolbar, toolbar { -GtkWidget-window-dragging: true; padding: 4px; background-color: #3b3e3f; }

toolbar { background: #343637 linear-gradient(to top, #2c2e2f, #313434 2px, #343637 3px); box-shadow: inset 0 1px rgba(238, 238, 236, 0.07); box-shadow: none; border-bottom: 1px solid #1d1f1f; padding: 4px 3px 3px 4px; }

.osd toolbar { background-color: transparent; }

toolbar.osd { padding: 13px; border: none; border-radius: 5px; background-color: rgba(34, 34, 34, 0.8); }

toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom { border-radius: 0; }

toolbar.horizontal separator { margin: 0 7px 1px 6px; }

toolbar.vertical separator { margin: 6px 1px 7px 0; }

toolbar:not(.inline-toolbar):not(.osd) switch, toolbar:not(.inline-toolbar):not(.osd) scale, toolbar:not(.inline-toolbar):not(.osd) entry, toolbar:not(.inline-toolbar):not(.osd) spinbutton, toolbar:not(.inline-toolbar):not(.osd) button { margin-right: 1px; margin-bottom: 1px; }

.inline-toolbar { padding: 3px; border-width: 0 1px 1px; border-radius: 0  0 5px 5px; }

searchbar, .location-bar { border-width: 0 0 1px; padding: 3px; }

.inline-toolbar, searchbar, .location-bar { border-style: solid; border-color: #1d1f1f; background-color: #323536; }

.inline-toolbar:backdrop, searchbar:backdrop, .location-bar:backdrop { border-color: #202223; background-color: #323435; box-shadow: none; transition: 200ms ease-out; }

/*************** Header bars * */
.titlebar:not(headerbar), headerbar { padding: 0 5px; min-height: 32px; border-width: 0 0 1px; border-style: solid; border-color: #1d1f1f; border-radius: 0; background: #343637 linear-gradient(to top, #2c2e2f, #313434 2px, #343637 3px); box-shadow: inset 0 1px rgba(238, 238, 236, 0.07); }

.titlebar:backdrop:not(headerbar), headerbar:backdrop { border-color: #202223; background-color: #3b3e3f; background-image: none; box-shadow: inset 0 1px rgba(238, 238, 236, 0.07); transition: 200ms ease-out; }

.titlebar:not(headerbar) .title, headerbar .title { padding-left: 12px; padding-right: 12px; font-weight: bold; }

.titlebar:not(headerbar) .subtitle, headerbar .subtitle { font-size: smaller; padding-left: 12px; padding-right: 12px; }

.selection-mode.titlebar:not(headerbar), headerbar.selection-mode { color: #ffffff; text-shadow: none; border-color: #09294b; background: #145ba6 linear-gradient(to top, #125498, #1459a1 2px, #145ba6 3px); box-shadow: inset 0 1px rgba(28, 96, 168, 0.535); }

.selection-mode.titlebar:backdrop:not(headerbar), headerbar.selection-mode:backdrop { background-color: #145ba6; background-image: none; box-shadow: inset 0 1px rgba(31, 99, 170, 0.442); }

.selection-mode.titlebar:not(headerbar) button, headerbar.selection-mode button { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #13569d, #125194 60%, #114c8b); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

.selection-mode.titlebar:not(headerbar) button.flat, .selection-mode.titlebar:not(headerbar) button.titlebutton, .selection-mode.titlebar:not(headerbar) button.sidebar-button, headerbar.selection-mode button.flat, headerbar.selection-mode button.titlebutton, headerbar.selection-mode button.titlebutton, headerbar.selection-mode button.sidebar-button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode.titlebar:not(headerbar) button:hover, headerbar.selection-mode button:hover { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #061d34; background-image: linear-gradient(to bottom, #155eaa, #13569d 60%, #125194); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

.selection-mode.titlebar:not(headerbar) button:active, .selection-mode.titlebar:not(headerbar) button:checked, headerbar.selection-mode button:active, headerbar.selection-mode button:checked { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #061d34; background-image: linear-gradient(to bottom, #0f457d, #114f8f); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

.selection-mode.titlebar:not(headerbar) button:backdrop, headerbar.selection-mode button:backdrop.flat, headerbar.selection-mode button.titlebutton:backdrop, headerbar.selection-mode button.titlebutton:backdrop, headerbar.selection-mode button.sidebar-button:backdrop, headerbar.selection-mode notebook > header > tabs > arrow:backdrop, headerbar.selection-mode popover.background checkbutton:backdrop, popover.background headerbar.selection-mode checkbutton:backdrop, headerbar.selection-mode popover.background radiobutton:backdrop, popover.background headerbar.selection-mode radiobutton:backdrop, headerbar.selection-mode button:backdrop { border-color: #061d34; background-color: #145ba6; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); -gtk-icon-effect: none; border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button:backdrop label, .selection-mode.titlebar:not(headerbar) button:backdrop, headerbar.selection-mode button:backdrop.flat label, headerbar.selection-mode button.titlebutton:backdrop label, headerbar.selection-mode button.titlebutton:backdrop label, headerbar.selection-mode button.sidebar-button:backdrop label, headerbar.selection-mode notebook > header > tabs > arrow:backdrop label, headerbar.selection-mode popover.background checkbutton:backdrop label, popover.background headerbar.selection-mode checkbutton:backdrop label, headerbar.selection-mode popover.background radiobutton:backdrop label, popover.background headerbar.selection-mode radiobutton:backdrop label, headerbar.selection-mode button:backdrop.flat, headerbar.selection-mode button.titlebutton:backdrop, headerbar.selection-mode button.titlebutton:backdrop, headerbar.selection-mode button.sidebar-button:backdrop, headerbar.selection-mode notebook > header > tabs > arrow:backdrop, headerbar.selection-mode popover.background checkbutton:backdrop, popover.background headerbar.selection-mode checkbutton:backdrop, headerbar.selection-mode popover.background radiobutton:backdrop, popover.background headerbar.selection-mode radiobutton:backdrop, headerbar.selection-mode button:backdrop label, headerbar.selection-mode button:backdrop { color: #d0deed; }

.selection-mode.titlebar:not(headerbar) button:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:checked, headerbar.selection-mode button:backdrop.flat:active, headerbar.selection-mode button.titlebutton:backdrop:active, headerbar.selection-mode button.sidebar-button:backdrop:active, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:active, headerbar.selection-mode popover.background checkbutton:backdrop:active, popover.background headerbar.selection-mode checkbutton:backdrop:active, headerbar.selection-mode popover.background radiobutton:backdrop:active, popover.background headerbar.selection-mode radiobutton:backdrop:active, headerbar.selection-mode button:backdrop.flat:checked, headerbar.selection-mode button.titlebutton:backdrop:checked, headerbar.selection-mode button.sidebar-button:backdrop:checked, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:checked, headerbar.selection-mode popover.background checkbutton:backdrop:checked, popover.background headerbar.selection-mode checkbutton:backdrop:checked, headerbar.selection-mode popover.background radiobutton:backdrop:checked, popover.background headerbar.selection-mode radiobutton:backdrop:checked, headerbar.selection-mode button:backdrop:active, headerbar.selection-mode button:backdrop:checked { border-color: #061d34; background-color: #0f4278; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button:backdrop:active label, .selection-mode.titlebar:not(headerbar) button:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:checked label, .selection-mode.titlebar:not(headerbar) button:backdrop:checked, headerbar.selection-mode button:backdrop.flat:active label, headerbar.selection-mode button.titlebutton:backdrop:active label, headerbar.selection-mode button.sidebar-button:backdrop:active label, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:active label, headerbar.selection-mode popover.background checkbutton:backdrop:active label, popover.background headerbar.selection-mode checkbutton:backdrop:active label, headerbar.selection-mode popover.background radiobutton:backdrop:active label, popover.background headerbar.selection-mode radiobutton:backdrop:active label, headerbar.selection-mode button:backdrop.flat:active, headerbar.selection-mode button.titlebutton:backdrop:active, headerbar.selection-mode button.sidebar-button:backdrop:active, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:active, headerbar.selection-mode popover.background checkbutton:backdrop:active, popover.background headerbar.selection-mode checkbutton:backdrop:active, headerbar.selection-mode popover.background radiobutton:backdrop:active, popover.background headerbar.selection-mode radiobutton:backdrop:active, headerbar.selection-mode button:backdrop.flat:checked label, headerbar.selection-mode button.titlebutton:backdrop:checked label, headerbar.selection-mode button.sidebar-button:backdrop:checked label, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:checked label, headerbar.selection-mode popover.background checkbutton:backdrop:checked label, popover.background headerbar.selection-mode checkbutton:backdrop:checked label, headerbar.selection-mode popover.background radiobutton:backdrop:checked label, popover.background headerbar.selection-mode radiobutton:backdrop:checked label, headerbar.selection-mode button:backdrop.flat:checked, headerbar.selection-mode button.titlebutton:backdrop:checked, headerbar.selection-mode button.sidebar-button:backdrop:checked, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:checked, headerbar.selection-mode popover.background checkbutton:backdrop:checked, popover.background headerbar.selection-mode checkbutton:backdrop:checked, headerbar.selection-mode popover.background radiobutton:backdrop:checked, popover.background headerbar.selection-mode radiobutton:backdrop:checked, headerbar.selection-mode button:backdrop:active label, headerbar.selection-mode button:backdrop:active, headerbar.selection-mode button:backdrop:checked label, headerbar.selection-mode button:backdrop:checked { color: #cfd9e4; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button:backdrop.flat:disabled, headerbar.selection-mode button.titlebutton:backdrop:disabled, headerbar.selection-mode button.sidebar-button:backdrop:disabled, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled, headerbar.selection-mode popover.background checkbutton:backdrop:disabled, popover.background headerbar.selection-mode checkbutton:backdrop:disabled, headerbar.selection-mode popover.background radiobutton:backdrop:disabled, popover.background headerbar.selection-mode radiobutton:backdrop:disabled, headerbar.selection-mode label:disabled selection.flat, label:disabled headerbar.selection-mode selection.flat, headerbar.selection-mode button:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { border-color: #061d34; background-color: #185594; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat label, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat label, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop label, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button:backdrop.flat:disabled label, headerbar.selection-mode button.titlebutton:backdrop:disabled label, headerbar.selection-mode button.sidebar-button:backdrop:disabled label, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled label, headerbar.selection-mode popover.background checkbutton:backdrop:disabled label, popover.background headerbar.selection-mode checkbutton:backdrop:disabled label, headerbar.selection-mode popover.background radiobutton:backdrop:disabled label, popover.background headerbar.selection-mode radiobutton:backdrop:disabled label, headerbar.selection-mode label:disabled selection.flat label, label:disabled headerbar.selection-mode selection.flat label, headerbar.selection-mode button:backdrop.flat:disabled, headerbar.selection-mode button.titlebutton:backdrop:disabled, headerbar.selection-mode button.sidebar-button:backdrop:disabled, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled, headerbar.selection-mode popover.background checkbutton:backdrop:disabled, popover.background headerbar.selection-mode checkbutton:backdrop:disabled, headerbar.selection-mode popover.background radiobutton:backdrop:disabled, popover.background headerbar.selection-mode radiobutton:backdrop:disabled, headerbar.selection-mode label:disabled selection.flat, label:disabled headerbar.selection-mode selection.flat, headerbar.selection-mode button:backdrop:disabled label, headerbar.selection-mode label:disabled selection:backdrop label, label:disabled headerbar.selection-mode selection:backdrop label, headerbar.selection-mode button:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { color: #6991b9; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat:active, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:active, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat:checked, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:checked, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:active, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:active, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:checked, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:checked, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:checked, headerbar.selection-mode button:backdrop.flat:disabled:active, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled:active, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:active, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:active, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:active, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:active, headerbar.selection-mode label:disabled selection.flat:active, label:disabled headerbar.selection-mode selection.flat:active, headerbar.selection-mode button:backdrop.flat:disabled:checked, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled:checked, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:checked, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:checked, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:checked, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:checked, headerbar.selection-mode label:disabled selection.flat:checked, label:disabled headerbar.selection-mode selection.flat:checked, headerbar.selection-mode button:backdrop:disabled:active, headerbar.selection-mode label:disabled selection:backdrop:active, label:disabled headerbar.selection-mode selection:backdrop:active, headerbar.selection-mode button:backdrop:disabled:checked, headerbar.selection-mode label:disabled selection:backdrop:checked, label:disabled headerbar.selection-mode selection:backdrop:checked { border-color: #061d34; background-color: #14487e; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat:active label, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:active label, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat:checked label, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:checked label, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:active label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:active label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:active label, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:checked label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:checked label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:checked label, headerbar.selection-mode button:backdrop.flat:disabled:active label, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled:active label, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:active label, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:active label, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:active label, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:active label, headerbar.selection-mode label:disabled selection.flat:active label, label:disabled headerbar.selection-mode selection.flat:active label, headerbar.selection-mode button:backdrop.flat:disabled:checked label, headerbar.selection-mode notebook > header > tabs > arrow:backdrop:disabled:checked label, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:checked label, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:checked label, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:checked label, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:checked label, headerbar.selection-mode label:disabled selection.flat:checked label, label:disabled headerbar.selection-mode selection.flat:checked label, headerbar.selection-mode button:backdrop:disabled:active label, headerbar.selection-mode label:disabled selection:backdrop:active label, label:disabled headerbar.selection-mode selection:backdrop:active label, headerbar.selection-mode button:backdrop:disabled:checked label, headerbar.selection-mode label:disabled selection:backdrop:checked label, label:disabled headerbar.selection-mode selection:backdrop:checked label { color: #6788ab; }

.selection-mode.titlebar:not(headerbar) button.flat:backdrop, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop, .selection-mode.titlebar:not(headerbar) button.sidebar-button:backdrop, .selection-mode.titlebar:not(headerbar) button.flat:disabled, .selection-mode.titlebar:not(headerbar) button.titlebutton:disabled, .selection-mode.titlebar:not(headerbar) button.sidebar-button:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button.flat:backdrop, headerbar.selection-mode button.titlebutton:backdrop, headerbar.selection-mode button.titlebutton:backdrop, headerbar.selection-mode button.sidebar-button:backdrop, headerbar.selection-mode button.flat:disabled, headerbar.selection-mode button.titlebutton:disabled, headerbar.selection-mode button.titlebutton:disabled, headerbar.selection-mode button.sidebar-button:disabled, headerbar.selection-mode label:disabled selection.flat, label:disabled headerbar.selection-mode selection.flat, headerbar.selection-mode button.flat:backdrop:disabled, headerbar.selection-mode button.titlebutton:backdrop:disabled, headerbar.selection-mode button.sidebar-button:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode.titlebar:not(headerbar) button:disabled, headerbar.selection-mode button:disabled { border-color: #061d34; background-color: #185594; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode.titlebar:not(headerbar) button:disabled label, .selection-mode.titlebar:not(headerbar) button:disabled, headerbar.selection-mode button:disabled label, headerbar.selection-mode button:disabled { color: #8caaca; }

.selection-mode.titlebar:not(headerbar) button:disabled:active, .selection-mode.titlebar:not(headerbar) button:disabled:checked, headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked { border-color: #061d34; background-image: linear-gradient(to bottom, #134477, #14487e); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode.titlebar:not(headerbar) button:disabled:active label, .selection-mode.titlebar:not(headerbar) button:disabled:active, .selection-mode.titlebar:not(headerbar) button:disabled:checked label, .selection-mode.titlebar:not(headerbar) button:disabled:checked, headerbar.selection-mode button:disabled:active label, headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked label, headerbar.selection-mode button:disabled:checked { color: #a1b6cb; }

.selection-mode.titlebar:not(headerbar) button.suggested-action, .selection-mode.titlebar:not(headerbar) button.titlebutton, headerbar.selection-mode button.suggested-action, headerbar.selection-mode button.titlebutton { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #36393a, #313434 60%, #2c2e2f); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); color: #ffffff; border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:hover, .selection-mode.titlebar:not(headerbar) button.titlebutton:hover, headerbar.selection-mode button.suggested-action:hover, headerbar.selection-mode button.titlebutton:hover { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3d4142, #36393a 60%, #313434); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:active, .selection-mode.titlebar:not(headerbar) button.titlebutton:active, headerbar.selection-mode button.suggested-action:active, headerbar.selection-mode button.titlebutton:active { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #252727, #2f3132); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:disabled, .selection-mode.titlebar:not(headerbar) button.titlebutton:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection.suggested-action, label:disabled .selection-mode.titlebar:not(headerbar) selection.suggested-action, headerbar.selection-mode button.suggested-action:disabled, headerbar.selection-mode button.titlebutton:disabled, headerbar.selection-mode label:disabled selection.suggested-action, label:disabled headerbar.selection-mode selection.suggested-action { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); background-image: none; background: #3b3e3f; border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:disabled label, .selection-mode.titlebar:not(headerbar) button.titlebutton:disabled label, .selection-mode.titlebar:not(headerbar) label:disabled selection.suggested-action label, label:disabled .selection-mode.titlebar:not(headerbar) selection.suggested-action label, .selection-mode.titlebar:not(headerbar) button.suggested-action:disabled, .selection-mode.titlebar:not(headerbar) button.titlebutton:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection.suggested-action, label:disabled .selection-mode.titlebar:not(headerbar) selection.suggested-action, headerbar.selection-mode button.suggested-action:disabled label, headerbar.selection-mode button.titlebutton:disabled label, headerbar.selection-mode label:disabled selection.suggested-action label, label:disabled headerbar.selection-mode selection.suggested-action label, headerbar.selection-mode button.suggested-action:disabled, headerbar.selection-mode button.titlebutton:disabled, headerbar.selection-mode label:disabled selection.suggested-action, label:disabled headerbar.selection-mode selection.suggested-action { color: #959696; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop, headerbar.selection-mode button.suggested-action:backdrop, headerbar.selection-mode button.titlebutton:backdrop { border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop label, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop label, .selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop, headerbar.selection-mode button.suggested-action:backdrop label, headerbar.selection-mode button.titlebutton:backdrop label, headerbar.selection-mode button.suggested-action:backdrop, headerbar.selection-mode button.titlebutton:backdrop { color: #959696; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button.suggested-action:backdrop:disabled, headerbar.selection-mode button.titlebutton:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #09294b; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled label, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop:disabled label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop label, .selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled, .selection-mode.titlebar:not(headerbar) button.titlebutton:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button.suggested-action:backdrop:disabled label, headerbar.selection-mode button.titlebutton:backdrop:disabled label, headerbar.selection-mode label:disabled selection:backdrop label, label:disabled headerbar.selection-mode selection:backdrop label, headerbar.selection-mode button.suggested-action:backdrop:disabled, headerbar.selection-mode button.titlebutton:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { color: #606567; }

.selection-mode.titlebar:not(headerbar) .selection-menu, headerbar.selection-mode .selection-menu:backdrop, headerbar.selection-mode .selection-menu { border-color: rgba(20, 91, 166, 0); background-color: rgba(20, 91, 166, 0); background-image: none; box-shadow: none; padding-left: 10px; padding-right: 10px; }

.selection-mode.titlebar:not(headerbar) .selection-menu .arrow, headerbar.selection-mode .selection-menu:backdrop .arrow, headerbar.selection-mode .selection-menu .arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); color: rgba(255, 255, 255, 0.5); -gtk-icon-shadow: none; }

.tiled .titlebar:not(headerbar), .tiled-top .titlebar:not(headerbar), .tiled-right .titlebar:not(headerbar), .tiled-bottom .titlebar:not(headerbar), .tiled-left .titlebar:not(headerbar), .maximized .titlebar:not(headerbar), .fullscreen .titlebar:not(headerbar), .tiled headerbar, .tiled-top headerbar, .tiled-right headerbar, .tiled-bottom headerbar, .tiled-left headerbar, .maximized headerbar, .fullscreen headerbar { border-radius: 0; }

.default-decoration.titlebar:not(headerbar), headerbar.default-decoration { min-height: 24px; padding: 4px; }

.default-decoration.titlebar:not(headerbar) button.titlebutton, .default-decoration.titlebar:not(headerbar) menubutton.titlebutton, headerbar.default-decoration button.titlebutton, headerbar.default-decoration menubutton.titlebutton { min-height: 22px; min-width: 22px; margin: 0; padding: 0; }

.default-decoration.titlebar:not(headerbar) menubutton.titlebutton button, headerbar.default-decoration menubutton.titlebutton button { min-height: 20px; min-width: 20px; margin: 0; padding: 4px; }

.solid-csd .titlebar:dir(rtl):not(headerbar), .solid-csd .titlebar:dir(ltr):not(headerbar), .solid-csd headerbar:backdrop:dir(rtl), .solid-csd headerbar:backdrop:dir(ltr), .solid-csd headerbar:dir(rtl), .solid-csd headerbar:dir(ltr) { margin-left: -1px; margin-right: -1px; margin-top: -1px; border-radius: 0; box-shadow: none; }

headerbar entry, headerbar separator { margin-top: 3px; margin-bottom: 3px; }

headerbar spinbutton, headerbar button { margin-top: 2px; margin-bottom: 2px; padding-top: 0; padding-bottom: 0; }

headerbar button label { min-width: 28px; min-height: 22px; }

headerbar button.titlebutton image { min-width: 22px; min-height: 22px; }

headerbar button:not(.image-button):not(.titlebutton) image { min-width: 22px; min-height: 22px; }

headerbar button.image-button { min-width: 22px; min-height: 22px; padding-left: 2px; padding-right: 2px; }

headerbar .stack-switcher button { min-width: 26px; min-height: 26px; }

headerbar .stack-switcher button:not(.text-button) { min-height: 22px; min-width: 22px; padding-left: 0px; padding-right: 0px; }

headerbar buttonbox { padding: 0px; }

headerbar buttonbox button { min-width: 26px; min-height: 26px; }

headerbar buttonbox button:not(.text-button) { min-width: 22px; padding-left: 0px; padding-right: 0px; }

headerbar switch { margin-top: 5px; margin-bottom: 5px; }

.background:not(.tiled):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-top):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-top):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-left):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-left):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-right):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-right):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-bottom):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-bottom):not(.maximized):not(.solid-csd) .titlebar { border-top-left-radius: 7px; border-top-right-radius: 7px; }

window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) separator:first-child + headerbar:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) separator:first-child + headerbar, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:first-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:first-child { border-top-left-radius: 7px; }

window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:last-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:last-child { border-top-right-radius: 7px; }

window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:first-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:first-child, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:last-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:last-child { border-top-left-radius: 7px; border-top-right-radius: 7px; }

window.tiled headerbar, window.tiled headerbar:first-child, window.tiled headerbar:last-child, window.tiled headerbar:only-child, window.tiled headerbar:backdrop, window.tiled headerbar:backdrop:first-child, window.tiled combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled button:backdrop:nth-child(2):dir(rtl), window.tiled .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled headerbar:backdrop:last-child, window.tiled combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled button:backdrop:nth-child(2):dir(ltr), window.tiled .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled headerbar:backdrop:only-child, window.tiled .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-top headerbar, window.tiled-top headerbar:first-child, window.tiled-top headerbar:last-child, window.tiled-top headerbar:only-child, window.tiled-top headerbar:backdrop, window.tiled-top headerbar:backdrop:first-child, window.tiled-top combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-top button:backdrop:nth-child(2):dir(rtl), window.tiled-top .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-top .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-top headerbar:backdrop:last-child, window.tiled-top combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-top button:backdrop:nth-child(2):dir(ltr), window.tiled-top .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-top .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-top headerbar:backdrop:only-child, window.tiled-top .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-top .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-right headerbar, window.tiled-right headerbar:first-child, window.tiled-right headerbar:last-child, window.tiled-right headerbar:only-child, window.tiled-right headerbar:backdrop, window.tiled-right headerbar:backdrop:first-child, window.tiled-right combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-right button:backdrop:nth-child(2):dir(rtl), window.tiled-right .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-right .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-right headerbar:backdrop:last-child, window.tiled-right combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-right button:backdrop:nth-child(2):dir(ltr), window.tiled-right .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-right .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-right headerbar:backdrop:only-child, window.tiled-right .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-right .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-bottom headerbar, window.tiled-bottom headerbar:first-child, window.tiled-bottom headerbar:last-child, window.tiled-bottom headerbar:only-child, window.tiled-bottom headerbar:backdrop, window.tiled-bottom headerbar:backdrop:first-child, window.tiled-bottom combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-bottom button:backdrop:nth-child(2):dir(rtl), window.tiled-bottom .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-bottom .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-bottom headerbar:backdrop:last-child, window.tiled-bottom combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-bottom button:backdrop:nth-child(2):dir(ltr), window.tiled-bottom .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-bottom .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-bottom headerbar:backdrop:only-child, window.tiled-bottom .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-bottom .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-left headerbar, window.tiled-left headerbar:first-child, window.tiled-left headerbar:last-child, window.tiled-left headerbar:only-child, window.tiled-left headerbar:backdrop, window.tiled-left headerbar:backdrop:first-child, window.tiled-left combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-left button:backdrop:nth-child(2):dir(rtl), window.tiled-left .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-left .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-left headerbar:backdrop:last-child, window.tiled-left combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-left button:backdrop:nth-child(2):dir(ltr), window.tiled-left .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-left .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-left headerbar:backdrop:only-child, window.tiled-left .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-left .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.maximized headerbar, window.maximized headerbar:first-child, window.maximized headerbar:last-child, window.maximized headerbar:only-child, window.maximized headerbar:backdrop, window.maximized headerbar:backdrop:first-child, window.maximized combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.maximized button:backdrop:nth-child(2):dir(rtl), window.maximized .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.maximized .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.maximized headerbar:backdrop:last-child, window.maximized combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.maximized button:backdrop:nth-child(2):dir(ltr), window.maximized .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.maximized .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.maximized headerbar:backdrop:only-child, window.maximized .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.maximized .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.fullscreen headerbar, window.fullscreen headerbar:first-child, window.fullscreen headerbar:last-child, window.fullscreen headerbar:only-child, window.fullscreen headerbar:backdrop, window.fullscreen headerbar:backdrop:first-child, window.fullscreen combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.fullscreen button:backdrop:nth-child(2):dir(rtl), window.fullscreen .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.fullscreen .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.fullscreen headerbar:backdrop:last-child, window.fullscreen combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.fullscreen button:backdrop:nth-child(2):dir(ltr), window.fullscreen .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.fullscreen .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.fullscreen headerbar:backdrop:only-child, window.fullscreen .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.fullscreen .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.solid-csd headerbar, window.solid-csd headerbar:first-child, window.solid-csd headerbar:last-child, window.solid-csd headerbar:only-child, window.solid-csd headerbar:backdrop, window.solid-csd headerbar:backdrop:first-child, window.solid-csd combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.solid-csd button:backdrop:nth-child(2):dir(rtl), window.solid-csd .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.solid-csd .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.solid-csd headerbar:backdrop:last-child, window.solid-csd combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.solid-csd button:backdrop:nth-child(2):dir(ltr), window.solid-csd .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.solid-csd .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.solid-csd headerbar:backdrop:only-child, window.solid-csd .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.solid-csd .linked.vertical > combobox:only-child > box > button.combo:backdrop { border-top-left-radius: 0; border-top-right-radius: 0; }

window.csd > .titlebar:not(headerbar) { padding: 0; background-color: transparent; background-image: none; border-style: none; border-color: transparent; box-shadow: none; }

.titlebar:not(headerbar) > separator { background-color: #1d1f1f; }

window.devel headerbar.titlebar:not(.selection-mode) { background: #3b3e3f cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, linear-gradient(to right, transparent 65%, rgba(20, 91, 166, 0.1)), linear-gradient(to top, #2a2c2d 3px, #2f3132); }

window.devel headerbar.titlebar:not(.selection-mode):backdrop { background: #3b3e3f cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, image(#3b3e3f); /* background-color would flash */ }

.background:not(.csd):not(.ssd):not(.solid-csd) headerbar, .background:not(.csd):not(.ssd):not(.solid-csd) headerbar:not(:last-child), .background:not(.csd):not(.ssd):not(.solid-csd) headerbar:backdrop, .background:not(.csd):not(.ssd):not(.solid-csd) headerbar:backdrop:not(:last-child) { border-radius: 0; border-top-color: transparent; box-shadow: none; }

/************ Pathbars * */
.path-bar button.text-button, .path-bar button.image-button, .path-bar button { padding-left: 4px; padding-right: 4px; }

.path-bar button.text-button.image-button label { padding-left: 0; padding-right: 0; }

.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child { padding-right: 8px; }

.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child { padding-left: 8px; }

.path-bar button image { padding-left: 4px; padding-right: 4px; }

.path-bar button.slider-button { padding-left: 0; padding-right: 0; }

/************** Tree Views * */
treeview.view { border-left-color: #8e8e8e; border-top-color: #3b3e3f; }

*, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link { -GtkTreeView-horizontal-separator: 4; -GtkTreeView-grid-line-width: 1; -GtkTreeView-grid-line-pattern: ''; -GtkTreeView-tree-line-width: 1; -GtkTreeView-tree-line-pattern: ''; -GtkTreeView-expander-size: 16; }

treeview.view:selected:focus, treeview.view:selected { border-radius: 0; }

treeview.view:selected:backdrop, treeview.view:selected { border-left-color: #8aadd2; border-top-color: rgba(238, 238, 236, 0.1); }

treeview.view:disabled { color: #959696; }

treeview.view:disabled:selected { color: #729dca; }

treeview.view:disabled:selected:backdrop { color: #4e80b4; }

treeview.view:disabled:backdrop { color: #606567; }

treeview.view.separator { min-height: 2px; color: #3b3e3f; }

treeview.view.separator:backdrop { color: rgba(59, 62, 63, 0.1); }

treeview.view:backdrop { border-left-color: #686a6b; border-top: #3b3e3f; }

treeview.view:drop(active) { border-style: solid none; border-width: 1px; border-color: #09294b; }

treeview.view:drop(active).after { border-top-style: none; }

treeview.view:drop(active).before { border-bottom-style: none; }

treeview.view.expander { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); color: #b4b4b4; }

treeview.view.expander:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

treeview.view.expander:hover { color: #eeeeec; }

treeview.view.expander:selected { color: #b9cee4; }

treeview.view.expander:selected:hover { color: #ffffff; }

treeview.view.expander:selected:backdrop { color: #9bb1c8; }

treeview.view.expander:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

treeview.view.expander:backdrop { color: #777878; }

treeview.view.progressbar { border: 1px solid #09294b; border-radius: 4px; background-color: #145ba6; background-image: linear-gradient(to bottom, #145ba6, #0f4278); box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), 0 1px rgba(0, 0, 0, 0.1); }

treeview.view.progressbar:selected:focus, treeview.view.progressbar:selected { border-radius: 4px; box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); background-image: linear-gradient(to bottom, #2d2e30, #141516); }

treeview.view.progressbar:selected:focus:backdrop, treeview.view.progressbar:selected:backdrop { border-color: #2f3133; background-color: #2f3133; }

treeview.view.progressbar:backdrop { border-color: #2f3133; background-image: none; box-shadow: none; }

treeview.view.trough { background-color: rgba(238, 238, 236, 0.1); border-radius: 4px; }

treeview.view.trough:selected:focus, treeview.view.trough:selected { background-color: #0f4278; border-radius: 4px; }

treeview.view header button { color: #8e8e8e; background-color: #2d2e30; font-weight: bold; text-shadow: none; box-shadow: none; }

treeview.view header button:hover { color: #bebebd; box-shadow: none; transition: none; }

treeview.view header button:active { color: #eeeeec; transition: none; }

treeview.view header button:last-child:backdrop, treeview.view header button:last-child, treeview.view header combobox.linked button:nth-child(2):dir(ltr), combobox.linked treeview.view header button:nth-child(2):dir(ltr), treeview.view header .linked:not(.vertical) > combobox:last-child > box > button.combo, treeview.view header .linked.vertical > combobox:last-child > box > button.combo { border-right-style: none; }

treeview.view button.dnd:active, treeview.view button.dnd:selected, treeview.view headerbar.selection-mode .dnd.subtitle:link, headerbar.selection-mode treeview.view .dnd.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) .dnd.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view .dnd.subtitle:link, treeview.view button.dnd:hover, treeview.view button.dnd, treeview.view header.button.dnd:active, treeview.view header.button.dnd:selected, treeview.view header.button.dnd:hover, treeview.view header.button.dnd { padding: 0 6px; color: #2d2e30; background-image: none; background-color: #145ba6; border-style: none; border-radius: 0; box-shadow: inset 0 0 0 1px #2d2e30; text-shadow: none; transition: none; }

treeview.view acceleditor > label { background-color: #145ba6; }

treeview.view header button, treeview.view header button:hover, treeview.view header button:active { padding: 0 6px; background-image: none; border-style: none solid solid none; border-color: #3b3e3f; border-radius: 0; text-shadow: none; }

treeview.view header button:backdrop { color: #686a6b; border-color: #3b3e3f; border-style: none solid solid none; background-image: none; background-color: #2f3133; }

treeview.view header button:last-child, treeview.view header combobox.linked button:nth-child(2):dir(ltr), combobox.linked treeview.view header button:nth-child(2):dir(ltr), treeview.view header .linked:not(.vertical) > combobox:last-child > box > button.combo, treeview.view header .linked.vertical > combobox:last-child > box > button.combo { border-right-style: none; }

/********* Menus * */
menubar, .menubar { -GtkWidget-window-dragging: true; padding: 0px; }

menubar:backdrop, .menubar:backdrop { background-color: #3b3e3f; }

menubar > menuitem, .menubar > menuitem { min-height: 16px; padding: 3px 8px; border: 1px solid transparent; }

menubar > menuitem:hover, .menubar > menuitem:hover { background-image: linear-gradient(to bottom, shade(#145ba6, 1.2), shade(#145ba6, 1)); color: #ffffff; border-color: shade(#145ba6, 1.1); }

menubar > menuitem:disabled, .menubar > menuitem:disabled { color: #959696; box-shadow: none; }

menu, .menu, .context-menu { margin: 4px; padding: 2px 0px; background-color: #303133; border: 1px solid #1d1f1f; }

.csd menu, .csd .menu, .csd .context-menu { border: none; }

menu:backdrop, .menu:backdrop, .context-menu:backdrop { background-color: #323335; }

menu menuitem, .menu menuitem, .context-menu menuitem { min-height: 16px; min-width: 40px; padding: 4px 6px; text-shadow: none; }

menu menuitem:hover, .menu menuitem:hover, .context-menu menuitem:hover { color: #ffffff; background-image: linear-gradient(to bottom, shade(#145ba6, 1.2), shade(#145ba6, 1)); box-shadow: inset 1px 1px shade(#145ba6, 0.8), inset -1px -1px shade(#145ba6, 0.8); }

menu menuitem:disabled, .menu menuitem:disabled, .context-menu menuitem:disabled { color: #959696; }

menu menuitem:disabled:backdrop, .menu menuitem:disabled:backdrop, .context-menu menuitem:disabled:backdrop { color: #606567; }

menu menuitem:backdrop, menu menuitem:backdrop:hover, .menu menuitem:backdrop, .menu menuitem:backdrop:hover, .context-menu menuitem:backdrop, .context-menu menuitem:backdrop:hover { color: #959696; background-color: transparent; }

menu menuitem arrow, .menu menuitem arrow, .context-menu menuitem arrow { min-height: 16px; min-width: 16px; }

menu menuitem arrow:dir(ltr), .menu menuitem arrow:dir(ltr), .context-menu menuitem arrow:dir(ltr) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); margin-left: 10px; }

menu menuitem arrow:dir(rtl), .menu menuitem arrow:dir(rtl), .context-menu menuitem arrow:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); margin-right: 10px; }

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr), .menu menuitem label:dir(rtl), .menu menuitem label:dir(ltr), .context-menu menuitem label:dir(rtl), .context-menu menuitem label:dir(ltr) { color: inherit; }

menu > arrow, .menu > arrow, .context-menu > arrow { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; min-height: 16px; min-width: 16px; padding: 4px; background-color: #303133; border-radius: 0; }

menu > arrow.top, .menu > arrow.top, .context-menu > arrow.top { margin-top: -6px; border-bottom: 1px solid #404143; -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

menu > arrow.bottom, .menu > arrow.bottom, .context-menu > arrow.bottom { margin-bottom: -6px; border-top: 1px solid #404143; -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

menu > arrow:hover, .menu > arrow:hover, .context-menu > arrow:hover { background-color: #404143; }

menu > arrow:backdrop, .menu > arrow:backdrop, .context-menu > arrow:backdrop { background-color: #323335; }

menu > arrow:disabled, .menu > arrow:disabled, .context-menu > arrow:disabled { color: transparent; background-color: transparent; border-color: transparent; }

menuitem accelerator { color: alpha(currentColor,0.55); }

menuitem check, menuitem radio { min-height: 16px; min-width: 16px; }

menuitem check:dir(ltr), menuitem radio:dir(ltr) { margin-right: 7px; }

menuitem check:dir(rtl), menuitem radio:dir(rtl) { margin-left: 7px; }

/*************** Popovers   * */
popover.background { padding: 2px; border-radius: 5px; background-color: #676d6e; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3); }

popover.background modelbutton:hover, popover.background checkbutton:hover, popover.background radiobutton:hover { color: #ffffff; }

.csd popover.background, popover.background { border: 1px solid #1d1f1f; }

popover.background:backdrop { background-color: #3b3e3f; box-shadow: none; }

popover.background > list, popover.background > .view, popover.background > iconview, popover.background > toolbar { border-style: none; background-color: transparent; }

.csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier { border: 1px solid rgba(255, 255, 255, 0.1); }

popover.background separator { margin: 3px; }

popover.background list separator { margin: 0px; }

/************* Notebooks * */
notebook.frame { border-style: none; }

notebook.frame > header { margin-left: 0; }

notebook.frame > stack:not(:only-child) { border: 1px solid shade(#3b3e3f, 0.9); }

notebook > header { padding: 1px; background-color: #3b3e3f; }

notebook > header:backdrop { border-color: #202223; background-color: #3b3e3f; }

notebook > header tabs { margin: -1px; }

notebook > header.top > stack { border-top-style: none; }

notebook > header.top > tabs > tab { border-radius: 3px 3px 0 0; border: 1px solid shade(#3b3e3f, 0.9); }

notebook > header.top > tabs > tab:backdrop { box-shadow: none; }

notebook > header.top > tabs > tab:checked { border-width: 1px 1px 0 1px; }

notebook > header.bottom > stack { border-bottom-style: none; }

notebook > header.bottom > tabs > tab { border-radius: 0 0 3px 3px; }

notebook > header.bottom > tabs > tab:backdrop { box-shadow: none; }

notebook > header.bottom > tabs > tab:checked { border-width: 0 1px 1px 1px; }

notebook > header.left > stack { border-left-style: none; }

notebook > header.left > tabs > tab { border-radius: 3px 0 0 3px; }

notebook > header.left > tabs > tab:backdrop { box-shadow: none; }

notebook > header.left > tabs > tab:checked { border-width: 1px 0 1px 1px; }

notebook > header.right > stack { border-right-style: none; }

notebook > header.right > tabs > tab { border-radius: 0 3px 3px 0; }

notebook > header.right > tabs > tab:backdrop { box-shadow: none; }

notebook > header.right > tabs > tab:checked { border-width: 1px 1px 1px 0; }

notebook > header.top > tabs > arrow { border-top-style: none; }

notebook > header.bottom > tabs > arrow { border-bottom-style: none; }

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow { margin-left: -5px; margin-right: -5px; padding-left: 4px; padding-right: 4px; }

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

notebook > header.left > tabs > arrow { border-left-style: none; }

notebook > header.right > tabs > arrow { border-right-style: none; }

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow { margin-top: -5px; margin-bottom: -5px; padding-top: 4px; padding-bottom: 4px; }

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

notebook > header > tabs > arrow { min-height: 16px; min-width: 16px; border-radius: 0; }

notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) { background-clip: padding-box; background-image: none; background-color: rgba(255, 255, 255, 0.3); border-color: transparent; box-shadow: none; }

notebook > header > tabs > arrow:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

notebook > header tab { min-height: 20px; min-width: 24px; padding: 3px 12px; outline-offset: -5px; color: #959696; background-color: #3b3e3f; border-width: 1px; border-radius: 3px; border-color: shade(#3b3e3f, 0.9); border-style: solid; }

notebook > header tab:hover { color: #c2c2c1; }

notebook > header tab:hover.reorderable-page { border-color: rgba(29, 31, 31, 0.3); background-color: rgba(59, 62, 63, 0.2); }

notebook > header tab:backdrop { color: #717373; }

notebook > header tab:backdrop.reorderable-page { border-color: transparent; background-color: transparent; }

notebook > header tab:checked { color: #eeeeec; background-color: shade(#3b3e3f, 1.05); border-width: 1px 1px 0 1px; }

notebook > header tab:checked:backdrop { background-color: #3b3e3f; }

notebook > header tab:checked.reorderable-page { border-color: rgba(29, 31, 31, 0.5); background-color: shade(#3b3e3f, 1.05); }

notebook > header tab:backdrop:checked { color: #959696; }

notebook > header tab:backdrop:checked.reorderable-page { border-color: #202223; background-color: #3b3e3f; }

notebook > header tab button.flat, notebook > header tab .selection-mode button.titlebutton, .selection-mode notebook > header tab button.titlebutton, notebook > header tab button.titlebutton, notebook > header tab button.sidebar-button { padding: 0; margin-top: 1px; margin-bottom: 1px; min-width: 16px; min-height: 16px; }

notebook > header tab button.flat:hover, notebook > header tab button.titlebutton:hover, notebook > header tab button.sidebar-button:hover { color: currentColor; }

notebook > header tab button.flat, notebook > header tab .selection-mode button.titlebutton, .selection-mode notebook > header tab button.titlebutton, notebook > header tab button.titlebutton, notebook > header tab button.sidebar-button, notebook > header tab button.flat:backdrop { color: alpha(currentColor,0.3); }

notebook > header tab button.flat:last-child, notebook > header tab button.titlebutton:last-child, notebook > header tab button.sidebar-button:last-child { margin-left: 1px; margin-right: -1px; }

notebook > header tab button.flat:first-child, notebook > header tab button.titlebutton:first-child, notebook > header tab button.sidebar-button:first-child { margin-left: -1px; margin-right: 1px; }

notebook > header.top tabs, notebook > header.bottom tabs { padding: 0; }

notebook > header.top tabs:not(:only-child), notebook > header.bottom tabs:not(:only-child) { margin-left: 2px; margin-right: 2px; }

notebook > header.top tabs:first-child, notebook > header.bottom tabs:first-child { margin-left: -3px; }

notebook > header.top tabs:last-child, notebook > header.bottom tabs:last-child { margin-right: -3px; }

notebook > header.top tabs tab, notebook > header.bottom tabs tab { margin-left: 2px; margin-right: 2px; }

notebook > header.left tabs, notebook > header.right tabs { padding: 0; }

notebook > header.left tabs:not(:only-child), notebook > header.right tabs:not(:only-child) { margin-top: 2px; margin-bottom: 2px; }

notebook > header.left tabs:first-child, notebook > header.right tabs:first-child { margin-top: -3px; }

notebook > header.left tabs:last-child, notebook > header.right tabs:last-child { margin-bottom: -3px; }

notebook > header.left tabs tab, notebook > header.right tabs tab { margin-top: 2px; margin-bottom: 2px; }

notebook > header.top tab { padding-bottom: 4px; }

notebook > header.bottom tab { padding-top: 4px; }

notebook > header.top > tabs { margin-bottom: -2px; }

notebook > header.bottom > tabs { margin-top: -2px; }

notebook > header.left > tabs { margin-right: -2px; }

notebook > header.right > tabs { margin-left: -2px; }

notebook > header { margin-left: 6px; }

notebook > stack:not(:only-child) { background-color: shade(#3b3e3f, 1.05); border-width: 1px; border-color: shade(#3b3e3f, 0.9); border-style: solid; }

notebook > stack:not(:only-child):backdrop { background-color: #3b3e3f; }

/************** Scrollbars * */
scrollbar { transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

*, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link { -GtkScrollbar-has-backward-stepper: false; -GtkScrollbar-has-forward-stepper: false; }

scrollbar.vertical { background-image: linear-gradient(to right, #545859, #868b8d); }

scrollbar.vertical slider { background-image: linear-gradient(to right, #474b4c, #3d4142); }

scrollbar.vertical slider:hover { background-image: linear-gradient(to right, #2f3132, #393b3c); }

scrollbar.horizontal { background-image: linear-gradient(to bottom, #545859, #868b8d); }

scrollbar.horizontal slider { background-image: linear-gradient(to bottom, #474b4c, #3d4142); }

scrollbar.horizontal slider:hover { background-image: linear-gradient(to bottom, #2f3132, #393b3c); }

scrollbar.top { border-bottom: 1px solid #474b4c; }

scrollbar.bottom { border-top: 1px solid #474b4c; }

scrollbar.left { border-right: 1px solid #474b4c; }

scrollbar.right { border-left: 1px solid #474b4c; }

scrollbar:backdrop { background-color: #343637; border-color: #474b4c; transition: 200ms ease-out; }

scrollbar slider { min-width: 7px; min-height: 7px; margin: 3px; border: 1px solid black; border-radius: 10px; background-clip: padding-box; }

scrollbar slider:hover:active { background-color: #1a74d3; }

scrollbar slider:backdrop { background-color: #93989a; }

scrollbar slider:disabled { background-color: transparent; }

scrollbar.fine-tune slider { min-width: 4px; min-height: 4px; }

scrollbar.fine-tune.horizontal slider { border-width: 5px 4px; }

scrollbar.fine-tune.vertical slider { border-width: 4px 5px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) { border-color: transparent; opacity: 0.4; background-color: transparent; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider { margin: 0; min-width: 6px; min-height: 6px; background-color: shade(#eeeeec, 0.9); background-image: none; border: 1px solid black; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button { min-width: 5px; min-height: 5px; background-color: shade(#eeeeec, 0.9); background-image: none; background-clip: padding-box; border-radius: 100%; border: 1px solid black; -gtk-icon-source: none; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider { margin: 0 2px; min-width: 40px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button { margin: 1px 2px; min-width: 5px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider { margin: 2px 0; min-height: 40px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button { margin: 2px 1px; min-height: 5px; }

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering { opacity: 0.8; }

scrollbar.horizontal slider { min-width: 40px; }

scrollbar.vertical slider { min-height: 40px; }

scrollbar button { padding: 0; min-width: 12px; min-height: 12px; border-style: none; border-radius: 0; transition-property: min-height, min-width, color; border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #3b3e3f; }

scrollbar button:hover { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #cacbc9; }

scrollbar button:active, scrollbar button:checked { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #1a74d3; }

scrollbar button:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(59, 62, 63, 0.2); }

scrollbar button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #93989a; }

scrollbar button:backdrop:disabled, scrollbar label:disabled selection:backdrop, label:disabled scrollbar selection:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(147, 152, 154, 0.2); }

scrollbar.vertical button.down { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

scrollbar.vertical button.up { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

scrollbar.horizontal button.down { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

scrollbar.horizontal button.up { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

treeview ~ scrollbar.vertical { border-top: 1px solid #1d1f1f; margin-top: -1px; }

/********** Switch * */
switch { font-size: 0; outline-offset: -4px; box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), 0 1px transparent; border: 1px solid alpha(black,0.25); border-radius: 10px; background-color: #2f3232; text-shadow: 0 1px rgba(0, 0, 0, 0.1); min-height: 20px; min-width: 20px; transition: all 200ms ease-in; /* only show i / o for the accessible theme */ }

switch:checked { box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), 0 1px transparent; border-color: shade(#09294b, 1.1); background-image: linear-gradient(to bottom, shade(#145ba6, 1.1), #145ba6); text-shadow: 0 1px rgba(9, 41, 75, 0.5), 0 0 2px rgba(255, 255, 255, 0.6); }

switch:disabled { border-color: #1d1f1f; background-color: #353839; box-shadow: 0 1px transparent; text-shadow: none; }

switch:backdrop { border-color: #202223; background-color: #323435; box-shadow: none; text-shadow: none; transition: 200ms ease-out; }

switch:backdrop:checked { border-color: rgba(9, 41, 75, 0.7); background-color: rgba(20, 91, 166, 0.7); background-image: none; box-shadow: none; }

switch:disabled { border-color: #202223; background-image: none; background-color: #353839; }

switch slider { margin: -1px; border: 1px solid alpha(black,0.2); border-radius: 10px; min-width: 20px; min-height: 20px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #343637 20%, #2c2e2f 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #313434, inset 0 -1px #252727, 0 1px rgba(0, 0, 0, 0.1); }

switch image { color: transparent; }

switch:hover slider { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3b3e3f 20%, #313434 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #343637, inset 0 -1px #2c2e2f, 0 1px rgba(0, 0, 0, 0.1); }

switch:checked slider { border: 1px solid alpha(#09294b,0.8); }

switch:disabled slider { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:disabled slider label, switch:disabled slider { color: #959696; }

switch:backdrop slider { transition: 200ms ease-out; border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:backdrop slider label, switch:backdrop slider { color: #959696; }

switch:backdrop:checked slider { border-color: rgba(9, 41, 75, 0.7); }

switch:backdrop:disabled slider, label:disabled selection:backdrop slider { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:backdrop:disabled slider label, label:disabled selection:backdrop slider label, switch:backdrop:disabled slider, label:disabled selection:backdrop slider { color: #606567; }

/************************* Check and Radio items * */
.view.content-view.check:not(list), iconview.content-view.check:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:hover:not(list), iconview.content-view.check:hover:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-hover-selectionmode.png"), url("assets/checkbox-hover-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:active:not(list), iconview.content-view.check:active:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-active-selectionmode.png"), url("assets/checkbox-active-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:backdrop:not(list), iconview.content-view.check:backdrop:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-backdrop-selectionmode.png"), url("assets/checkbox-backdrop-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:checked:not(list), iconview.content-view.check:checked:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:checked:hover:not(list), iconview.content-view.check:checked:hover:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-hover-selectionmode.png"), url("assets/checkbox-checked-hover-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:checked:active:not(list), iconview.content-view.check:checked:active:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-active-selectionmode.png"), url("assets/checkbox-checked-active-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:backdrop:checked:not(list), iconview.content-view.check:backdrop:checked:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-backdrop-selectionmode.png"), url("assets/checkbox-checked-backdrop-selectionmode@2.png")); background-color: transparent; }

checkbutton.text-button, radiobutton.text-button { padding: 2px 0; outline-offset: 0; }

checkbutton.text-button label:not(:only-child):first-child, radiobutton.text-button label:not(:only-child):first-child { margin-left: 4px; }

checkbutton.text-button label:not(:only-child):last-child, radiobutton.text-button label:not(:only-child):last-child { margin-right: 4px; }

check, radio { margin: 0 4px; min-height: 14px; min-width: 14px; border: 1px solid; -gtk-icon-source: none; color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #0a0a0a; background-image: linear-gradient(to bottom, #404344 20%, #393b3c 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #3d4142, inset 0 -1px #313434, 0 1px rgba(0, 0, 0, 0.1); }

check:only-child, radio:only-child { margin: 0; }

check:hover, radio:hover { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3b3e3f 20%, #313434 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #343637, inset 0 -1px #2c2e2f, 0 1px rgba(0, 0, 0, 0.1); }

check:active, radio:active { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #252727, #2f3132); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

check:disabled, radio:disabled { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

check:disabled label, check:disabled, radio:disabled label, radio:disabled { color: #959696; }

check:backdrop, radio:backdrop { border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); transition: 200ms ease-out; }

check:backdrop label, check:backdrop, radio:backdrop label, radio:backdrop { color: #959696; }

check:backdrop:disabled, label:disabled selection:backdrop, radio:backdrop:disabled { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

check:backdrop:disabled label, label:disabled selection:backdrop label, check:backdrop:disabled, label:disabled selection:backdrop, radio:backdrop:disabled label, radio:backdrop:disabled { color: #606567; }

.osd check, .osd radio { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd check:hover, .osd radio:hover { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd check:active, .osd radio:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd check:backdrop, .osd radio:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd check:disabled, .osd radio:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

menu menuitem check, menu menuitem radio { margin: 0; }

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem radio, menu menuitem radio:hover, menu menuitem radio:disabled { min-height: 14px; min-width: 14px; background-image: none; background-color: transparent; box-shadow: none; -gtk-icon-shadow: none; color: inherit; border-color: currentColor; animation: none; }

check { border-radius: 3px; }

check:checked { -gtk-icon-source: image(-gtk-recolor(url("assets/check-symbolic.svg")), -gtk-recolor(url("assets/check-symbolic.symbolic.png"))); }

check:indeterminate { -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }

treeview.view radio:selected:focus, treeview.view radio:selected, treeview.view headerbar.selection-mode radio.subtitle:link, headerbar.selection-mode treeview.view radio.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:link, radio { border-radius: 100%; }

treeview.view radio:checked:selected, treeview.view headerbar.selection-mode radio.subtitle:checked:link, headerbar.selection-mode treeview.view radio.subtitle:checked:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:checked:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:checked:link, radio:checked { -gtk-icon-source: image(-gtk-recolor(url("assets/bullet-symbolic.svg")), -gtk-recolor(url("assets/bullet-symbolic.symbolic.png"))); }

treeview.view radio:indeterminate:selected, treeview.view headerbar.selection-mode radio.subtitle:indeterminate:link, headerbar.selection-mode treeview.view radio.subtitle:indeterminate:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:indeterminate:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:indeterminate:link, radio:indeterminate { -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }

@keyframes check_check { from { -gtk-icon-transform: translate(6px, -3px) rotate(-45deg) scaleY(0.2) rotate(45deg) scaleX(0); }
  to { -gtk-icon-transform: unset; } }

@keyframes check_radio { from { -gtk-icon-transform: scale(0); }
  to { -gtk-icon-transform: unset; } }

@keyframes check_indeterminate { from { -gtk-icon-transform: scale(0, 1); }
  to { -gtk-icon-transform: unset; } }

check:not(:indeterminate):checked { animation: check_check 400ms; }

radio:not(:indeterminate):checked { animation: check_radio 400ms; }

check:indeterminate:checked, radio:indeterminate:checked { animation: check_indeterminate 400ms; }

menu menuitem check:not(:indeterminate):checked, menu menuitem radio:not(:indeterminate):checked, menu menuitem check:indeterminate:checked:active, menu menuitem radio:indeterminate:checked { animation: none; }

treeview.view check:selected:focus, treeview.view check:selected, treeview.view headerbar.selection-mode check.subtitle:link, headerbar.selection-mode treeview.view check.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) check.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view check.subtitle:link, treeview.view radio:selected:focus, treeview.view radio:selected, treeview.view headerbar.selection-mode radio.subtitle:link, headerbar.selection-mode treeview.view radio.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:link { color: #eeeeec; }

treeview.view check:selected:disabled, treeview.view radio:selected:disabled { color: #959696; }

treeview.view check:selected:disabled:backdrop, treeview.view radio:selected:disabled:backdrop { color: #606567; }

treeview.view check:backdrop:selected, treeview.view headerbar.selection-mode .subtitle:backdrop:link, headerbar.selection-mode treeview.view .subtitle:backdrop:link, treeview.view .selection-mode.titlebar:not(headerbar) .subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) treeview.view .subtitle:backdrop:link, treeview.view check:backdrop, treeview.view radio:backdrop:selected, treeview.view radio:backdrop { color: #959696; }

/************ GtkScale * */
progressbar trough, scale fill, scale trough { border: 1px solid #1d1f1f; border-radius: 3px; background-color: #313334; box-shadow: inset 1px 1px rgba(0, 0, 0, 0.1); }

progressbar trough:disabled, scale fill:disabled, scale trough:disabled { background-color: #353839; box-shadow: none; }

progressbar trough:backdrop, scale fill:backdrop, scale trough:backdrop { background-color: #323435; border-color: #202223; box-shadow: none; transition: 200ms ease-out; }

progressbar trough:backdrop:disabled, scale fill:backdrop:disabled, scale trough:backdrop:disabled, label:disabled selection:backdrop { background-color: #353839; }

row:selected progressbar trough, progressbar row:selected trough, row:selected scale fill, scale row:selected fill, row:selected scale trough, scale row:selected trough, headerbar.selection-mode row.subtitle:link progressbar trough, progressbar headerbar.selection-mode row.subtitle:link trough, headerbar.selection-mode row.subtitle:link scale fill, scale headerbar.selection-mode row.subtitle:link fill, headerbar.selection-mode row.subtitle:link scale trough, scale headerbar.selection-mode row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link progressbar trough, progressbar .selection-mode.titlebar:not(headerbar) row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale fill, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link fill, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale trough, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link trough { box-shadow: none; }

row:selected progressbar trough, progressbar row:selected trough, row:selected scale fill, scale row:selected fill, row:selected scale trough, scale row:selected trough, headerbar.selection-mode row.subtitle:link progressbar trough, progressbar headerbar.selection-mode row.subtitle:link trough, headerbar.selection-mode row.subtitle:link scale fill, scale headerbar.selection-mode row.subtitle:link fill, headerbar.selection-mode row.subtitle:link scale trough, scale headerbar.selection-mode row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link progressbar trough, progressbar .selection-mode.titlebar:not(headerbar) row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale fill, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link fill, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale trough, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link trough { border-color: #09294b; }

.osd progressbar trough, progressbar .osd trough, .osd scale fill, scale .osd fill, .osd scale trough, scale .osd trough { border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); box-shadow: none; outline-color: rgba(238, 238, 238, 0.2); }

.osd progressbar trough:disabled, progressbar .osd trough:disabled, .osd scale fill:disabled, scale .osd fill:disabled, .osd scale trough:disabled, scale .osd trough:disabled { background-color: rgba(34, 34, 34, 0.8); }

progressbar progress, scale highlight { border: 1px solid shade(#145ba6, 0.7); border-radius: 3px; background-image: linear-gradient(to bottom, shade(#145ba6, 1.1), shade(#145ba6, 0.9)); }

progressbar progress:disabled, scale highlight:disabled { background-color: transparent; border-color: transparent; }

progressbar progress:backdrop, scale highlight:backdrop { border-color: rgba(9, 41, 75, 0.7); background-color: rgba(20, 91, 166, 0.7); background-image: none; }

progressbar progress:backdrop:disabled, scale highlight:backdrop:disabled, label:disabled selection:backdrop { background-color: transparent; border-color: transparent; }

row:selected progressbar progress, progressbar row:selected progress, row:selected scale highlight, scale row:selected highlight, headerbar.selection-mode row.subtitle:link progressbar progress, progressbar headerbar.selection-mode row.subtitle:link progress, headerbar.selection-mode row.subtitle:link scale highlight, scale headerbar.selection-mode row.subtitle:link highlight, .selection-mode.titlebar:not(headerbar) row.subtitle:link progressbar progress, progressbar .selection-mode.titlebar:not(headerbar) row.subtitle:link progress, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale highlight, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link highlight { border-color: #09294b; }

.osd progressbar progress, progressbar .osd progress, .osd scale highlight, scale .osd highlight { border-color: rgba(0, 0, 0, 0.7); }

.osd progressbar progress:disabled, progressbar .osd progress:disabled, .osd scale highlight:disabled, scale .osd highlight:disabled { border-color: transparent; }

scale { min-height: 10px; min-width: 10px; padding: 12px; }

scale fill, scale highlight { margin: -2px; }

scale slider { min-height: 13px; min-width: 13px; margin: -7px; }

scale.fine-tune.horizontal { padding-top: 9px; padding-bottom: 9px; min-height: 16px; }

scale.fine-tune.vertical { padding-left: 9px; padding-right: 9px; min-width: 16px; }

scale.fine-tune slider { margin: -6px; }

scale.fine-tune fill, scale.fine-tune highlight, scale.fine-tune trough { border-radius: 5px; -gtk-outline-radius: 7px; }

scale trough { padding: 1px; outline-offset: 2px; -gtk-outline-radius: 5px; }

scale fill, scale fill:backdrop { background-color: #1d1f1f; box-shadow: none; }

scale fill:disabled, scale fill:disabled:backdrop { border-color: transparent; background-color: transparent; }

.osd scale fill { background-color: rgba(91, 91, 91, 0.775); }

.osd scale fill:disabled, .osd scale fill:disabled:backdrop { border-color: transparent; background-color: transparent; }

scale slider { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #36393a, #313434 60%, #2c2e2f); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); background-image: linear-gradient(to bottom, shade(#3b3e3f, 1.45), shade(#3b3e3f, 1.15)); border: 1px solid #161717; border-radius: 100%; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-property: background, border, box-shadow; }

scale slider:hover { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3b3e3f 20%, #313434 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 0 -2px #343637, inset 0 -1px #2c2e2f, 0 1px rgba(0, 0, 0, 0.1); }

scale slider:active { border-color: #09294b; }

scale slider:disabled { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:disabled label, scale slider:disabled { color: #959696; }

scale slider:backdrop { transition: 200ms ease-out; border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:backdrop label, scale slider:backdrop { color: #959696; }

scale slider:backdrop:disabled, scale label:disabled selection:backdrop, label:disabled scale selection:backdrop { border-color: #202223; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:backdrop:disabled label, scale label:disabled selection:backdrop label, label:disabled scale selection:backdrop label, scale slider:backdrop:disabled, scale label:disabled selection:backdrop, label:disabled scale selection:backdrop { color: #606567; }

row:selected scale slider, headerbar.selection-mode row.subtitle:link scale slider, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale slider, row:selected scale slider:disabled, headerbar.selection-mode row.subtitle:link scale slider:disabled { border-color: #09294b; }

.osd scale slider { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); border-color: rgba(0, 0, 0, 0.7); background-color: #222222; }

.osd scale slider:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd scale slider:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd scale slider:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd scale slider:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

scale value { color: alpha(currentColor,0.6); }

scale marks { color: alpha(currentColor,0.4); }

scale marks.top { margin-bottom: 6px; margin-top: -12px; }

scale marks.bottom { margin-top: 6px; margin-bottom: -12px; }

scale marks.top { margin-right: 6px; margin-left: -12px; }

scale marks.bottom { margin-left: 6px; margin-right: -12px; }

scale.fine-tune marks.top { margin-bottom: 6px; margin-top: -9px; }

scale.fine-tune marks.bottom { margin-top: 6px; margin-bottom: -9px; }

scale.fine-tune marks.top { margin-right: 6px; margin-left: -9px; }

scale.fine-tune marks.bottom { margin-left: 6px; margin-right: -9px; }

scale.horizontal indicator { min-height: 6px; min-width: 1px; }

scale.horizontal.fine-tune indicator { min-height: 3px; }

scale.vertical indicator { min-height: 1px; min-width: 6px; }

scale.vertical.fine-tune indicator { min-width: 3px; }

scale.color { min-height: 0; min-width: 0; }

scale.color trough { background-image: image(#1d1f1f); background-repeat: no-repeat; }

scale.color.horizontal { padding: 0 0 15px 0; }

scale.color.horizontal trough { padding-bottom: 4px; background-position: 0 -3px; border-top-left-radius: 0; border-top-right-radius: 0; }

scale.color.horizontal slider:dir(ltr):hover, scale.color.horizontal slider:dir(ltr):backdrop, scale.color.horizontal slider:dir(ltr):disabled, scale.color.horizontal label:disabled selection:dir(ltr), label:disabled scale.color.horizontal selection:dir(ltr), scale.color.horizontal slider:dir(ltr):backdrop:disabled, scale.color.horizontal label:disabled selection:backdrop, label:disabled scale.color.horizontal selection:backdrop, scale.color.horizontal slider:dir(ltr), scale.color.horizontal slider:dir(rtl):hover, scale.color.horizontal slider:dir(rtl):backdrop, scale.color.horizontal slider:dir(rtl):disabled, scale.color.horizontal label:disabled selection:dir(rtl), label:disabled scale.color.horizontal selection:dir(rtl), scale.color.horizontal slider:dir(rtl):backdrop:disabled, scale.color.horizontal slider:dir(rtl) { margin-bottom: -15px; margin-top: 6px; }

scale.color.vertical:dir(ltr) { padding: 0 0 0 15px; }

scale.color.vertical:dir(ltr) trough { padding-left: 4px; background-position: 3px 0; border-bottom-right-radius: 0; border-top-right-radius: 0; }

scale.color.vertical:dir(ltr) slider:hover, scale.color.vertical:dir(ltr) slider:backdrop, scale.color.vertical:dir(ltr) slider:disabled, scale.color.vertical:dir(ltr) slider:backdrop:disabled, scale.color.vertical:dir(ltr) label:disabled selection:backdrop, label:disabled scale.color.vertical:dir(ltr) selection:backdrop, scale.color.vertical:dir(ltr) slider { margin-left: -15px; margin-right: 6px; }

scale.color.vertical:dir(rtl) { padding: 0 15px 0 0; }

scale.color.vertical:dir(rtl) trough { padding-right: 4px; background-position: -3px 0; border-bottom-left-radius: 0; border-top-left-radius: 0; }

scale.color.vertical:dir(rtl) slider:hover, scale.color.vertical:dir(rtl) slider:backdrop, scale.color.vertical:dir(rtl) slider:disabled, scale.color.vertical:dir(rtl) slider:backdrop:disabled, scale.color.vertical:dir(rtl) label:disabled selection:backdrop, label:disabled scale.color.vertical:dir(rtl) selection:backdrop, scale.color.vertical:dir(rtl) slider { margin-right: -15px; margin-left: 6px; }

scale.color.fine-tune.horizontal:dir(ltr), scale.color.fine-tune.horizontal:dir(rtl) { padding: 0 0 12px 0; }

scale.color.fine-tune.horizontal:dir(ltr) trough, scale.color.fine-tune.horizontal:dir(rtl) trough { padding-bottom: 7px; background-position: 0 -6px; }

scale.color.fine-tune.horizontal:dir(ltr) slider, scale.color.fine-tune.horizontal:dir(rtl) slider { margin-bottom: -15px; margin-top: 6px; }

scale.color.fine-tune.vertical:dir(ltr) { padding: 0 0 0 12px; }

scale.color.fine-tune.vertical:dir(ltr) trough { padding-left: 7px; background-position: 6px 0; }

scale.color.fine-tune.vertical:dir(ltr) slider { margin-left: -15px; margin-right: 6px; }

scale.color.fine-tune.vertical:dir(rtl) { padding: 0 12px 0 0; }

scale.color.fine-tune.vertical:dir(rtl) trough { padding-right: 7px; background-position: -6px 0; }

scale.color.fine-tune.vertical:dir(rtl) slider { margin-right: -15px; margin-left: 6px; }

/***************** Progress bars * */
progressbar { font-size: smaller; color: rgba(238, 238, 236, 0.4); font-feature-settings: "tnum"; }

progressbar.horizontal trough { min-height: 6px; padding: 1px 0; }

progressbar.horizontal progress { min-height: 8px; }

progressbar.vertical trough { min-width: 6px; padding: 0 1px; }

progressbar.vertical progress { min-width: 8px; }

progressbar.horizontal progress, progressbar.vertical progress { margin: 0; }

progressbar:backdrop { box-shadow: none; transition: 200ms ease-out; }

progressbar progress { border: 1px solid shade(#145ba6, 0.7); border-radius: 3px; }

progressbar progress.left { border-top-left-radius: 3px; border-bottom-left-radius: 3px; }

progressbar progress.right { border-top-right-radius: 3px; border-bottom-right-radius: 3px; }

progressbar progress.top { border-top-right-radius: 3px; border-top-left-radius: 3px; }

progressbar progress.bottom { border-bottom-right-radius: 3px; border-bottom-left-radius: 3px; }

progressbar.osd { min-width: 3px; min-height: 3px; background-color: transparent; }

progressbar.osd trough { border-style: none; border-radius: 0; background-color: transparent; box-shadow: none; }

progressbar.osd progress { border-style: none; border-radius: 0; }

progressbar trough.empty progress { all: unset; }

/************* Level Bar * */
levelbar block { min-width: 32px; min-height: 1px; }

levelbar.vertical block { min-width: 1px; min-height: 32px; }

levelbar:backdrop { transition: 200ms ease-out; }

levelbar trough { border: 1px solid; padding: 2px; border-radius: 3px; color: white; border-color: #1d1f1f; background-color: #2d2e30; box-shadow: inset 0 0 0 1px rgba(20, 91, 166, 0); }

levelbar trough:backdrop { color: #d5d6d6; border-color: #202223; background-color: #2f3133; box-shadow: none; }

levelbar.horizontal.discrete block { margin: 0 1px; }

levelbar.vertical.discrete block { margin: 1px 0; }

levelbar block { border: 1px solid; border-radius: 1px; box-shadow: 0 1px rgba(0, 0, 0, 0.2); }

levelbar block:backdrop { box-shadow: none; }

levelbar block.low { border-color: #f57900; background-color: #f57900; }

levelbar block.low:backdrop { border-color: #f57900; }

levelbar block.high, levelbar block:not(.empty) { border-color: #145ba6; background-color: #145ba6; }

levelbar block.high:backdrop, levelbar block:not(.empty):backdrop { border-color: #145ba6; }

levelbar block.full { border-color: #356904; background-color: #356904; }

levelbar block.full:backdrop { border-color: #356904; }

levelbar block.empty { background-color: transparent; border-color: rgba(238, 238, 236, 0.1); box-shadow: none; }

levelbar block.empty:backdrop { border-color: rgba(149, 150, 150, 0.15); }

/**************** Print dialog * */
printdialog paper { color: #eeeeec; border: 1px solid #1d1f1f; background: white; padding: 0; }

printdialog paper:backdrop { color: #959696; border-color: #202223; }

printdialog .dialog-vbox { background-color: #3b3e3f; }

printdialog .dialog-vbox:backdrop { background-color: #3b3e3f; }

printdialog .dialog-action-box { margin: 12px; }

/********** Frames * */
frame > border, .frame { box-shadow: none; margin: 0; padding: 0; border-radius: 0; border: 1px solid #1d1f1f; }

frame > border.flat, .frame.flat, button.frame.titlebutton, button.frame.sidebar-button, popover.background checkbutton.frame, popover.background radiobutton.frame, notebook > header > tabs > arrow.frame { border-style: none; }

frame > border:backdrop, .frame:backdrop { border-color: #202223; }

actionbar > revealer > box { padding: 6px; border-top: 1px solid #1d1f1f; }

actionbar > revealer > box:backdrop { border-color: #202223; }

scrolledwindow viewport.frame { border-style: none; }

scrolledwindow overshoot.top { background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#050505), to(rgba(5, 5, 5, 0))), -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(238, 238, 236, 0.07)), to(rgba(238, 238, 236, 0))); background-size: 100% 5%, 100% 100%; background-repeat: no-repeat; background-position: center top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.top:backdrop { background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#202223), to(rgba(32, 34, 35, 0))); background-size: 100% 5%; background-repeat: no-repeat; background-position: center top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.bottom { background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#050505), to(rgba(5, 5, 5, 0))), -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(238, 238, 236, 0.07)), to(rgba(238, 238, 236, 0))); background-size: 100% 5%, 100% 100%; background-repeat: no-repeat; background-position: center bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.bottom:backdrop { background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#202223), to(rgba(32, 34, 35, 0))); background-size: 100% 5%; background-repeat: no-repeat; background-position: center bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.left { background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#050505), to(rgba(5, 5, 5, 0))), -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(238, 238, 236, 0.07)), to(rgba(238, 238, 236, 0))); background-size: 5% 100%, 100% 100%; background-repeat: no-repeat; background-position: left center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.left:backdrop { background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#202223), to(rgba(32, 34, 35, 0))); background-size: 5% 100%; background-repeat: no-repeat; background-position: left center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.right { background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#050505), to(rgba(5, 5, 5, 0))), -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(238, 238, 236, 0.07)), to(rgba(238, 238, 236, 0))); background-size: 5% 100%, 100% 100%; background-repeat: no-repeat; background-position: right center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.right:backdrop { background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#202223), to(rgba(32, 34, 35, 0))); background-size: 5% 100%; background-repeat: no-repeat; background-position: right center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow undershoot.top { background-color: transparent; background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-top: 1px; background-size: 10px 1px; background-repeat: repeat-x; background-origin: content-box; background-position: center top; border: none; box-shadow: none; }

scrolledwindow undershoot.bottom { background-color: transparent; background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-bottom: 1px; background-size: 10px 1px; background-repeat: repeat-x; background-origin: content-box; background-position: center bottom; border: none; box-shadow: none; }

scrolledwindow undershoot.left { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-left: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: left center; border: none; box-shadow: none; }

scrolledwindow undershoot.right { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-right: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: right center; border: none; box-shadow: none; }

scrolledwindow junction { border-color: transparent; border-image: linear-gradient(to bottom, #1d1f1f 1px, transparent 1px) 0 0 0 1/0 1px stretch; background-color: #343638; }

scrolledwindow junction:dir(rtl) { border-image-slice: 0 1 0 0; }

scrolledwindow junction:backdrop { border-image-source: linear-gradient(to bottom, #202223 1px, transparent 1px); background-color: #343637; transition: 200ms ease-out; }

separator { background: rgba(0, 0, 0, 0.1); min-width: 1px; min-height: 1px; }

/********* Lists * */
list { color: white; background-color: #2d2e30; border-color: #1d1f1f; }

list:backdrop { color: #d5d6d6; background-color: #2f3133; border-color: #202223; }

list row { padding: 2px; }

list row.expander { padding: 0px; }

list row.expander .row-header { padding: 2px; }

list.separators row:not(:first-child) { border-top: 1px solid #1d1f1f; }

row { transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row:hover { transition: none; }

row:backdrop { transition: 200ms ease-out; }

row.activatable.has-open-popup, row.activatable:hover { background-color: rgba(238, 238, 236, 0.05); }

row.activatable:active { box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }

row.activatable:backdrop:hover { background-color: transparent; }

row.activatable:selected:active, headerbar.selection-mode .activatable.subtitle:active:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:active:link { box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }

row.activatable:selected.has-open-popup, headerbar.selection-mode .activatable.has-open-popup.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.has-open-popup.subtitle:link, row.activatable:selected:hover, headerbar.selection-mode .activatable.subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:hover:link { background-color: #2a6aad; }

/********************* App Notifications * */
.app-notification, .app-notification.frame { padding: 10px; border-radius: 0 0 5px 5px; background-color: rgba(34, 34, 34, 0.8); background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px); background-clip: padding-box; }

.app-notification:backdrop, .app-notification.frame:backdrop { background-image: none; transition: 200ms ease-out; }

.app-notification border, .app-notification.frame border { border: none; }

/************* Expanders * */
expander title > arrow { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

expander title > arrow:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

expander title > arrow:hover { color: white; }

expander title > arrow:disabled { color: #959696; }

expander title > arrow:disabled:backdrop { color: #606567; }

expander title > arrow:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

/************ Calendar * */
calendar { color: white; border: 1px solid #1d1f1f; }

calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link { border-radius: 3px; }

calendar.header { border-bottom-color: rgba(0, 0, 0, 0.1); }

calendar.header:backdrop { border-bottom-color: rgba(0, 0, 0, 0.1); }

calendar.button { color: rgba(238, 238, 236, 0.45); }

calendar.button:hover { color: #eeeeec; }

calendar.button:backdrop { color: rgba(149, 150, 150, 0.45); }

calendar.button:disabled, label:disabled selection.button { color: rgba(149, 150, 150, 0.45); }

calendar.highlight { color: #959696; }

calendar.highlight:backdrop { color: #606567; }

calendar:backdrop { color: #d5d6d6; border-color: #202223; }

calendar:indeterminate { color: alpha(currentColor,0.1); }

/*********** Dialogs * */
messagedialog .titlebar { min-height: 20px; background-image: none; background-color: #3b3e3f; border-style: none; border-top-left-radius: 7px; border-top-right-radius: 7px; }

messagedialog.csd.background { border-bottom-left-radius: 9px; border-bottom-right-radius: 9px; }

messagedialog.csd .dialog-action-area { padding: 0px; }

messagedialog.csd .dialog-action-area button { padding: 3px; border-radius: 0px; border-left-style: solid; border-right-style: none; border-bottom-style: none; }

messagedialog.csd .dialog-action-area button:first-child, messagedialog.csd .dialog-action-area combobox.linked button:nth-child(2):dir(rtl), combobox.linked messagedialog.csd .dialog-action-area button:nth-child(2):dir(rtl), messagedialog.csd .dialog-action-area .linked:not(.vertical) > combobox:first-child > box > button.combo, messagedialog.csd .dialog-action-area .linked.vertical > combobox:first-child > box > button.combo { border-left-style: none; border-bottom-left-radius: 7px; -gtk-outline-bottom-left-radius: 5px; }

messagedialog.csd .dialog-action-area button:last-child, messagedialog.csd .dialog-action-area combobox.linked button:nth-child(2):dir(ltr), combobox.linked messagedialog.csd .dialog-action-area button:nth-child(2):dir(ltr), messagedialog.csd .dialog-action-area .linked:not(.vertical) > combobox:last-child > box > button.combo, messagedialog.csd .dialog-action-area .linked.vertical > combobox:last-child > box > button.combo { border-bottom-right-radius: 7px; -gtk-outline-bottom-right-radius: 5px; }

filechooser .dialog-action-box { border-top: 1px solid #1d1f1f; }

filechooser .dialog-action-box:backdrop { border-top-color: #202223; }

filechooser #pathbarbox { border-bottom: 1px solid #3b3e3f; }

filechooser #pathbarbox stack { background-color: #3b3e3f; }

filechooserbutton:drop(active) { box-shadow: none; border-color: transparent; }

/*********** Sidebar * */
.sidebar { border-style: none; background-color: #222; }

.sidebar row, .sidebar treeview { border-top: 1px solid transparent; border-bottom: 1px solid transparent; }

.sidebar row:selected, .sidebar headerbar.selection-mode row.subtitle:link, headerbar.selection-mode .sidebar row.subtitle:link, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:link, .sidebar row:selected:focus, .sidebar treeview:selected, .sidebar headerbar.selection-mode treeview.subtitle:link, headerbar.selection-mode .sidebar treeview.subtitle:link, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:link, .sidebar treeview:selected:focus { background-image: linear-gradient(to bottom, shade(#222, 0.87), shade(#222, 0.95) 10%, shade(#222, 0.99) 92%, shade(#222, 0.92)); border-top: 1px solid shade(#3b3e3f, 0.85); border-bottom: 1px solid shade(#3b3e3f, 1.12); }

.sidebar row:selected label, .sidebar headerbar.selection-mode row.subtitle:link label, headerbar.selection-mode .sidebar row.subtitle:link label, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link label, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:link label, .sidebar row:selected:focus label, .sidebar treeview:selected label, .sidebar headerbar.selection-mode treeview.subtitle:link label, headerbar.selection-mode .sidebar treeview.subtitle:link label, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:link label, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:link label, .sidebar treeview:selected:focus label { color: #eeeeec; }

.sidebar row:selected label:backdrop, .sidebar headerbar.selection-mode row.subtitle:link label:backdrop, headerbar.selection-mode .sidebar row.subtitle:link label:backdrop, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link label:backdrop, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:link label:backdrop, .sidebar row:selected:focus label:backdrop, .sidebar treeview:selected label:backdrop, .sidebar headerbar.selection-mode treeview.subtitle:link label:backdrop, headerbar.selection-mode .sidebar treeview.subtitle:link label:backdrop, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:link label:backdrop, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:link label:backdrop, .sidebar treeview:selected:focus label:backdrop { color: #959696; }

.sidebar row:selected:backdrop, .sidebar headerbar.selection-mode row.subtitle:backdrop:link, headerbar.selection-mode .sidebar row.subtitle:backdrop:link, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:backdrop:link, .sidebar row:selected:focus:backdrop, .sidebar treeview:selected:backdrop, .sidebar headerbar.selection-mode treeview.subtitle:backdrop:link, headerbar.selection-mode .sidebar treeview.subtitle:backdrop:link, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:backdrop:link, .sidebar treeview:selected:focus:backdrop { background-image: none; background-color: #3b3e3f; color: #eeeeec; border-top: 1px solid shade(#3b3e3f, 0.9); border-bottom: 1px solid shade(#3b3e3f, 0.9); }

.sidebar row .view:selected, .sidebar row iconview:selected, .sidebar row headerbar.selection-mode .view.subtitle:link, headerbar.selection-mode .sidebar row .view.subtitle:link, .sidebar row headerbar.selection-mode iconview.subtitle:link, headerbar.selection-mode .sidebar row iconview.subtitle:link, .sidebar row .selection-mode.titlebar:not(headerbar) .view.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar row .view.subtitle:link, .sidebar row .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar row iconview.subtitle:link, .sidebar row .view:selected:focus, .sidebar treeview .view:selected, .sidebar treeview iconview:selected, .sidebar treeview headerbar.selection-mode .view.subtitle:link, headerbar.selection-mode .sidebar treeview .view.subtitle:link, .sidebar treeview headerbar.selection-mode iconview.subtitle:link, headerbar.selection-mode .sidebar treeview iconview.subtitle:link, .sidebar treeview .selection-mode.titlebar:not(headerbar) .view.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview .view.subtitle:link, .sidebar treeview .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview iconview.subtitle:link, .sidebar treeview .view:selected:focus { color: #eeeeec; }

.sidebar row:backdrop, .sidebar treeview:backdrop { background-color: transparent; }

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left { border-right: 1px solid #1d1f1f; border-left-style: none; border-top-style: none; border-bottom-style: none; }

stacksidebar.sidebar:dir(rtl) list .sidebar:dir(rtl), stacksidebar.sidebar.right list .sidebar:dir(rtl), .sidebar.right { border-left: 1px solid #1d1f1f; border-right-style: none; border-top-style: none; border-bottom-style: none; }

.sidebar:backdrop { background-color: #353739; border-color: #202223; transition: 200ms ease-out; }

.sidebar list, .sidebar treeview { background-color: transparent; }

.sidebar list:backdrop, .sidebar treeview:backdrop { background-color: transparent; }

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar { border-style: none; }

stacksidebar row { padding: 10px 4px; }

stacksidebar row > label { padding-left: 6px; padding-right: 6px; }

stacksidebar row.needs-attention > label { background-size: 6px 6px, 0 0; }

/**************** File chooser * */
placessidebar > viewport.frame { border-style: none; }

placessidebar row { min-height: 24px; padding: 0px; }

placessidebar row > revealer { padding: 0 14px; }

placessidebar row:selected, placessidebar headerbar.selection-mode row.subtitle:link, headerbar.selection-mode placessidebar row.subtitle:link, placessidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link, .selection-mode.titlebar:not(headerbar) placessidebar row.subtitle:link { color: #eeeeec; }

placessidebar row:disabled { color: #959696; }

placessidebar row:backdrop { color: #959696; background-color: #3b3e3f; }

placessidebar row:backdrop:selected, placessidebar headerbar.selection-mode .subtitle:backdrop:link, headerbar.selection-mode placessidebar .subtitle:backdrop:link, placessidebar .selection-mode.titlebar:not(headerbar) .subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) placessidebar .subtitle:backdrop:link { color: #959696; }

placessidebar row:backdrop:disabled, placessidebar label:disabled selection:backdrop, label:disabled placessidebar selection:backdrop { color: #606567; }

placessidebar row image.sidebar-icon:dir(ltr) { padding-right: 8px; }

placessidebar row image.sidebar-icon:dir(rtl) { padding-left: 8px; }

placessidebar row label.sidebar-label:dir(ltr) { padding-right: 2px; }

placessidebar row label.sidebar-label:dir(rtl) { padding-left: 2px; }

button.sidebar-button { min-height: 26px; min-width: 26px; margin-top: 3px; margin-bottom: 3px; padding: 0; border-radius: 100%; -gtk-outline-radius: 100%; }

button.sidebar-button:not(:hover):not(:active) > image, button.sidebar-button:backdrop > image { opacity: 0.7; }

placessidebar row:selected:active, placessidebar headerbar.selection-mode row.subtitle:active:link, headerbar.selection-mode placessidebar row.subtitle:active:link, placessidebar .selection-mode.titlebar:not(headerbar) row.subtitle:active:link, .selection-mode.titlebar:not(headerbar) placessidebar row.subtitle:active:link { box-shadow: none; }

placessidebar row.sidebar-placeholder-row { padding: 0 8px; min-height: 2px; background-image: image(#4e9a06); background-clip: content-box; }

placessidebar row.sidebar-new-bookmark-row { color: #145ba6; }

placessidebar row:drop(active):not(:disabled) { color: #4e9a06; box-shadow: inset 0 1px #4e9a06, inset 0 -1px #4e9a06; }

placessidebar row:drop(active):not(:disabled):selected { color: #ffffff; background-image: linear-gradient(to bottom, #4293e8, #66a8ec 10%, #78b2ee 92%, #59a0eb); }

placesview .server-list-button > image { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(0turn); }

placesview .server-list-button:checked > image { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(-0.5turn); }

placesview row.activatable:hover { background-color: transparent; }

placesview > actionbar > revealer > box > label { padding-left: 8px; padding-right: 8px; }

/********* Paned * */
paned > separator { min-width: 1px; min-height: 1px; -gtk-icon-source: none; border-style: none; background-color: transparent; background-image: image(#1d1f1f); background-size: 1px 1px; }

paned > separator:selected, headerbar.selection-mode paned > separator.subtitle:link, .selection-mode.titlebar:not(headerbar) paned > separator.subtitle:link { background-image: image(#145ba6); }

paned > separator:backdrop { background-image: image(#202223); }

paned > separator.wide { min-width: 5px; min-height: 5px; background-color: #3b3e3f; background-image: image(#1d1f1f), image(#1d1f1f); background-size: 1px 1px, 1px 1px; }

paned > separator.wide:backdrop { background-color: #3b3e3f; background-image: image(#202223), image(#202223); }

paned.horizontal > separator { background-repeat: repeat-y; }

paned.horizontal > separator:dir(ltr) { margin: 0 -8px 0 0; padding: 0 8px 0 0; background-position: left; }

paned.horizontal > separator:dir(rtl) { margin: 0 0 0 -8px; padding: 0 0 0 8px; background-position: right; }

paned.horizontal > separator.wide { margin: 0; padding: 0; background-repeat: repeat-y, repeat-y; background-position: left, right; }

paned.vertical > separator { margin: 0 0 -8px 0; padding: 0 0 8px 0; background-repeat: repeat-x; background-position: top; }

paned.vertical > separator.wide { margin: 0; padding: 0; background-repeat: repeat-x, repeat-x; background-position: bottom, top; }

/************** GtkInfoBar * */
infobar { border-style: none; }

.info, .question, .warning, .error { text-shadow: 0 1px #0f4278; }

.info:backdrop, .info, .question:backdrop, .question, .warning:backdrop, .warning, .error:backdrop, .error { background-color: #145ba6; border-color: #0f4278; }

.info:backdrop label, .info:backdrop, .info label, .info, .question:backdrop label, .question:backdrop, .question label, .question, .warning:backdrop label, .warning:backdrop, .warning label, .warning, .error:backdrop label, .error:backdrop, .error label, .error { color: #ffffff; }

.info:backdrop, .question:backdrop, .warning:backdrop, .error:backdrop { text-shadow: none; }

.info button, .question button, .warning button, .error button { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #13569d, #125194 60%, #114c8b); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); border-color: #09294b; }

.info button:hover, .question button:hover, .warning button:hover, .error button:hover { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #061d34; background-image: linear-gradient(to bottom, #155eaa, #13569d 60%, #125194); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

.info button:active, .info button:checked, .question button:active, .question button:checked, .warning button:active, .warning button:checked, .error button:active, .error button:checked { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #061d34; background-image: linear-gradient(to bottom, #0f457d, #114f8f); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

.info button:disabled, .question button:disabled, .warning button:disabled, .error button:disabled { border-color: #061d34; background-color: #185594; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.info button:disabled label, .info button:disabled, .question button:disabled label, .question button:disabled, .warning button:disabled label, .warning button:disabled, .error button:disabled label, .error button:disabled { color: #8caaca; }

.info button:backdrop, .question button:backdrop, .warning button:backdrop, .error button:backdrop { border-color: #061d34; background-color: #145ba6; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #061d34; }

.info button:backdrop label, .info button:backdrop, .question button:backdrop label, .question button:backdrop, .warning button:backdrop label, .warning button:backdrop, .error button:backdrop label, .error button:backdrop { color: #d0deed; }

.info button:backdrop:disabled, .info label:disabled selection:backdrop, label:disabled .info selection:backdrop, .question button:backdrop:disabled, .question label:disabled selection:backdrop, label:disabled .question selection:backdrop, .warning button:backdrop:disabled, .warning label:disabled selection:backdrop, label:disabled .warning selection:backdrop, .error button:backdrop:disabled, .error label:disabled selection:backdrop, label:disabled .error selection:backdrop { border-color: #061d34; background-color: #185594; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #061d34; }

.info button:backdrop:disabled label, .info label:disabled selection:backdrop label, label:disabled .info selection:backdrop label, .info button:backdrop:disabled, .info label:disabled selection:backdrop, label:disabled .info selection:backdrop, .question button:backdrop:disabled label, .question label:disabled selection:backdrop label, label:disabled .question selection:backdrop label, .question button:backdrop:disabled, .question label:disabled selection:backdrop, label:disabled .question selection:backdrop, .warning button:backdrop:disabled label, .warning label:disabled selection:backdrop label, label:disabled .warning selection:backdrop label, .warning button:backdrop:disabled, .warning label:disabled selection:backdrop, label:disabled .warning selection:backdrop, .error button:backdrop:disabled label, .error label:disabled selection:backdrop label, label:disabled .error selection:backdrop label, .error button:backdrop:disabled, .error label:disabled selection:backdrop, label:disabled .error selection:backdrop { color: #6991b9; }

.info label:selected:focus, .info label:selected:hover, .info label:selected, .info headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .info label.subtitle:link, .info .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .info label.subtitle:link, .question label:selected:focus, .question label:selected:hover, .question label:selected, .question headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .question label.subtitle:link, .question .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .question label.subtitle:link, .warning label:selected:focus, .warning label:selected:hover, .warning label:selected, .warning headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .warning label.subtitle:link, .warning .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .warning label.subtitle:link, .error label:selected:focus, .error label:selected:hover, .error label:selected, .error headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .error label.subtitle:link, .error .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .error label.subtitle:link { background-color: #0f4278; }

/************* Buttonbox * */
buttonbox { padding: 6px; }

/************ Tooltips * */
tooltip { padding: 1px; /* not working */ border-radius: 5px; box-shadow: none; text-shadow: 0 1px black; }

tooltip.background { background-color: rgba(0, 0, 0, 0.8); background-clip: padding-box; border: 1px solid rgba(255, 255, 255, 0.1); }

tooltip decoration { background-color: transparent; }

tooltip *, tooltip headerbar.selection-mode .subtitle:link, headerbar.selection-mode tooltip .subtitle:link, tooltip .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) tooltip .subtitle:link { padding: 1px; background-color: transparent; color: white; }

/***************** Color Chooser * */
colorswatch, colorswatch:drop(active) { border-style: none; }

colorswatch.top { border-top-left-radius: 5.5px; border-top-right-radius: 5.5px; }

colorswatch.top overlay { border-top-left-radius: 5px; border-top-right-radius: 5px; }

colorswatch.bottom { border-bottom-left-radius: 5.5px; border-bottom-right-radius: 5.5px; }

colorswatch.bottom overlay { border-bottom-left-radius: 5px; border-bottom-right-radius: 5px; }

colorswatch.left, colorswatch:first-child:not(.top) { border-top-left-radius: 5.5px; border-bottom-left-radius: 5.5px; }

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay { border-top-left-radius: 5px; border-bottom-left-radius: 5px; }

colorswatch.right, colorswatch:last-child:not(.bottom) { border-top-right-radius: 5.5px; border-bottom-right-radius: 5.5px; }

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay { border-top-right-radius: 5px; border-bottom-right-radius: 5px; }

colorswatch.dark overlay { color: #ffffff; }

colorswatch.dark overlay:hover { border-color: #1d1f1f; }

colorswatch.dark overlay:backdrop { color: #d5d6d6; }

colorswatch.light overlay { color: white; }

colorswatch.light overlay:hover { border-color: #1d1f1f; }

colorswatch.light overlay:backdrop { color: #d5d6d6; }

colorswatch:drop(active) { box-shadow: none; }

colorswatch:drop(active).light overlay { border-color: #4e9a06; box-shadow: inset 0 0 0 2px #1d1f1f, inset 0 0 0 1px #4e9a06; }

colorswatch:drop(active).dark overlay { border-color: #4e9a06; box-shadow: inset 0 0 0 2px #1d1f1f, inset 0 0 0 1px #4e9a06; }

colorswatch overlay { box-shadow: inset 0 3px 2px -2px rgba(0, 0, 0, 0.5); border: 1px solid #1d1f1f; }

colorswatch overlay:hover { box-shadow: inset 0 1px rgba(255, 255, 255, 0.3); }

colorswatch overlay:backdrop, colorswatch overlay:backdrop:hover { border-color: #1d1f1f; box-shadow: none; }

colorswatch#add-color-button { border-radius: 5px 5px 0 0; }

colorswatch#add-color-button:only-child, .linked:not(.vertical) > combobox:only-child > box > button#add-color-button.combo, .linked.vertical > combobox:only-child > box > button#add-color-button.combo { border-radius: 5px; }

colorswatch#add-color-button overlay { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #36393a, #313434 60%, #2c2e2f); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

colorswatch#add-color-button overlay:hover { color: #eeeeec; outline-color: rgba(238, 238, 236, 0.3); border-color: #1d1f1f; background-image: linear-gradient(to bottom, #3d4142, #36393a 60%, #313434); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

colorswatch#add-color-button overlay:backdrop { border-color: #202223; background-color: #3b3e3f; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

colorswatch#add-color-button overlay:backdrop label, colorswatch#add-color-button overlay:backdrop { color: #959696; }

colorswatch:disabled { opacity: 0.5; }

colorswatch:disabled overlay { border-color: rgba(0, 0, 0, 0.6); box-shadow: none; }

row:selected colorswatch, headerbar.selection-mode row.subtitle:link colorswatch, .selection-mode.titlebar:not(headerbar) row.subtitle:link colorswatch { box-shadow: 0 0 0 2px #ffffff; }

colorswatch#editor-color-sample { border-radius: 4px; }

colorswatch#editor-color-sample overlay { border-radius: 4.5px; }

colorchooser .popover.osd { border-radius: 5px; }

/******** Misc * */
.content-view { background-color: #2a2c2d; }

.content-view:hover { -gtk-icon-effect: highlight; }

.content-view:backdrop { background-color: #2a2c2d; }

.osd .scale-popup button.flat, .osd .scale-popup button.titlebutton { border-style: none; border-radius: 5px; }

.scale-popup button:hover { background-color: rgba(238, 238, 236, 0.1); border-radius: 5px; }

/********************** Window Decorations * */
decoration { border-radius: 7px 7px 0 0; border-width: 0px; box-shadow: 0 3px 9px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(29, 31, 31, 0.9); margin: 10px; }

decoration:backdrop { box-shadow: 0 3px 9px 1px transparent, 0 2px 6px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(29, 31, 31, 0.9); transition: 200ms ease-out; }

.maximized decoration, .fullscreen decoration, .tiled decoration, .tiled-top decoration, .tiled-right decoration, .tiled-bottom decoration, .tiled-left decoration { border-radius: 0; }

.popup decoration { box-shadow: none; }

.ssd decoration { box-shadow: 0 0 0 1px rgba(29, 31, 31, 0.9); }

.csd.popup decoration { border-radius: 0; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(29, 31, 31, 0.8); }

tooltip.csd decoration { border-radius: 5px; box-shadow: none; }

messagedialog.csd decoration { border-radius: 7px; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(29, 31, 31, 0.8); }

.solid-csd decoration { margin: 0; padding: 4px; background-color: #1d1f1f; border: solid 1px #1d1f1f; border-radius: 0; box-shadow: inset 0 0 0 3px #343637, inset 0 1px rgba(238, 238, 236, 0.07); }

.solid-csd decoration:backdrop { box-shadow: inset 0 0 0 3px #3b3e3f, inset 0 1px rgba(238, 238, 236, 0.07); }

button.titlebutton { text-shadow: 0 -1px rgba(0, 0, 0, 0.808627); -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.808627); }

button.titlebutton:not(.appmenu) { color: transparent; background-color: transparent; background-position: center; background-repeat: no-repeat; }

button.titlebutton:not(.appmenu):backdrop { opacity: 0.5; }

button.titlebutton.close { background-image: -gtk-scaled(url("assets/titlebutton-close-dark.png"), url("assets/titlebutton-close-dark@2.png")); }

button.titlebutton.close:backdrop { background-image: -gtk-scaled(url("assets/titlebutton-close-backdrop-dark.png"), url("assets/titlebutton-close-backdrop-dark@2.png")); }

button.titlebutton.close:hover { background-image: -gtk-scaled(url("assets/titlebutton-close-hover-dark.png"), url("assets/titlebutton-close-hover-dark@2.png")); }

button.titlebutton.close:active { background-image: -gtk-scaled(url("assets/titlebutton-close-active-dark.png"), url("assets/titlebutton-close-active-dark@2.png")); }

button.titlebutton.maximize { background-image: -gtk-scaled(url("assets/titlebutton-maximize-dark.png"), url("assets/titlebutton-maximize-dark@2.png")); }

button.titlebutton.maximize:backdrop { background-image: -gtk-scaled(url("assets/titlebutton-maximize-backdrop-dark.png"), url("assets/titlebutton-maximize-backdrop-dark@2.png")); }

button.titlebutton.maximize:hover { background-image: -gtk-scaled(url("assets/titlebutton-maximize-hover-dark.png"), url("assets/titlebutton-maximize-hover-dark@2.png")); }

button.titlebutton.maximize:active { background-image: -gtk-scaled(url("assets/titlebutton-maximize-active-dark.png"), url("assets/titlebutton-maximize-active-dark@2.png")); }

button.titlebutton.minimize { background-image: -gtk-scaled(url("assets/titlebutton-minimize-dark.png"), url("assets/titlebutton-minimize-dark@2.png")); }

button.titlebutton.minimize:backdrop { background-image: -gtk-scaled(url("assets/titlebutton-minimize-backdrop-dark.png"), url("assets/titlebutton-minimize-backdrop-dark@2.png")); }

button.titlebutton.minimize:hover { background-image: -gtk-scaled(url("assets/titlebutton-minimize-hover-dark.png"), url("assets/titlebutton-minimize-hover-dark@2.png")); }

button.titlebutton.minimize:active { background-image: -gtk-scaled(url("assets/titlebutton-minimize-active-dark.png"), url("assets/titlebutton-minimize-active-dark@2.png")); }

button.titlebutton:backdrop { -gtk-icon-shadow: none; }

.selection-mode headerbar button.titlebutton, .selection-mode .titlebar button.titlebutton, headerbar.selection-mode button.titlebutton, .titlebar.selection-mode button.titlebutton { text-shadow: 0 -1px rgba(0, 0, 0, 0.708235); -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.708235); }

.selection-mode headerbar button.titlebutton:backdrop, .selection-mode .titlebar button.titlebutton:backdrop, headerbar.selection-mode button.titlebutton:backdrop, .titlebar.selection-mode button.titlebutton:backdrop { -gtk-icon-shadow: none; }

textview text:focus:selected, iconview:focus:selected, flowbox headerbar.selection-mode flowboxchild.subtitle:focus:link, headerbar.selection-mode flowbox flowboxchild.subtitle:focus:link, notebook > header > tabs > arrow.button:focus:selected, row:focus:selected, headerbar.selection-mode row.subtitle:focus:link, headerbar.selection-mode calendar.subtitle:focus:link, selection, .view:selected, .view text:selected, textview text:selected, iconview:selected, flowbox flowboxchild:selected, label:disabled selection, modelbutton.flat:selected, .menuitem.button.flat:selected, headerbar.selection-mode .view.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link, headerbar.selection-mode .flat.subtitle:link, popover.background checkbutton.flat:selected, popover.background radiobutton.flat:selected, popover.background checkbutton.button:selected, popover.background radiobutton.button:selected, notebook > header > tabs > arrow.button:selected, row.activatable:selected, headerbar.selection-mode .activatable.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:link, row:selected, headerbar.selection-mode row.subtitle:link, .selection-mode.titlebar:not(headerbar) row.subtitle:link, calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link, button.button.sidebar-button:selected, button.button.titlebutton:selected { color: #ffffff; background-color: #145ba6; }

selection:backdrop, .view:backdrop:selected, .view text:backdrop:selected, textview text:backdrop:selected, iconview:backdrop:selected, flowbox flowboxchild:backdrop:selected, label:disabled selection:backdrop, modelbutton.flat:backdrop:selected, .menuitem.button.flat:backdrop:selected, headerbar.selection-mode .view.subtitle:backdrop:link, flowbox headerbar.selection-mode flowboxchild.subtitle:backdrop:link, headerbar.selection-mode flowbox flowboxchild.subtitle:backdrop:link, headerbar.selection-mode .flat.subtitle:backdrop:link, popover.background checkbutton.flat:backdrop:selected, popover.background radiobutton.flat:backdrop:selected, popover.background checkbutton.button:backdrop:selected, popover.background radiobutton.button:backdrop:selected, notebook > header > tabs > arrow.button:backdrop:selected, headerbar.selection-mode .activatable.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:backdrop:link, row:backdrop:selected, headerbar.selection-mode row.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) row.subtitle:backdrop:link, calendar:backdrop:selected, headerbar.selection-mode calendar.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:backdrop:link, button.button.sidebar-button:backdrop:selected, button.button.titlebutton:backdrop:selected { color: #d5d6d6; background-color: #656a6c; }

row:selected label, label:selected, headerbar.selection-mode row.subtitle:link label, headerbar.selection-mode label.subtitle:link, .selection-mode button.titlebutton, selection, .view:selected, .view text:selected, textview text:selected, iconview:selected, flowbox flowboxchild:selected, label:disabled selection, modelbutton.flat:selected, .menuitem.button.flat:selected, headerbar.selection-mode .view.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link, headerbar.selection-mode .flat.subtitle:link, popover.background checkbutton.flat:selected, popover.background radiobutton.flat:selected, popover.background checkbutton.button:selected, popover.background radiobutton.button:selected, notebook > header > tabs > arrow.button:selected, row.activatable:selected, headerbar.selection-mode .activatable.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:link, row:selected, headerbar.selection-mode row.subtitle:link, .selection-mode.titlebar:not(headerbar) row.subtitle:link, calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link, button.button.sidebar-button:selected, button.button.titlebutton:selected { color: #ffffff; }

row:selected label:backdrop, label:backdrop:selected, headerbar.selection-mode row.subtitle:link label:backdrop, headerbar.selection-mode label.subtitle:backdrop:link, .selection-mode button.titlebutton:backdrop, selection:backdrop, .view:backdrop:selected, .view text:backdrop:selected, textview text:backdrop:selected, iconview:backdrop:selected, flowbox flowboxchild:backdrop:selected, label:disabled selection:backdrop, modelbutton.flat:backdrop:selected, .menuitem.button.flat:backdrop:selected, headerbar.selection-mode .view.subtitle:backdrop:link, flowbox headerbar.selection-mode flowboxchild.subtitle:backdrop:link, headerbar.selection-mode flowbox flowboxchild.subtitle:backdrop:link, headerbar.selection-mode .flat.subtitle:backdrop:link, popover.background checkbutton.flat:backdrop:selected, popover.background radiobutton.flat:backdrop:selected, popover.background checkbutton.button:backdrop:selected, popover.background radiobutton.button:backdrop:selected, notebook > header > tabs > arrow.button:backdrop:selected, headerbar.selection-mode .activatable.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:backdrop:link, row:backdrop:selected, headerbar.selection-mode row.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) row.subtitle:backdrop:link, calendar:backdrop:selected, headerbar.selection-mode calendar.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:backdrop:link, button.button.sidebar-button:backdrop:selected, button.button.titlebutton:backdrop:selected { color: #d5d6d6; }

.monospace { font-family: monospace; }

/********************** Touch Copy & Paste * */
cursor-handle { background-color: transparent; background-image: none; box-shadow: none; border-style: none; }

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-dark.png"), url("assets/text-select-start-dark@2.png")); padding-left: 10px; }

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-dark.png"), url("assets/text-select-end-dark@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-dark.png"), url("assets/slider-horz-scale-has-marks-above-dark@2.png")); }

cursor-handle.top:hover:dir(ltr), cursor-handle.bottom:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-hover-dark.png"), url("assets/text-select-start-hover-dark@2.png")); padding-left: 10px; }

cursor-handle.bottom:hover:dir(ltr), cursor-handle.top:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-hover-dark.png"), url("assets/text-select-end-hover-dark@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:hover:dir(ltr), cursor-handle.insertion-cursor:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover-dark.png"), url("assets/slider-horz-scale-has-marks-above-hover-dark@2.png")); }

cursor-handle.top:active:dir(ltr), cursor-handle.bottom:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-active-dark.png"), url("assets/text-select-start-active-dark@2.png")); padding-left: 10px; }

cursor-handle.bottom:active:dir(ltr), cursor-handle.top:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-active-dark.png"), url("assets/text-select-end-active-dark@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:active:dir(ltr), cursor-handle.insertion-cursor:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active-dark.png"), url("assets/slider-horz-scale-has-marks-above-active-dark@2.png")); }

.context-menu { font: initial; }

button.circular { border-radius: 9999px; -gtk-outline-radius: 9999px; }

button.circular label { padding: 0; }

.keycap { min-width: 20px; min-height: 25px; margin-top: 2px; padding-bottom: 3px; padding-left: 6px; padding-right: 6px; color: #eeeeec; background-color: #2d2e30; border: 1px solid; border-color: #1d1f1f; border-radius: 5px; box-shadow: inset 0 -3px #242526; font-size: smaller; }

.keycap:backdrop { background-color: #2f3133; color: #959696; transition: 200ms ease-out; }

:not(decoration):not(window):drop(active):focus, :not(decoration):not(window):drop(active), combobox:drop(active) button.combo:not(window) { border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; caret-color: #4e9a06; }

stackswitcher button.text-button { min-width: 100px; }

stackswitcher button.circular, stackswitcher button.text-button.circular { min-width: 32px; min-height: 32px; padding: 0; }

/************* App Icons * */
/* Outline for low res icons */
.lowres-icon { -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/* Dropshadow for large icons */
.icon-dropshadow { -gtk-icon-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/********* Emoji * */
popover.emoji-picker { padding-left: 0; padding-right: 0; }

popover.emoji-picker entry.search { margin: 3px 5px 5px 5px; }

button.emoji-section { border-color: transparent; border-width: 3px; border-style: none none solid; border-radius: 0; margin: 2px 4px 2px 4px; padding: 3px 0 0; min-width: 32px; min-height: 28px; /* reset props inherited from the button style */ background: none; box-shadow: none; text-shadow: none; outline-offset: -5px; }

button.emoji-section:first-child, combobox.linked button.emoji-section:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.emoji-section.combo, .linked.vertical > combobox:first-child > box > button.emoji-section.combo { margin-left: 7px; }

button.emoji-section:last-child, combobox.linked button.emoji-section:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.emoji-section.combo, .linked.vertical > combobox:last-child > box > button.emoji-section.combo { margin-right: 7px; }

button.emoji-section:backdrop:not(:checked) { border-color: transparent; }

button.emoji-section:hover { border-color: rgba(238, 238, 236, 0.1); }

button.emoji-section:checked { border-color: #145ba6; }

button.emoji-section label { padding: 0; opacity: 0.55; }

button.emoji-section:hover label { opacity: 0.775; }

button.emoji-section:checked label { opacity: 1; }

popover.emoji-picker .emoji { font-size: x-large; padding: 6px; }

popover.emoji-picker .emoji :hover { background: #145ba6; border-radius: 6px; }

popover.emoji-completion arrow { border: none; background: none; }

popover.emoji-completion contents row box { padding: 2px 10px; }

popover.emoji-completion .emoji:hover { background: #145ba6; }

/* GTK NAMED COLORS ---------------- use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color #eeeeec;
/*
text color for entries, views and content in general */
@define-color theme_text_color white;
/*
widget base background color */
@define-color theme_bg_color #3b3e3f;
/*
text widgets and the like base background color */
@define-color theme_base_color #2d2e30;
/*
base background color of selections */
@define-color theme_selected_bg_color #145ba6;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #ffffff;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #353839;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #959696;
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #2d2e30;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #959696;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color white;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #3b3e3f;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #2f3133;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #145ba6;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #ffffff;
/*
widgets main borders color */
@define-color borders #1d1f1f;
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #202223;
/*
these are pretty self explicative */
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #356904;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title shade(#eeeeec, 1.8);
@define-color wm_unfocused_title #959696;
@define-color wm_highlight rgba(0, 0, 0, 0);
@define-color wm_borders_edge rgba(238, 238, 236, 0.07);
@define-color wm_bg_a shade(#3b3e3f, 1.2);
@define-color wm_bg_b #3b3e3f;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.18);
@define-color wm_button_hover_color_a shade(#3b3e3f, 1.3);
@define-color wm_button_hover_color_b #3b3e3f;
@define-color wm_button_active_color_a shade(#3b3e3f, 0.85);
@define-color wm_button_active_color_b shade(#3b3e3f, 0.89);
@define-color wm_button_active_color_c shade(#3b3e3f, 0.9);
@define-color content_view_bg #2d2e30;
.XfceHeading { margin: 0; padding: 0; border-width: 0; background-image: none; background-color: shade(#3b3e3f, 1.18); color: white; text-shadow: 0px 1px rgba(0, 0, 0, 0.1); }

.xfce4-panel.background { background-color: rgba(36, 36, 36, 0.8); color: #fcfcfc; font-weight: normal; }

.xfce4-panel.background button { background-image: none; background-color: transparent; border-radius: 0; border-color: transparent; box-shadow: none; padding: 0 1px; color: #fcfcfc; text-shadow: 0px 1px rgba(0, 0, 0, 0.1); }

.xfce4-panel.background button:active, .xfce4-panel.background button:checked { background-image: none; background-color: shade(#686868, 0.7); border-color: shade(#686868, 0.6); color: #fcfcfc; transition: none; }

.xfce4-panel.background button:hover, .xfce4-panel.background button:active:hover, .xfce4-panel.background button:checked:hover { border-color: shade(#145ba6, 0.6); background-image: linear-gradient(to bottom, shade(#145ba6, 0.88), shade(#145ba6, 0.85)); color: #fcfcfc; box-shadow: inset 0 -1px alpha(white,0), inset 1px 0 alpha(white,0.15), inset -1px 0 alpha(white,0.15), inset 0 1px alpha(white,0.15); transition: none; }

.xfce4-panel.background button:drop(active), .xfce4-panel.background combobox:drop(active) button.combo, combobox:drop(active) .xfce4-panel.background button.combo { color: #4e9a06; border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; }

.xfce4-panel.background entry { caret-color: white; }

.xfce4-panel.background menu { -gtk-icon-effect: none; text-shadow: none; }

.xfce4-panel.background menu .linked button { color: white; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#3b3e3f, 0.8); border-right-color: shade(#3b3e3f, 0.72); border-left-color: shade(#3b3e3f, 0.72); border-bottom-color: shade(#3b3e3f, 0.7); background-image: linear-gradient(to bottom, #2b2c2e, #262728 60%, #212223); box-shadow: inset 0 1px rgba(255, 255, 255, 0.05); }

.xfce4-panel.background menu .linked button:disabled { border-color: #1d1f1f; background-color: #353839; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: rgba(29, 31, 31, 0.5); }

.xfce4-panel.background menu .linked button:disabled label, .xfce4-panel.background menu .linked button:disabled { color: #959696; }

.xfce4-panel.background progressbar { margin: 0; }

.xfce4-panel.background progressbar.horizontal trough { min-height: 6px; padding: 0; }

.xfce4-panel.background progressbar.horizontal progress { min-height: 4px; }

.xfce4-panel.background progressbar.vertical trough { min-width: 6px; padding: 0; }

.xfce4-panel.background progressbar.vertical progress { min-width: 4px; }

.xfce4-panel.background progressbar progress { border-radius: 0px; }

.xfce4-panel.background progressbar trough { background: shade(#686868, 0.7); border-radius: 0px; border-color: shade(#686868, 0.4); }

.xfce4-panel.background .tasklist button { border-radius: 3px; color: shade(#fcfcfc, 0.7); background-image: linear-gradient(to bottom, shade(#686868, 0.65), shade(#686868, 0.6), shade(#686868, 0.5), shade(#686868, 0.45)); border: none; }

.xfce4-panel.background .tasklist button.flat { background-image: none; border: none; box-shadow: none; }

.xfce4-panel.background .tasklist button:active, .xfce4-panel.background .tasklist button:checked { background-image: linear-gradient(to bottom, shade(#145ba6, 0.65), shade(#145ba6, 0.6), shade(#145ba6, 0.5), shade(#145ba6, 0.45)); color: shade(#fcfcfc, 1); box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), inset 0 -1px rgba(0, 0, 0, 0.2); }

.xfce4-panel.background .tasklist button:hover, .xfce4-panel.background .tasklist button:active:hover, .xfce4-panel.background .tasklist button:checked:hover { background-image: linear-gradient(to bottom, shade(#145ba6, 0.85), shade(#145ba6, 0.8), shade(#145ba6, 0.7), shade(#145ba6, 0.65)); color: shade(#fcfcfc, 1); box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), inset 0 -1px rgba(0, 0, 0, 0.2); }

.xfce4-panel.background .tasklist button image { padding: 3px; }

.xfce4-panel.background.horizontal .tasklist button { margin: 0 1px; }

.xfce4-panel.background.horizontal .tasklist button label { padding-right: 3px; }

.xfce4-panel.background.vertical .tasklist button { margin: 1px 0; }

.xfce4-panel.background.vertical .tasklist button label { padding-bottom: 3px; }

/* Workspace switcher provided by libwnck */
wnck-pager:selected, headerbar.selection-mode wnck-pager.subtitle:link, .selection-mode.titlebar:not(headerbar) wnck-pager.subtitle:link { background-color: shade(#145ba6, 0.88); }

wnck-pager:hover { background-color: #145ba6; }

/* Thunar's sidebar top border */
.thunar :backdrop { color: #959696; }

.thunar toolbar { border-bottom: none; background-color: #3b3e3f; background-image: none; }

.thunar toolbar entry { min-height: 24px; }

.thunar .sidebar.frame { border-top: 1px solid #1d1f1f; }

XfdesktopIconView.view { background: transparent; color: #fcfcfc; border-radius: 3px; }

XfdesktopIconView.view:active { background-color: rgba(12, 54, 98, 0.5); color: #145ba6; text-shadow: 0 1px 1px black; }

XfdesktopIconView.view .label { text-shadow: 1px 1px 2px black; outline-style: none; }

XfdesktopIconView.view .label:active { color: #ffffff; }

XfdesktopIconView.view .label:backdrop { color: #ffffff; background-color: transparent; }

XfdesktopIconView.view .label:selected, XfdesktopIconView.view headerbar.selection-mode .label.subtitle:link, headerbar.selection-mode XfdesktopIconView.view .label.subtitle:link, XfdesktopIconView.view .selection-mode.titlebar:not(headerbar) .label.subtitle:link, .selection-mode.titlebar:not(headerbar) XfdesktopIconView.view .label.subtitle:link { background-color: #398ee7; }

XfdesktopIconView.view .label:selected:backdrop, XfdesktopIconView.view headerbar.selection-mode .label.subtitle:backdrop:link, headerbar.selection-mode XfdesktopIconView.view .label.subtitle:backdrop:link, XfdesktopIconView.view .selection-mode.titlebar:not(headerbar) .label.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) XfdesktopIconView.view .label.subtitle:backdrop:link { background-color: rgba(20, 91, 166, 0.5); }

XfdesktopIconView.view .rubberband { border-radius: 0; }

#XfceNotifyWindow { background-color: shade(#686868, 0.3); color: #fcfcfc; border-color: shade(#686868, 0.6); box-shadow: none; }

#XfceNotifyWindow buttonbox { padding: 0; }

#XfceNotifyWindow button { color: #fcfcfc; background-image: none; border-color: shade(#fcfcfc, 0.35); border-radius: 3px; box-shadow: none; }

#XfceNotifyWindow button:hover { background-color: shade(#686868, 0.4); border-color: shade(#fcfcfc, 0.45); }

#XfceNotifyWindow label#summary { font-weight: bold; }

#XfceNotifyWindow progressbar { min-height: 6px; border-radius: 3px; }

#XfceNotifyWindow progressbar progress { background-image: none; background-color: #fcfcfc; border: none; box-shadow: none; }

#XfceNotifyWindow progressbar trough { background-image: linear-gradient(to bottom, shade(#686868, 0.65), shade(#686868, 1.25)); border: 1px solid shade(#686868, 0.2); border-radius: 3px; padding: 1px 0; }

/* Xfwm4's alt-tab dialog, aka "tabwin" */
#xfwm-tabwin { padding: 12px; background-image: none; background-color: rgba(0, 0, 0, 0.8); color: shade(#ffffff, 0.65); text-shadow: 0px 1px rgba(0, 0, 0, 0.8); border-radius: 12px; /* Set the application icon- and preview-size to 64px */ -XfwmTabwinWidget-icon-size: 64px; -XfwmTabwinWidget-preview-size: 128px; }

#xfwm-tabwin button { background-image: none; color: #ffffff; font-weight: bold; text-shadow: 0px 1px rgba(0, 0, 0, 0.8); border: none; border-radius: 6px; box-shadow: none; }

#xfwm-tabwin button:active, #xfwm-tabwin button:checked, #xfwm-tabwin button:active:hover, #xfwm-tabwin button:checked:hover { background: rgba(238, 238, 236, 0.3); }

#xfwm-tabwin button:hover { background: rgba(59, 62, 63, 0.1); box-shadow: inset 0 -1px alpha(white,0.15), inset 1px 0 alpha(white,0.15), inset -1px 0 alpha(white,0.15), inset 0 1px alpha(white,0.15); transition-duration: 50ms; }

#xfwm-tabwin .tabwin-app-grid button { min-width: 96px; min-height: 96px; }

#xfce4-terminal-notebook > stack:not(:only-child) { /* Make sure there are no extra borders for the tabs in the terminal apart from at the top */ border-left: none; border-right: none; border-bottom: none; }

.lightdm-gtk-greeter { /********* panel * */ /**************** login window * */ }

.lightdm-gtk-greeter #panel_window menubar { color: #fcfcfc; font-weight: bold; text-shadow: 0 1px transparentize black, 0.5; -gtk-icon-shadow: 0 1px transparentize black, 0.5; box-shadow: inset 0 -1px transparentize black, 0.5; background-color: rgba(36, 36, 36, 0.8); text-shadow: 0 1px transparentize black, 0.5; -gtk-icon-shadow: 0 1px transparentize black, 0.5; }

.lightdm-gtk-greeter #panel_window menubar menu { background-color: #303133; }

.lightdm-gtk-greeter #panel_window menubar menu menuitem { font-weight: normal; text-shadow: none; }

.lightdm-gtk-greeter #panel_window menubar separator { background: transparent; }

.lightdm-gtk-greeter #login_window, .lightdm-gtk-greeter #shutdown_dialog, .lightdm-gtk-greeter #restart_dialog { border-style: none; border-radius: 5px; background-color: #2d2e30; color: #eeeeec; box-shadow: inset 1px 0 shade(#2d2e30, 0.6), inset -1px 0 shade(#2d2e30, 0.6), inset 0 1px shade(#2d2e30, 0.6), inset 0 -1px shade(#2d2e30, 0.6); }

.lightdm-gtk-greeter #login_window button, .lightdm-gtk-greeter #shutdown_dialog button, .lightdm-gtk-greeter #restart_dialog button { padding: 3px 15px; /************************************ login/unlock and restart buttons * */ /******************* shutdown button * */ }

.lightdm-gtk-greeter #login_window button#login_button, .lightdm-gtk-greeter #login_window button#restart_button, .lightdm-gtk-greeter #shutdown_dialog button#login_button, .lightdm-gtk-greeter #shutdown_dialog button#restart_button, .lightdm-gtk-greeter #restart_dialog button#login_button, .lightdm-gtk-greeter #restart_dialog button#restart_button { border-color: shade(#145ba6, 0.8); background-image: linear-gradient(to bottom, shade(#145ba6, 1.02), shade(#145ba6, 0.95) 90%, shade(#145ba6, 0.9)); color: #ffffff; }

.lightdm-gtk-greeter #login_window button#login_button:hover, .lightdm-gtk-greeter #login_window button#login_button:active, .lightdm-gtk-greeter #login_window button#restart_button:hover, .lightdm-gtk-greeter #login_window button#restart_button:active, .lightdm-gtk-greeter #shutdown_dialog button#login_button:hover, .lightdm-gtk-greeter #shutdown_dialog button#login_button:active, .lightdm-gtk-greeter #shutdown_dialog button#restart_button:hover, .lightdm-gtk-greeter #shutdown_dialog button#restart_button:active, .lightdm-gtk-greeter #restart_dialog button#login_button:hover, .lightdm-gtk-greeter #restart_dialog button#login_button:active, .lightdm-gtk-greeter #restart_dialog button#restart_button:hover, .lightdm-gtk-greeter #restart_dialog button#restart_button:active { border-color: shade(#145ba6, 0.7); background-image: linear-gradient(to bottom, shade(#145ba6, 1.12), shade(#145ba6, 1.05) 90%, shade(#145ba6, 1)); }

.lightdm-gtk-greeter #login_window button#shutdown_button, .lightdm-gtk-greeter #shutdown_dialog button#shutdown_button, .lightdm-gtk-greeter #restart_dialog button#shutdown_button { border-color: shade(#cc0000, 0.8); background-image: linear-gradient(to bottom, shade(#cc0000, 1.02), shade(#cc0000, 0.95) 90%, shade(#cc0000, 0.9)); color: #ffffff; }

.lightdm-gtk-greeter #login_window button#shutdown_button:hover, .lightdm-gtk-greeter #login_window button#shutdown_button:active, .lightdm-gtk-greeter #shutdown_dialog button#shutdown_button:hover, .lightdm-gtk-greeter #shutdown_dialog button#shutdown_button:active, .lightdm-gtk-greeter #restart_dialog button#shutdown_button:hover, .lightdm-gtk-greeter #restart_dialog button#shutdown_button:active { border-color: shade(#cc0000, 0.7); background-image: linear-gradient(to bottom, shade(#cc0000, 1.12), shade(#cc0000, 1.05) 90%, shade(#cc0000, 1)); }

.lightdm-gtk-greeter #content_frame { padding-bottom: 14px; }

.lightdm-gtk-greeter #login_window menu { border-radius: 1px; }

.lightdm-gtk-greeter #login_window combobox button.combo { color: #eeeeec; padding: 0; background: none; border-style: none; box-shadow: none; }

.lightdm-gtk-greeter #login_window #user_combobox { color: #eeeeec; font-size: 18px; }

.lightdm-gtk-greeter #login_window #user_combobox menu { font-weight: normal; }

.lightdm-gtk-greeter #login_window #user_image { padding: 3px; border-radius: 3px; box-shadow: inset 1px 0 shade(#2d2e30, 0.75), inset -1px 0 shade(#2d2e30, 0.75), inset 0 1px shade(#2d2e30, 0.55), inset 0 -1px shade(#2d2e30, 0.85); }

.lightdm-gtk-greeter #login_window #user_image_border { border-radius: 3px; background-image: linear-gradient(to bottom, shade(#2d2e30, 0.9), shade(#2d2e30, 0.98) 10%, shade(#2d2e30, 1) 99%, shade(#2d2e30, 1)); box-shadow: inset 0 1px shade(#2d2e30, 0.8), inset 0 -1px shade(#2d2e30, 0.55); }

.lightdm-gtk-greeter #buttonbox_frame { padding-top: 20px; padding-bottom: 0px; border-style: none; border-bottom-left-radius: 5px; border-bottom-right-radius: 5px; background-image: linear-gradient(to bottom, shade(#3b3e3f, 0.85), shade(#3b3e3f, 0.98) 10%, shade(#3b3e3f, 1) 99%, shade(#3b3e3f, 1)); box-shadow: inset 1px 0 shade(#2d2e30, 0.6), inset -1px 0 shade(#2d2e30, 0.6), inset 0 1px shade(#2d2e30, 0.6), inset 0 -1px shade(#2d2e30, 0.6); }

/************************ NAUTILUS (aka Files) * */
.nautilus-window { background-color: #2d2e30; }

.nautilus-window notebook, .nautilus-window notebook > stack { background-color: #2d2e30; }

/* Floating status bar */
.floating-bar { background-color: #2d2e30; border-style: solid; border-color: #1d1f1f; }

.floating-bar.left { border-radius: 0 3px 0 0; border-width: 1px 1px 0 0; }

.floating-bar.right { border-radius: 3px 0 0 0; border-width: 1px 0 0 1px; }

.floating-bar:backdrop { background-color: #3b3e3f; border-color: #202223; }

.floating-bar button { padding: 0px; }

/* Searchbar */
.search-bar { box-shadow: none; }

/* View */
.nautilus-list-view .view, .nautilus-list-view iconview { border-bottom: 1px solid #3b3e3f; /* Hide superfluous treeview drop target indication */ }

.nautilus-list-view .view.dnd, .nautilus-list-view iconview.dnd { border-style: none; }

/********* Geary * */
.conversation-frame .view.cell, .conversation-frame iconview.cell { background-color: #2d2e30; }

.conversation-frame .view.cell:selected, .conversation-frame iconview.cell:selected, .conversation-frame headerbar.selection-mode .view.cell.subtitle:link, headerbar.selection-mode .conversation-frame .view.cell.subtitle:link, .conversation-frame headerbar.selection-mode iconview.cell.subtitle:link, headerbar.selection-mode .conversation-frame iconview.cell.subtitle:link, .conversation-frame .selection-mode.titlebar:not(headerbar) .view.cell.subtitle:link, .selection-mode.titlebar:not(headerbar) .conversation-frame .view.cell.subtitle:link, .conversation-frame .selection-mode.titlebar:not(headerbar) iconview.cell.subtitle:link, .selection-mode.titlebar:not(headerbar) .conversation-frame iconview.cell.subtitle:link, .conversation-frame .view.cell:selected:focus { background-color: #145ba6; }

/***************** Gnome Builder * */
headerbar entry .vertical.pan button image { min-height: 12px; padding: 0; }

/****************** Gnome Software * */
headerbar viewswitcher button stack box { padding-top: 0px; padding-bottom: 0px; }

UnityDecoration { -UnityDecoration-extents: 28px 1px 1px 1px; -UnityDecoration-input-extents: 10px; -UnityDecoration-shadow-offset-x: 1px; -UnityDecoration-shadow-offset-y: 1px; -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.7); -UnityDecoration-active-shadow-radius: 8px; -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.5); -UnityDecoration-inactive-shadow-radius: 5px; -UnityDecoration-glow-size: 10px; -UnityDecoration-glow-color: #145ba6; -UnityDecoration-title-indent: 10px; -UnityDecoration-title-fade: 35px; -UnityDecoration-title-alignment: 0.0; }

UnityDecoration .top { border: 1px solid shade(#3b3e3f, 0.7); border-bottom-width: 0; border-radius: 4px 4px 0 0; padding: 1px 8px 0 8px; background-image: linear-gradient(to bottom, shade(#3b3e3f, 1.07), #3b3e3f); color: #eeeeec; text-shadow: 0 1px shade(#3b3e3f, 1.2); }

UnityDecoration .top:backdrop { border: 1px solid shade(#3b3e3f, 0.8); border-bottom-width: 0; background-image: linear-gradient(to bottom, shade(#3b3e3f, 1.02), #3b3e3f); color: #eeeeec; text-shadow: 0 1px shade(#3b3e3f, 1.1); }

UnityDecoration .left, UnityDecoration .right, UnityDecoration .bottom { background-color: shade(#3b3e3f, 0.7); }

UnityDecoration .left:backdrop, UnityDecoration .right:backdrop, UnityDecoration .bottom:backdrop { background-color: shade(#3b3e3f, 0.8); }

UnityPanelWidget, .unity-panel { border-width: 0 0 1px 0; border-style: solid; border-color: shade(#686868, 1); background-color: shade(#686868, 0.35); }

UnityPanelWidget.menuitem, UnityPanelWidget .menuitem, .unity-panel.menuitem, .unity-panel .menuitem { border-width: 0 1px; color: #fcfcfc; }

UnityPanelWidget.menuitem:hover, UnityPanelWidget.menuitem *:hover, UnityPanelWidget.menuitem headerbar.selection-mode .subtitle:hover:link, headerbar.selection-mode UnityPanelWidget.menuitem .subtitle:hover:link, UnityPanelWidget.menuitem .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) UnityPanelWidget.menuitem .subtitle:hover:link, UnityPanelWidget .menuitem:hover, UnityPanelWidget .menuitem *:hover, UnityPanelWidget .menuitem headerbar.selection-mode .subtitle:hover:link, headerbar.selection-mode UnityPanelWidget .menuitem .subtitle:hover:link, UnityPanelWidget .menuitem .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) UnityPanelWidget .menuitem .subtitle:hover:link, .unity-panel.menuitem:hover, .unity-panel.menuitem *:hover, .unity-panel.menuitem headerbar.selection-mode .subtitle:hover:link, headerbar.selection-mode .unity-panel.menuitem .subtitle:hover:link, .unity-panel.menuitem .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .unity-panel.menuitem .subtitle:hover:link, .unity-panel .menuitem:hover, .unity-panel .menuitem *:hover, .unity-panel .menuitem headerbar.selection-mode .subtitle:hover:link, headerbar.selection-mode .unity-panel .menuitem .subtitle:hover:link, .unity-panel .menuitem .selection-mode.titlebar:not(headerbar) .subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .unity-panel .menuitem .subtitle:hover:link { border-color: shade(#686868, 0.8); background-color: shade(#686868, 0.75); color: #fcfcfc; }

@keyframes playbackmenuitem_spinner { to { -gtk-icon-transform: rotate(1turn); } }

.menu IdoPlaybackMenuItem.menuitem:active { -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); animation: playbackmenuitem_spinner 1s infinite linear; color: #eeeeec; }

window.background.chromium { background-color: #3b3e3f; }

window.background.chromium button:not(.titlebutton) { border-color: #1d1f1f; }
